@@ -1,25 +1,25 @@
-# encoding: utf-8
-
 module Nanoc
-  # @return [String] A string containing information about this nanoc version
+  # @return [String] A string containing information about this Nanoc version
   #   and its environment (Ruby engine and version, Rubygems version if any).
+  #
+  # @api private
   def self.version_information
     gem_info = defined?(Gem) ? "with RubyGems #{Gem::VERSION}" : 'without RubyGems'
     engine   = defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby'
     res = ''
-    res << "nanoc #{Nanoc::VERSION} © 2007-2015 Denis Defreyne.\n"
+    res << "Nanoc #{Nanoc::VERSION} © 2007-2016 Denis Defreyne.\n"
     res << "Running #{engine} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} #{gem_info}.\n"
     res
   end
 
-  # @return [Boolean] True if the current platform is Windows,
+  # @return [Boolean] True if the current platform is Windows, false otherwise.
+  #
+  # @api private
   def self.on_windows?
     RUBY_PLATFORM =~ /windows|bccwin|cygwin|djgpp|mingw|mswin|wince/i
   end
 end
 
-Nanoc3 = Nanoc
-
 # Load general requirements
 require 'digest'
 require 'enumerator'
@@ -34,10 +34,11 @@ require 'time'
 require 'yaml'
 require 'English'
 
-# Load nanoc
+# Load Nanoc
 require 'nanoc/version'
 require 'nanoc/base'
 require 'nanoc/extra'
 require 'nanoc/data_sources'
 require 'nanoc/filters'
 require 'nanoc/helpers'
+require 'nanoc/rule_dsl'
