@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc
   # Nanoc::Filter is responsible for filtering items. It is the superclass
   # for all textual filters.
@@ -25,16 +23,19 @@ module Nanoc
   #     # => 'bar'
   #
   # @abstract Subclass and override {#run} to implement a custom filter.
-  class Filter < Context
-    TMP_BINARY_ITEMS_DIR = 'binary_items'
+  class Filter < Nanoc::Int::Context
+    # @api private
+    TMP_BINARY_ITEMS_DIR = 'binary_items'.freeze
 
     # A hash containing variables that will be made available during
     # filtering.
     #
     # @return [Hash]
+    #
+    # @api private
     attr_reader :assigns
 
-    extend Nanoc::PluginRegistry::PluginMethods
+    extend Nanoc::Int::PluginRegistry::PluginMethods
 
     class << self
       # Sets the new type for the filter. The type can be `:binary` (default)
@@ -55,20 +56,26 @@ module Nanoc
       # @return [void]
       def type(arg)
         if arg.is_a?(Hash)
-          @from, @to = arg.keys[0], arg.values[0]
+          @from = arg.keys[0]
+          @to = arg.values[0]
         else
-          @from, @to = arg, arg
+          @from = arg
+          @to = arg
         end
       end
 
       # @return [Boolean] True if this filter can be applied to binary item
       #   representations, false otherwise
+      #
+      # @api private
       def from_binary?
         (@from || :text) == :binary
       end
 
       # @return [Boolean] True if this filter results in a binary item
       #   representation, false otherwise
+      #
+      # @api private
       def to_binary?
         (@to || :text) == :binary
       end
@@ -81,7 +88,7 @@ module Nanoc
       #   Returns the required libraries for this filter.
       #   @return [Enumerable<String>] This filter’s list of library names that are required
       def requires(*requires)
-        if requires.size > 0
+        if requires.any?
           @requires = requires
         else
           @requires || []
@@ -91,6 +98,8 @@ module Nanoc
       # Requires the filter’s required library if necessary.
       #
       # @return [void]
+      #
+      # @api private
       def setup
         @setup ||= begin
           requires.each { |r| require r }
@@ -103,6 +112,8 @@ module Nanoc
     #
     # @param [Hash] hash A hash containing variables that should be made
     #   available during filtering.
+    #
+    # @api private
     def initialize(hash = {})
       @assigns = hash
       super
@@ -112,6 +123,8 @@ module Nanoc
     # to {#run} unchanged and returns the return value from {#run}.
     #
     # @see {#run}
+    #
+    # @api private
     def setup_and_run(*args)
       self.class.setup
       run(*args)
@@ -145,13 +158,15 @@ module Nanoc
     # @return [String] The output filename
     def output_filename
       @output_filename ||=
-        Nanoc::TempFilenameFactory.instance.create(TMP_BINARY_ITEMS_DIR)
+        Nanoc::Int::TempFilenameFactory.instance.create(TMP_BINARY_ITEMS_DIR)
     end
 
     # Returns the filename associated with the item that is being filtered.
     #   It is in the format `item <identifier> (rep <name>)`.
     #
     # @return [String] The filename
+    #
+    # @api private
     def filename
       if assigns[:layout]
         "layout #{assigns[:layout].identifier}"
@@ -166,20 +181,21 @@ module Nanoc
     # the given collection of items. In other words, require the given items
     # to be compiled first before this items is processed.
     #
-    # @param [Array<Nanoc::Item>] items The items that are depended on.
-    #
     # @return [void]
     def depend_on(items)
+      orig_items = items
+      items = items.map { |i| i.is_a?(Nanoc::ItemWithRepsView) ? i.unwrap : i }
+
       # Notify
       items.each do |item|
-        Nanoc::NotificationCenter.post(:visit_started, item)
-        Nanoc::NotificationCenter.post(:visit_ended,   item)
+        Nanoc::Int::NotificationCenter.post(:visit_started, item)
+        Nanoc::Int::NotificationCenter.post(:visit_ended,   item)
       end
 
       # Raise unmet dependency error if necessary
       items.each do |item|
-        rep = item.reps.find { |r| !r.compiled? }
-        raise Nanoc::Errors::UnmetDependency.new(rep) if rep
+        rep = orig_items.sample._context.reps[item].find { |r| !r.compiled? }
+        raise Nanoc::Int::Errors::UnmetDependency.new(rep) if rep
       end
     end
   end
