@@ -1,30 +1,30 @@
-# encoding: utf-8
-
-module Nanoc
+module Nanoc::Int
   # Responsible for determining whether an item or a layout is outdated.
   #
   # @api private
   class OutdatednessChecker
-    extend Nanoc::Memoization
+    extend Nanoc::Int::Memoization
 
-    # @option params [Nanoc::Site] :site (nil) The site this outdatedness
-    #   checker belongs to.
-    #
-    # @option params [Nanoc::ChecksumStore] :checksum_store (nil) The
-    #   checksum store where checksums of items, layouts, … are stored.
-    #
-    # @option params [Nanoc::DependencyTracker] :dependency_tracker (nil) The
-    #   dependency tracker for the given site.
-    def initialize(params = {})
-      @site = params.fetch(:site) do
-        raise ArgumentError, 'Nanoc::OutdatednessChecker#initialize needs a :site parameter'
-      end
-      @checksum_store = params.fetch(:checksum_store) do
-        raise ArgumentError, 'Nanoc::OutdatednessChecker#initialize needs a :checksum_store parameter'
-      end
-      @dependency_tracker = params.fetch(:dependency_tracker) do
-        raise ArgumentError, 'Nanoc::OutdatednessChecker#initialize needs a :dependency_tracker parameter'
-      end
+    attr_reader :checksum_store
+    attr_reader :dependency_store
+    attr_reader :rule_memory_store
+    attr_reader :site
+
+    Reasons = Nanoc::Int::OutdatednessReasons
+
+    # @param [Nanoc::Int::Site] site
+    # @param [Nanoc::Int::ChecksumStore] checksum_store
+    # @param [Nanoc::Int::DependencyStore] dependency_store
+    # @param [Nanoc::Int::RuleMemoryStore] rule_memory_store
+    # @param [Nanoc::Int::ActionProvider] action_provider
+    # @param [Nanoc::Int::ItemRepRepo] reps
+    def initialize(site:, checksum_store:, dependency_store:, rule_memory_store:, action_provider:, reps:)
+      @site = site
+      @checksum_store = checksum_store
+      @dependency_store = dependency_store
+      @rule_memory_store = rule_memory_store
+      @action_provider = action_provider
+      @reps = reps
 
       @basic_outdatedness_reasons = {}
       @outdatedness_reasons = {}
@@ -34,7 +34,7 @@ module Nanoc
     # Checks whether the given object is outdated and therefore needs to be
     # recompiled.
     #
-    # @param [Nanoc::Item, Nanoc::ItemRep, Nanoc::Layout] obj The object
+    # @param [Nanoc::Int::Item, Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The object
     #   whose outdatedness should be checked.
     #
     # @return [Boolean] true if the object is outdated, false otherwise
@@ -44,15 +44,15 @@ module Nanoc
 
     # Calculates the reason why the given object is outdated.
     #
-    # @param [Nanoc::Item, Nanoc::ItemRep, Nanoc::Layout] obj The object
+    # @param [Nanoc::Int::Item, Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The object
     #   whose outdatedness reason should be calculated.
     #
-    # @return [Nanoc::OutdatednessReasons::Generic, nil] The reason why the
+    # @return [Reasons::Generic, nil] The reason why the
     #   given object is outdated, or nil if the object is not outdated.
     def outdatedness_reason_for(obj)
       reason = basic_outdatedness_reason_for(obj)
       if reason.nil? && outdated_due_to_dependencies?(obj)
-        reason = Nanoc::OutdatednessReasons::DependenciesOutdated
+        reason = Reasons::DependenciesOutdated
       end
       reason
     end
@@ -65,7 +65,7 @@ module Nanoc
     # {#outdated?} if you want to include dependencies in the outdatedness
     # check.
     #
-    # @param [Nanoc::Item, Nanoc::ItemRep, Nanoc::Layout] obj The object
+    # @param [Nanoc::Int::Item, Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The object
     #   whose outdatedness should be checked.
     #
     # @return [Boolean] true if the object is outdated, false otherwise
@@ -77,45 +77,45 @@ module Nanoc
     # not take dependencies into account; use {#outdatedness_reason_for?} if
     # you want to include dependencies in the outdatedness check.
     #
-    # @param [Nanoc::Item, Nanoc::ItemRep, Nanoc::Layout] obj The object
+    # @param [Nanoc::Int::Item, Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The object
     #   whose outdatedness reason should be calculated.
     #
-    # @return [Nanoc::OutdatednessReasons::Generic, nil] The reason why the
+    # @return [Reasons::Generic, nil] The reason why the
     #   given object is outdated, or nil if the object is not outdated.
     def basic_outdatedness_reason_for(obj)
-      case obj.type
-      when :item_rep
+      case obj
+      when Nanoc::Int::ItemRep
         # Outdated if rules outdated
-        return Nanoc::OutdatednessReasons::RulesModified if
+        return Reasons::RulesModified if
           rule_memory_differs_for(obj)
 
         # Outdated if checksums are missing or different
-        return Nanoc::OutdatednessReasons::NotEnoughData unless checksums_available?(obj.item)
-        return Nanoc::OutdatednessReasons::SourceModified unless checksums_identical?(obj.item)
+        return Reasons::NotEnoughData unless checksums_available?(obj.item)
+        return Reasons::SourceModified unless checksums_identical?(obj.item)
 
         # Outdated if compiled file doesn't exist (yet)
-        return Nanoc::OutdatednessReasons::NotWritten if obj.raw_path && !File.file?(obj.raw_path)
+        return Reasons::NotWritten if obj.raw_path && !File.file?(obj.raw_path)
 
         # Outdated if code snippets outdated
-        return Nanoc::OutdatednessReasons::CodeSnippetsModified if site.code_snippets.any? do |cs|
+        return Reasons::CodeSnippetsModified if site.code_snippets.any? do |cs|
           object_modified?(cs)
         end
 
         # Outdated if configuration outdated
-        return Nanoc::OutdatednessReasons::ConfigurationModified if object_modified?(site.config)
+        return Reasons::ConfigurationModified if object_modified?(site.config)
 
         # Not outdated
         return nil
-      when :item
-        obj.reps.find { |rep| basic_outdatedness_reason_for(rep) }
-      when :layout
+      when Nanoc::Int::Item
+        @reps[obj].find { |rep| basic_outdatedness_reason_for(rep) }
+      when Nanoc::Int::Layout
         # Outdated if rules outdated
-        return Nanoc::OutdatednessReasons::RulesModified if
+        return Reasons::RulesModified if
           rule_memory_differs_for(obj)
 
         # Outdated if checksums are missing or different
-        return Nanoc::OutdatednessReasons::NotEnoughData unless checksums_available?(obj)
-        return Nanoc::OutdatednessReasons::SourceModified unless checksums_identical?(obj)
+        return Reasons::NotEnoughData unless checksums_available?(obj)
+        return Reasons::SourceModified unless checksums_identical?(obj)
 
         # Not outdated
         return nil
@@ -127,7 +127,7 @@ module Nanoc
 
     # Checks whether the given object is outdated due to dependencies.
     #
-    # @param [Nanoc::Item, Nanoc::ItemRep, Nanoc::Layout] obj The object
+    # @param [Nanoc::Int::Item, Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The object
     #   whose outdatedness should be checked.
     #
     # @param [Set] processed The collection of items that has been visited
@@ -138,7 +138,7 @@ module Nanoc
     # @return [Boolean] true if the object is outdated, false otherwise
     def outdated_due_to_dependencies?(obj, processed = Set.new)
       # Convert from rep to item if necessary
-      obj = obj.item if obj.type == :item_rep
+      obj = obj.item if obj.is_a?(Nanoc::Int::ItemRep)
 
       # Get from cache
       if @objects_outdated_due_to_dependencies.key?(obj)
@@ -151,7 +151,7 @@ module Nanoc
       return false if processed.include?(obj)
 
       # Calculate
-      is_outdated = dependency_tracker.objects_causing_outdatedness_of(obj).any? do |other|
+      is_outdated = dependency_store.objects_causing_outdatedness_of(obj).any? do |other|
         other.nil? || basic_outdated?(other) || outdated_due_to_dependencies?(other, processed.merge([obj]))
       end
 
@@ -162,22 +162,30 @@ module Nanoc
       is_outdated
     end
 
-    # @param [Nanoc::ItemRep, Nanoc::Layout] obj The layout or item
+    # @param [Nanoc::Int::ItemRep, Nanoc::Int::Layout] obj The layout or item
     #   representation to check the rule memory for
     #
     # @return [Boolean] true if the rule memory for the given item
     #   represenation has changed, false otherwise
     def rule_memory_differs_for(obj)
-      rules_collection.rule_memory_differs_for(obj)
+      !rule_memory_store[obj].eql?(@action_provider.memory_for(obj).serialize)
     end
     memoize :rule_memory_differs_for
 
+    # @param obj The object to create a checksum for
+    #
+    # @return [String] The digest
+    def calc_checksum(obj)
+      Nanoc::Int::Checksummer.calc(obj)
+    end
+    memoize :calc_checksum
+
     # @param obj
     #
     # @return [Boolean] false if either the new or the old checksum for the
     #   given object is not available, true if both checksums are available
     def checksums_available?(obj)
-      checksum_store[obj] && obj.checksum
+      checksum_store[obj] && calc_checksum(obj)
     end
     memoize :checksums_available?
 
@@ -186,7 +194,7 @@ module Nanoc
     # @return [Boolean] false if the old and new checksums for the given
     #   object differ, true if they are identical
     def checksums_identical?(obj)
-      checksum_store[obj] == obj.checksum
+      checksum_store[obj] == calc_checksum(obj)
     end
     memoize :checksums_identical?
 
@@ -198,25 +206,5 @@ module Nanoc
       !checksums_available?(obj) || !checksums_identical?(obj)
     end
     memoize :object_modified?
-
-    # @return [Nanoc::ChecksumStore] The checksum store
-    def checksum_store
-      @checksum_store
-    end
-
-    # @return [Nanoc::RulesCollection] The rules collection
-    def rules_collection
-      site.compiler.rules_collection
-    end
-
-    # @return [Nanoc::DependencyTracker] The dependency tracker
-    def dependency_tracker
-      @dependency_tracker
-    end
-
-    # @return [Nanoc::Site] The site
-    def site
-      @site
-    end
   end
 end
