@@ -1,13 +1,11 @@
-# encoding: utf-8
-
-module Nanoc
+module Nanoc::Int
   # Represents a directed graph. It is used by the dependency tracker for
   # storing and querying dependencies between items.
   #
   # @example Creating and using a directed graph
   #
   #   # Create a graph with three vertices
-  #   graph = Nanoc::DirectedGraph.new(%w( a b c d ))
+  #   graph = Nanoc::Int::DirectedGraph.new(%w( a b c d ))
   #
   #   # Add edges
   #   graph.add_edge('a', 'b')
@@ -28,6 +26,8 @@ module Nanoc
   #     # => %w( c )
   #   graph.predecessors_of('d').sort
   #     # => %w( b c )
+  #
+  # @api private
   class DirectedGraph
     # @group Creating a graph
 
@@ -224,13 +224,6 @@ module Nanoc
       @roots
     end
 
-    # @group Deprecated methods
-
-    # @deprecated Use {#delete_edge} instead
-    def remove_edge(from, to)
-      delete_edge(from, to)
-    end
-
     private
 
     # Invalidates cached data. This method should be called when the internal
