@@ -1,8 +1,8 @@
-# encoding: utf-8
-
-module Nanoc
+module Nanoc::Int
   # Adds support for memoizing functions.
   #
+  # @api private
+  #
   # @since 3.2.0
   module Memoization
     # Memoizes the method with the given name. The modified method will cache
@@ -20,7 +20,7 @@ module Nanoc
     #
     #     class FibFast
     #
-    #       extend Nanoc::Memoization
+    #       extend Nanoc::Int::Memoization
     #
     #       def run(n)
     #         if n == 0
