@@ -1,11 +1,10 @@
-# encoding: utf-8
-
-module Nanoc
+module Nanoc::Int
   # The class responsible for keeping track of all loaded plugins, such as
-  # filters ({Nanoc::Filter}), data sources ({Nanoc::DataSource}) and VCSes
-  # ({Nanoc::Extra::VCS}).
+  # filters ({Nanoc::Filter}) and data sources ({Nanoc::DataSource}).
+  #
+  # @api private
   class PluginRegistry
-    extend Nanoc::Memoization
+    extend Nanoc::Int::Memoization
 
     # A module that contains class methods for plugins. It provides functions
     # for setting identifiers, registering plugins and finding plugins. Plugin
@@ -25,7 +24,7 @@ module Nanoc
       #   @return [Array<Symbol>] The identifiers for this plugin
       def identifiers(*identifiers)
         if identifiers.empty?
-          Nanoc::PluginRegistry.instance.identifiers_of(superclass, self)
+          Nanoc::Int::PluginRegistry.instance.identifiers_of(superclass, self)
         else
           register(self, *identifiers)
         end
@@ -46,7 +45,7 @@ module Nanoc
         if identifier
           identifiers(identifier)
         else
-          Nanoc::PluginRegistry.instance.identifiers_of(superclass, self).first
+          Nanoc::Int::PluginRegistry.instance.identifiers_of(superclass, self).first
         end
       end
 
@@ -65,14 +64,14 @@ module Nanoc
         klass = klass.superclass while klass.superclass.respond_to?(:register)
 
         # Register
-        registry = Nanoc::PluginRegistry.instance
+        registry = Nanoc::Int::PluginRegistry.instance
         registry.register(klass, class_or_name, *identifiers)
       end
 
       # @return [Hash<Symbol, Class>] All plugins of this type, with keys
       #   being the identifiers and values the plugin classes
       def all
-        Nanoc::Plugin.find_all(self)
+        Nanoc::Int::PluginRegistry.instance.find_all(self)
       end
 
       # Returns the plugin with the given name (identifier)
@@ -81,21 +80,21 @@ module Nanoc
       #
       # @return [Class] The plugin class with the given name
       def named(name)
-        Nanoc::Plugin.find(self, name)
+        Nanoc::Int::PluginRegistry.instance.find(self, name)
       end
     end
 
     # Returns the shared {PluginRegistry} instance, creating it if none exists
     # yet.
     #
-    # @return [Nanoc::PluginRegistry] The shared plugin registry
+    # @return [Nanoc::Int::PluginRegistry] The shared plugin registry
     def self.instance
       @instance ||= new
     end
 
     # Creates a new plugin registry. This should usually not be necessary; it
     # is recommended to use the shared instance (obtained from
-    # {Nanoc::PluginRegistry.instance}).
+    # {Nanoc::Int::PluginRegistry.instance}).
     def initialize
       @identifiers_to_classes = {}
       @classes_to_identifiers = {}
@@ -104,7 +103,7 @@ module Nanoc
     # Registers the given class as a plugin.
     #
     # @param [Class] superclass The superclass of the plugin. For example:
-    #   {Nanoc::Filter}, {Nanoc::Extra::VCS}.
+    #   {Nanoc::Filter}.
     #
     # @param [Class, String] class_or_name The class to register. This can be
     #   a string, in which case it will be automatically converted to a proper
@@ -126,7 +125,7 @@ module Nanoc
     end
 
     # @param [Class] superclass The superclass of the plugin. For example:
-    #   {Nanoc::Filter}, {Nanoc::Extra::VCS}.
+    #   {Nanoc::Filter}.
     #
     # @param [Class] klass The class to get the identifiers for.
     #
@@ -184,7 +183,7 @@ module Nanoc
             plugins << {
               class: klass,
               superclass: superclass,
-              identifiers: [identifier]
+              identifiers: [identifier],
             }
           end
         end
@@ -193,11 +192,6 @@ module Nanoc
       plugins
     end
 
-    # @deprecated Use {Nanoc::PluginRegistry#find} instead
-    def named(name)
-      find(self, name)
-    end
-
     protected
 
     def resolve(class_or_name, _klass)
@@ -215,7 +209,4 @@ module Nanoc
       klass.to_s.sub(/^(::)?/, '::')
     end
   end
-
-  # @deprecated Use {Nanoc::PluginRegistry.instance} instead
-  Plugin = PluginRegistry.instance
 end
