@@ -1,10 +1,8 @@
-# encoding: utf-8
-
 begin
   require 'cri'
 rescue LoadError => e
   $stderr.puts e
-  $stderr.puts "If you are using a Gemfile, make sure that the Gemfile contains nanoc ('gem \"nanoc\"')."
+  $stderr.puts "If you are using a Gemfile, make sure that the Gemfile contains Nanoc ('gem \"nanoc\"')."
   exit 1
 end
 
@@ -15,6 +13,7 @@ if Nanoc.on_windows?
   end
 end
 
+# @api private
 module Nanoc::CLI
   module Commands
   end
@@ -26,10 +25,6 @@ module Nanoc::CLI
   autoload 'StreamCleaners',      'nanoc/cli/stream_cleaners'
   autoload 'ErrorHandler',        'nanoc/cli/error_handler'
 
-  # Deprecated; use CommandRunner instead
-  # TODO: [in nanoc 4.0] remove me
-  autoload 'Command',             'nanoc/cli/command_runner'
-
   # @return [Boolean] true if debug output is enabled, false if not
   #
   # @since 3.2.0
@@ -47,7 +42,7 @@ module Nanoc::CLI
     @debug = boolean
   end
 
-  # Invokes the nanoc command-line tool with the given arguments.
+  # Invokes the Nanoc command-line tool with the given arguments.
   #
   # @param [Array<String>] args An array of command-line arguments
   #
@@ -121,9 +116,9 @@ module Nanoc::CLI
   #
   # @return [void]
   def self.load_custom_commands
-    if Nanoc::Site.cwd_is_nanoc_site?
-      site = Nanoc::Site.new('.')
-      site.config[:commands_dirs].each do |path|
+    if Nanoc::Int::SiteLoader.cwd_is_nanoc_site?
+      config = Nanoc::Int::ConfigLoader.new.new_from_cwd
+      config[:commands_dirs].each do |path|
         load_commands_at(path)
       end
     end
@@ -157,7 +152,7 @@ module Nanoc::CLI
   # @return [Cri::Command] The loaded command
   def self.load_command_at(filename, command_name = nil)
     # Load
-    code = File.read(filename)
+    code = File.read(filename, encoding: 'UTF-8')
     cmd = Cri::Command.define(code, filename)
 
     # Set name
@@ -185,11 +180,11 @@ module Nanoc::CLI
   def self.wrap_in_cleaning_stream(io)
     cio = ::Nanoc::CLI::CleaningStream.new(io)
 
-    unless self.enable_utf8?(io)
+    unless enable_utf8?(io)
       cio.add_stream_cleaner(Nanoc::CLI::StreamCleaners::UTF8)
     end
 
-    unless self.enable_ansi_colors?(io)
+    unless enable_ansi_colors?(io)
       cio.add_stream_cleaner(Nanoc::CLI::StreamCleaners::ANSIColors)
     end
 
