@@ -1,8 +1,8 @@
-# encoding: utf-8
-
 module Nanoc::CLI
   # A simple ANSI colorizer for strings. When given a string and a list of
   # attributes, it returns a colorized string.
+  #
+  # @api private
   module ANSIStringColorizer
     # TODO: complete mapping
     MAPPING = {
@@ -10,8 +10,8 @@ module Nanoc::CLI
       red: "\e[31m",
       green: "\e[32m",
       yellow: "\e[33m",
-      blue: "\e[34m"
-    }
+      blue: "\e[34m",
+    }.freeze
 
     # @param [String] s The string to colorize
     #
