@@ -1,8 +1,8 @@
-# encoding: utf-8
-
 module Nanoc::CLI
   # An output stream that passes output through stream cleaners. This can be
   # used to strip ANSI color sequences, for instance.
+  #
+  # @api private
   class CleaningStream
     # @param [IO, StringIO] stream The stream to wrap
     def initialize(stream)
@@ -114,13 +114,33 @@ module Nanoc::CLI
 
     # @see IO.winsize=
     def winsize=(arg)
-      @stream.winsize = (arg)
+      @stream.winsize = arg
+    end
+
+    # @see IO.sync
+    def sync
+      @stream.sync
+    end
+
+    # @see IO.sync=
+    def sync=(arg)
+      @stream.sync = arg
+    end
+
+    # @see IO.sync=
+    def external_encoding
+      @stream.external_encoding
+    end
+
+    # @see ARGF.set_encoding
+    def set_encoding(*args)
+      @stream.set_encoding(*args)
     end
 
     protected
 
     def _nanoc_clean(s)
-      @stream_cleaners.reduce(s) { |a, e| e.clean(a) }
+      @stream_cleaners.reduce(s.to_s) { |a, e| e.clean(a) }
     end
 
     def _nanoc_swallow_broken_pipe_errors_while
