@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 usage 'check [options] [names]'
 summary 'run issue checks'
 description "
@@ -14,7 +12,7 @@ module Nanoc::CLI::Commands
   class Check < ::Nanoc::CLI::CommandRunner
     def run
       validate_options_and_arguments
-      require_site
+      load_site
 
       runner = Nanoc::Extra::Checking::Runner.new(site)
 
@@ -33,7 +31,7 @@ module Nanoc::CLI::Commands
         end
 
       unless success
-        raise Nanoc::Errors::GenericTrivial, 'One or more checks failed'
+        raise Nanoc::Int::Errors::GenericTrivial, 'One or more checks failed'
       end
     end
 
@@ -41,8 +39,10 @@ module Nanoc::CLI::Commands
 
     def validate_options_and_arguments
       if arguments.empty? && !options[:all] && !options[:deploy] && !options[:list]
-        raise Nanoc::Errors::GenericTrivial,
-          'nothing to do (pass either --all, --deploy or --list or a list of checks)'
+        raise(
+          Nanoc::Int::Errors::GenericTrivial,
+          'nothing to do (pass either --all, --deploy or --list or a list of checks)',
+        )
       end
     end
   end
