@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 usage 'compile [options]'
 summary 'compile items of this site'
 description <<-EOS
@@ -17,20 +15,15 @@ SKIP - The item was deemed not outdated and was therefore not recompiled
 
 EOS
 
-option :a, :all,   '(ignored)'
-option :f, :force, '(ignored)'
-
 module Nanoc::CLI::Commands
   class Compile < ::Nanoc::CLI::CommandRunner
-    extend Nanoc::Memoization
-
     # Listens to compilation events and reacts to them. This abstract class
     # does not have a real implementation; subclasses should override {#start}
     # and set up notifications to listen to.
     #
     # @abstract Subclasses must override {#start} and may override {#stop}.
     class Listener
-      def initialize(_params = {})
+      def initialize(*)
       end
 
       # @param [Nanoc::CLI::CommandRunner] command_runner The command runner for this listener
@@ -70,15 +63,14 @@ module Nanoc::CLI::Commands
         require 'tempfile'
         setup_diffs
         old_contents = {}
-        Nanoc::NotificationCenter.on(:will_write_rep) do |rep, snapshot|
-          path = rep.raw_path(snapshot: snapshot)
+        Nanoc::Int::NotificationCenter.on(:will_write_rep) do |rep, path|
           old_contents[rep] = File.file?(path) ? File.read(path) : nil
         end
-        Nanoc::NotificationCenter.on(:rep_written) do |rep, path, _is_created, _is_modified|
+        Nanoc::Int::NotificationCenter.on(:rep_written) do |rep, path, _is_created, _is_modified|
           unless rep.binary?
             new_contents = File.file?(path) ? File.read(path) : nil
             if old_contents[rep] && new_contents
-              generate_diff_for(rep, old_contents[rep], new_contents)
+              generate_diff_for(path, old_contents[rep], new_contents)
             end
             old_contents.delete(rep)
           end
@@ -103,14 +95,14 @@ module Nanoc::CLI::Commands
         @diff_threads.each(&:join)
       end
 
-      def generate_diff_for(rep, old_content, new_content)
+      def generate_diff_for(path, old_content, new_content)
         return if old_content == new_content
 
         @diff_threads << Thread.new do
           # Generate diff
           diff = diff_strings(old_content, new_content)
-          diff.sub!(/^--- .*/,    '--- ' + rep.raw_path)
-          diff.sub!(/^\+\+\+ .*/, '+++ ' + rep.raw_path)
+          diff.sub!(/^--- .*/,    '--- ' + path)
+          diff.sub!(/^\+\+\+ .*/, '+++ ' + path)
 
           # Write diff
           @diff_lock.synchronize do
@@ -153,20 +145,20 @@ module Nanoc::CLI::Commands
         command_runner.options.fetch(:verbose, false)
       end
 
-      # @option params [Array<Nanoc::ItemRep>] :reps The list of item representations in the site
-      def initialize(params = {})
+      # @param [Enumerable<Nanoc::Int::ItemRep>] reps
+      def initialize(reps:)
         @times = {}
 
-        @reps = params.fetch(:reps)
+        @reps = reps
       end
 
       # @see Listener#start
       def start
-        Nanoc::NotificationCenter.on(:filtering_started) do |_rep, filter_name|
+        Nanoc::Int::NotificationCenter.on(:filtering_started) do |_rep, filter_name|
           @times[filter_name] ||= []
           @times[filter_name] << { start: Time.now }
         end
-        Nanoc::NotificationCenter.on(:filtering_ended) do |_rep, filter_name|
+        Nanoc::Int::NotificationCenter.on(:filtering_ended) do |_rep, filter_name|
           @times[filter_name].last[:stop] = Time.now
         end
       end
@@ -255,13 +247,13 @@ module Nanoc::CLI::Commands
         !ENV.key?('TRAVIS')
       end
 
-      def initialize(_params = {})
+      def initialize(*)
         @gc_count = 0
       end
 
       # @see Listener#start
       def start
-        Nanoc::NotificationCenter.on(:compilation_started) do |_rep|
+        Nanoc::Int::NotificationCenter.on(:compilation_started) do |_rep|
           if @gc_count % 20 == 0
             GC.enable
             GC.start
@@ -287,32 +279,32 @@ module Nanoc::CLI::Commands
 
       # @see Listener#start
       def start
-        Nanoc::NotificationCenter.on(:compilation_started) do |rep|
+        Nanoc::Int::NotificationCenter.on(:compilation_started) do |rep|
           puts "*** Started compilation of #{rep.inspect}"
         end
-        Nanoc::NotificationCenter.on(:compilation_ended) do |rep|
+        Nanoc::Int::NotificationCenter.on(:compilation_ended) do |rep|
           puts "*** Ended compilation of #{rep.inspect}"
           puts
         end
-        Nanoc::NotificationCenter.on(:compilation_failed) do |rep, e|
+        Nanoc::Int::NotificationCenter.on(:compilation_failed) do |rep, e|
           puts "*** Suspended compilation of #{rep.inspect}: #{e.message}"
         end
-        Nanoc::NotificationCenter.on(:cached_content_used) do |rep|
+        Nanoc::Int::NotificationCenter.on(:cached_content_used) do |rep|
           puts "*** Used cached compiled content for #{rep.inspect} instead of recompiling"
         end
-        Nanoc::NotificationCenter.on(:filtering_started) do |rep, filter_name|
+        Nanoc::Int::NotificationCenter.on(:filtering_started) do |rep, filter_name|
           puts "*** Started filtering #{rep.inspect} with #{filter_name}"
         end
-        Nanoc::NotificationCenter.on(:filtering_ended) do |rep, filter_name|
+        Nanoc::Int::NotificationCenter.on(:filtering_ended) do |rep, filter_name|
           puts "*** Ended filtering #{rep.inspect} with #{filter_name}"
         end
-        Nanoc::NotificationCenter.on(:visit_started) do |item|
+        Nanoc::Int::NotificationCenter.on(:visit_started) do |item|
           puts "*** Started visiting #{item.inspect}"
         end
-        Nanoc::NotificationCenter.on(:visit_ended) do |item|
+        Nanoc::Int::NotificationCenter.on(:visit_ended) do |item|
           puts "*** Ended visiting #{item.inspect}"
         end
-        Nanoc::NotificationCenter.on(:dependency_created) do |src, dst|
+        Nanoc::Int::NotificationCenter.on(:dependency_created) do |src, dst|
           puts "*** Dependency created from #{src.inspect} onto #{dst.inspect}"
         end
       end
@@ -320,19 +312,18 @@ module Nanoc::CLI::Commands
 
     # Prints file actions (created, updated, deleted, identical, skipped)
     class FileActionPrinter < Listener
-      # @option params [Array<Nanoc::ItemRep>] :reps The list of item representations in the site
-      def initialize(params = {})
+      def initialize(reps:)
         @start_times = {}
 
-        @reps = params.fetch(:reps)
+        @reps = reps
       end
 
       # @see Listener#start
       def start
-        Nanoc::NotificationCenter.on(:compilation_started) do |rep|
+        Nanoc::Int::NotificationCenter.on(:compilation_started) do |rep|
           @start_times[rep.raw_path] = Time.now
         end
-        Nanoc::NotificationCenter.on(:rep_written) do |_rep, path, is_created, is_modified|
+        Nanoc::Int::NotificationCenter.on(:rep_written) do |_rep, path, is_created, is_modified|
           duration = path && @start_times[path] ? Time.now - @start_times[path] : nil
           action =
             case
@@ -367,16 +358,17 @@ module Nanoc::CLI::Commands
       end
     end
 
-    def initialize(options, arguments, command, params = {})
-      super(options, arguments, command)
-      @listener_classes = params.fetch(:listener_classes, default_listener_classes)
+    attr_accessor :listener_classes
+
+    def initialize(options, arguments, command)
+      super
+      @listener_classes = default_listener_classes
     end
 
     def run
       time_before = Time.now
 
       load_site
-      check_for_deprecated_usage
 
       puts 'Compiling site…'
       run_listeners_while do
@@ -403,7 +395,7 @@ module Nanoc::CLI::Commands
         Nanoc::CLI::Commands::Compile::DebugPrinter,
         Nanoc::CLI::Commands::Compile::TimingRecorder,
         Nanoc::CLI::Commands::Compile::GCController,
-        Nanoc::CLI::Commands::Compile::FileActionPrinter
+        Nanoc::CLI::Commands::Compile::FileActionPrinter,
       ]
     end
 
@@ -432,22 +424,7 @@ module Nanoc::CLI::Commands
     end
 
     def reps
-      site.items.map(&:reps).flatten
-    end
-    memoize :reps
-
-    def check_for_deprecated_usage
-      # Check presence of --all option
-      if options.key?(:all) || options.key?(:force)
-        $stderr.puts 'Warning: the --force option (and its deprecated --all alias) are, as of nanoc 3.2, no longer supported and have no effect.'
-      end
-
-      # Warn if trying to compile a single item
-      if arguments.size == 1
-        $stderr.puts '-' * 80
-        $stderr.puts 'Note: As of nanoc 3.2, it is no longer possible to compile a single item. When invoking the “compile” command, all items in the site will be compiled.'
-        $stderr.puts '-' * 80
-      end
+      site.compiler.reps
     end
 
     def prune_config
