@@ -1,14 +1,12 @@
-# encoding: utf-8
-
 usage 'prune'
-summary 'remove files not managed by nanoc from the output directory'
+summary 'remove files not managed by Nanoc from the output directory'
 description <<-EOS
 Find all files in the output directory that do not correspond to an item
-managed by nanoc and remove them. Since this is a hazardous operation, an
+managed by Nanoc and remove them. Since this is a hazardous operation, an
 additional `--yes` flag is needed as confirmation.
 
 Also see the `auto_prune` configuration option in `nanoc.yaml` (`config.yaml`
-for older nanoc sites), which will automatically prune after compilation.
+for older Nanoc sites), which will automatically prune after compilation.
 EOS
 
 flag :y, :yes,       'confirm deletion'
@@ -18,6 +16,9 @@ module Nanoc::CLI::Commands
   class Prune < ::Nanoc::CLI::CommandRunner
     def run
       load_site
+      # FIXME: ugly to preprocess here
+      site.compiler.action_provider.preprocess(site)
+      site.compiler.build_reps
 
       if options.key?(:yes)
         Nanoc::Extra::Pruner.new(site, exclude: prune_config_exclude).run
@@ -26,7 +27,7 @@ module Nanoc::CLI::Commands
       else
         $stderr.puts 'WARNING: Since the prune command is a destructive command, it requires an additional --yes flag in order to work.'
         $stderr.puts
-        $stderr.puts 'Please ensure that the output directory does not contain any files (such as images or stylesheets) that are necessary but are not managed by nanoc. If you want to get a list of all files that would be removed, pass --dry-run.'
+        $stderr.puts 'Please ensure that the output directory does not contain any files (such as images or stylesheets) that are necessary but are not managed by Nanoc. If you want to get a list of all files that would be removed, pass --dry-run.'
         exit 1
       end
     end
