@@ -1,25 +1,23 @@
-# encoding: utf-8
-
 summary 'show all available plugins'
 aliases :info
 usage 'show-plugins [options]'
 description <<-EOS
-Show a list of available plugins, including filters, data sources and VCSes.
-If the current directory contains a nanoc web site, the plugins defined in this site will be shown as well.
+Show a list of available plugins, including filters and data sources.
+If the current directory contains a Nanoc web site, the plugins defined in this site will be shown as well.
 EOS
 
 module Nanoc::CLI::Commands
   class ShowPlugins < ::Nanoc::CLI::CommandRunner
     def run
       # Check arguments
-      if arguments.size != 0
-        raise Nanoc::Errors::GenericTrivial, "usage: #{command.usage}"
+      if arguments.any?
+        raise Nanoc::Int::Errors::GenericTrivial, "usage: #{command.usage}"
       end
 
       # Get list of plugins (before and after)
-      plugins_before = Nanoc::Plugin.all
+      plugins_before = Nanoc::Int::PluginRegistry.instance.all
       site.code_snippets if site
-      plugins_after  = Nanoc::Plugin.all
+      plugins_after = Nanoc::Int::PluginRegistry.instance.all
 
       # Divide list of plugins into builtin and custom
       plugins_builtin = plugins_before
@@ -34,7 +32,7 @@ module Nanoc::CLI::Commands
       PLUGIN_CLASS_ORDER.each do |superclass|
         plugins_with_this_superclass = {
           builtin: plugins_builtin.select { |p| p[:superclass] == superclass },
-          custom: plugins_custom.select  { |p| p[:superclass] == superclass }
+          custom: plugins_custom.select { |p| p[:superclass] == superclass },
         }
 
         # Print kind
@@ -60,7 +58,7 @@ module Nanoc::CLI::Commands
             puts format(
               "    %-#{max_identifiers_length}s (%s)",
               plugin[:identifiers].join(', '),
-              plugin[:class].to_s.sub(/^::/, '')
+              plugin[:class].to_s.sub(/^::/, ''),
             )
           end
         end
@@ -73,17 +71,15 @@ module Nanoc::CLI::Commands
 
     PLUGIN_CLASS_ORDER = [
       Nanoc::Filter,
-      Nanoc::Extra::VCS,
       Nanoc::DataSource,
-      Nanoc::Extra::Deployer
-    ] unless defined? PLUGIN_CLASS_ORDER
+      Nanoc::Extra::Deployer,
+    ].freeze unless defined? PLUGIN_CLASS_ORDER
 
     PLUGIN_CLASSES = {
       Nanoc::Filter          => 'Filters',
       Nanoc::DataSource      => 'Data Sources',
-      Nanoc::Extra::VCS      => 'VCSes',
-      Nanoc::Extra::Deployer => 'Deployers'
-    } unless defined? PLUGIN_CLASSES
+      Nanoc::Extra::Deployer => 'Deployers',
+    }.freeze unless defined? PLUGIN_CLASSES
 
     def name_for_plugin_class(klass)
       PLUGIN_CLASSES[klass]
