@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 usage 'view [options]'
 summary 'start the web server that serves static files'
 description <<-EOS
@@ -20,13 +18,12 @@ module Nanoc::CLI::Commands
       load_adsf
       require 'rack'
 
-      # Make sure we are in a nanoc site directory
-      require_site
+      load_site
 
       # Set options
       options_for_rack = {
         Port: (options[:port] || 3000).to_i,
-        Host: (options[:host] || '0.0.0.0')
+        Host: (options[:host] || '0.0.0.0'),
       }
 
       # Get handler
