@@ -1,34 +1,30 @@
-# encoding: utf-8
-
 module Nanoc::CLI
   # Catches errors and prints nice diagnostic messages, then exits.
   #
   # @api private
   class ErrorHandler
-    # @option params [Nanoc::CLI::Command, nil] command The command that is
+    # @param [Nanoc::CLI::Command, nil] command The command that is
     #   currently being executed, or nil if there is none
-    def initialize(params = {})
-      @command = params[:command]
+    def initialize(command: nil)
+      @command = command
     end
 
     # Enables error handling in the given block.
     #
-    # @option params [Nanoc::CLI::Command, nil] command The command that is
+    # @param [Nanoc::CLI::Command, nil] command The command that is
     #   currently being executed, or nil if there is none
     #
     # @return [void]
-    def self.handle_while(params = {}, &block)
+    def self.handle_while(command: nil, &block)
       if @disabled
         yield
       else
-        new(params).handle_while(&block)
+        new(command: command).handle_while(&block)
       end
     end
 
     # Disables error handling. This is used by the test cases to prevent error
     # from being handled by the CLI while tests are running.
-    #
-    # @api private
     def self.disable
       @disabled = true
     end
@@ -36,8 +32,6 @@ module Nanoc::CLI
     # Re-enables error handling after it was disabled. This is used by the test
     # cases to prevent error from being handled by the CLI while tests are
     # running.
-    #
-    # @api private
     def self.enable
       @disabled = false
     end
@@ -46,8 +40,6 @@ module Nanoc::CLI
     # called directly; use {Nanoc::CLI::ErrorHandler.handle_while} instead.
     #
     # @return [void]
-    #
-    # @api private
     def handle_while(&_block)
       # Set exit handler
       %w( INT TERM ).each do |signal|
@@ -70,7 +62,7 @@ module Nanoc::CLI
 
       # Run
       yield
-    rescue Nanoc::Errors::GenericTrivial => e
+    rescue Nanoc::Int::Errors::GenericTrivial => e
       $stderr.puts "Error: #{e.message}"
       exit(1)
     rescue Interrupt
@@ -113,8 +105,6 @@ module Nanoc::CLI
     #
     # @param [IO] stream The stream to write the description too
     #
-    # @api private
-    #
     # @return [void]
     def write_compact_error(error, stream)
       # Header
@@ -136,8 +126,6 @@ module Nanoc::CLI
     #
     # @param [IO] stream The stream to write the description too
     #
-    # @api private
-    #
     # @return [void]
     def write_verbose_error(error, stream)
       # Header
@@ -147,12 +135,11 @@ module Nanoc::CLI
       write_error_message(stream, error, verbose: true)
       write_compilation_stack(stream, error, verbose: true)
       write_stack_trace(stream, error, verbose: true)
-      write_version_information(stream,        verbose: true)
-      write_system_information(stream,        verbose: true)
-      write_installed_gems(stream,        verbose: true)
-      write_environment(stream,        verbose: true)
-      write_gemfile_lock(stream,        verbose: true)
-      write_load_paths(stream,        verbose: true)
+      write_version_information(stream, verbose: true)
+      write_system_information(stream, verbose: true)
+      write_installed_gems(stream, verbose: true)
+      write_gemfile_lock(stream, verbose: true)
+      write_load_paths(stream, verbose: true)
     end
 
     protected
@@ -164,12 +151,12 @@ module Nanoc::CLI
       Nanoc::CLI.debug?
     end
 
-    # @return [Nanoc::Site] The site that is currently being processed
+    # @return [Nanoc::Int::Site] The site that is currently being processed
     def site
       @command && @command.site
     end
 
-    # @return [Nanoc::Compiler] The compiler for the current site
+    # @return [Nanoc::Int::Compiler] The compiler for the current site
     def compiler
       site && site.compiler
     end
@@ -219,8 +206,8 @@ module Nanoc::CLI
       'redcloth'       => 'RedCloth',
       'rubypants'      => 'rubypants',
       'sass'           => 'sass',
-      'w3c_validators' => 'w3c_validators'
-    }
+      'w3c_validators' => 'w3c_validators',
+    }.freeze
 
     # Attempts to find a resolution for the given error, or nil if no
     # resolution can be automatically obtained.
@@ -238,7 +225,7 @@ module Nanoc::CLI
 
         # Build message
         if gem_name
-          if self.using_bundler?
+          if using_bundler?
             'Make sure the gem is added to Gemfile and run `bundle install`.'
           else
             "Install the '#{gem_name}' gem using `gem install #{gem_name}`."
@@ -259,9 +246,9 @@ module Nanoc::CLI
       defined?(Bundler) && Bundler::SharedHelpers.in_bundle?
     end
 
-    def write_section_header(stream, title, params = {})
+    def write_section_header(stream, title, verbose: false)
       stream.puts
-      if params[:verbose]
+      if verbose
         stream.puts '===== ' + title.upcase + ':'
       else
         stream.puts "\e[1m\e[31m" + title + ':' + "\e[0m"
@@ -269,22 +256,22 @@ module Nanoc::CLI
       stream.puts
     end
 
-    def write_error_message(stream, error, params = {})
-      write_section_header(stream, 'Message', params)
+    def write_error_message(stream, error, verbose: false)
+      write_section_header(stream, 'Message', verbose: verbose)
 
       stream.puts "#{error.class}: #{error.message}"
       resolution = resolution_for(error)
-      stream.puts "#{resolution}" if resolution
+      stream.puts resolution.to_s if resolution
     end
 
-    def write_compilation_stack(stream, _error, params = {})
-      write_section_header(stream, 'Compilation stack', params)
+    def write_compilation_stack(stream, _error, verbose: false)
+      write_section_header(stream, 'Compilation stack', verbose: verbose)
 
       if stack.empty?
         stream.puts '  (empty)'
       else
         stack.reverse_each do |obj|
-          if obj.is_a?(Nanoc::ItemRep)
+          if obj.is_a?(Nanoc::Int::ItemRep)
             stream.puts "  - [item]   #{obj.item.identifier} (rep #{obj.name})"
           else # layout
             stream.puts "  - [layout] #{obj.identifier}"
@@ -293,63 +280,54 @@ module Nanoc::CLI
       end
     end
 
-    def write_stack_trace(stream, error, params = {})
-      is_verbose = params.fetch(:verbose, false)
+    def write_stack_trace(stream, error, verbose: false)
+      write_section_header(stream, 'Stack trace', verbose: verbose)
 
-      write_section_header(stream, 'Stack trace', params)
-
-      count = is_verbose ? -1 : 10
+      count = verbose ? -1 : 10
       error.backtrace[0...count].each_with_index do |item, index|
         stream.puts "  #{index}. #{item}"
       end
-      if !is_verbose && error.backtrace.size > count
+      if !verbose && error.backtrace.size > count
         stream.puts "  ... #{error.backtrace.size - count} more lines omitted. See full crash log for details."
       end
     end
 
     def write_issue_link(stream, _params = {})
       stream.puts
-      stream.puts 'If you believe this is a bug in nanoc, please do report it at'
+      stream.puts 'If you believe this is a bug in Nanoc, please do report it at'
       stream.puts '-> https://github.com/nanoc/nanoc/issues/new <-'
       stream.puts
       stream.puts 'A detailed crash log has been written to ./crash.log.'
     end
 
-    def write_version_information(stream, params = {})
-      write_section_header(stream, 'Version information', params)
+    def write_version_information(stream, verbose: false)
+      write_section_header(stream, 'Version information', verbose: verbose)
       stream.puts Nanoc.version_information
     end
 
-    def write_system_information(stream, params = {})
+    def write_system_information(stream, verbose: false)
       uname = `uname -a`
-      write_section_header(stream, 'System information', params)
+      write_section_header(stream, 'System information', verbose: verbose)
       stream.puts uname
     rescue Errno::ENOENT
     end
 
-    def write_installed_gems(stream, params = {})
-      write_section_header(stream, 'Installed gems', params)
+    def write_installed_gems(stream, verbose: false)
+      write_section_header(stream, 'Installed gems', verbose: verbose)
       gems_and_versions.each do |g|
         stream.puts "  #{g.first} #{g.last.join(', ')}"
       end
     end
 
-    def write_environment(stream, params = {})
-      write_section_header(stream, 'Environment', params)
-      ENV.sort.each do |e|
-        stream.puts "#{e.first} => #{e.last.inspect}"
-      end
-    end
-
-    def write_gemfile_lock(stream, params = {})
+    def write_gemfile_lock(stream, verbose: false)
       if File.exist?('Gemfile.lock')
-        write_section_header(stream, 'Gemfile.lock', params)
+        write_section_header(stream, 'Gemfile.lock', verbose: verbose)
         stream.puts File.read('Gemfile.lock')
       end
     end
 
-    def write_load_paths(stream, params = {})
-      write_section_header(stream, 'Load paths', params)
+    def write_load_paths(stream, verbose: false)
+      write_section_header(stream, 'Load paths', verbose: verbose)
       $LOAD_PATH.each_with_index do |i, index|
         stream.puts "  #{index}. #{i}"
       end
