@@ -1,10 +1,10 @@
-# encoding: utf-8
-
 require 'singleton'
 
 module Nanoc::CLI
   # Nanoc::CLI::Logger is a singleton class responsible for generating
   # feedback in the terminal.
+  #
+  # @api private
   class Logger
     # Maps actions (`:create`, `:update`, `:identical`, `:skip` and `:delete`)
     # onto their ANSI color codes.
@@ -14,7 +14,7 @@ module Nanoc::CLI
       identical: '',    # (nothing)
       skip: '',         # (nothing)
       delete: "\e[31m"  # red
-    }
+    }.freeze
 
     include Singleton
 
@@ -41,12 +41,15 @@ module Nanoc::CLI
     def file(level, action, name, duration = nil)
       log(
         level,
-        format('%s%12s%s  %s%s',
+        format(
+          '%s%12s%s  %s%s',
           ACTION_COLORS[action.to_sym],
           action,
           "\e[0m",
           duration.nil? ? '' : format('[%2.2fs]  ', duration),
-          name))
+          name,
+        ),
+      )
     end
 
     # Logs a message.
