@@ -1,13 +1,12 @@
-# encoding: utf-8
-
 module ::Nanoc::Extra::Checking::Checks
+  # @api private
   class CSS < ::Nanoc::Extra::Checking::Check
     identifier :css
 
     def run
       require 'w3c_validators'
 
-      Dir[site.config[:output_dir] + '/**/*.css'].each do |filename|
+      Dir[@config[:output_dir] + '/**/*.css'].each do |filename|
         results = ::W3CValidators::CSSValidator.new.validate_file(filename)
         lines = File.readlines(filename)
         results.errors.each do |e|
