@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 require 'net/http'
 require 'net/https'
 require 'nokogiri'
@@ -8,13 +6,15 @@ require 'uri'
 
 module ::Nanoc::Extra::Checking::Checks
   # A validator that verifies that all external links point to a location that exists.
+  #
+  # @api private
   class ExternalLinks < ::Nanoc::Extra::Checking::Check
     identifiers :external_links, :elinks
 
     def run
       # Find all broken external hrefs
       # TODO: de-duplicate this (duplicated in internal links check)
-      filenames = output_filenames.select { |f| File.extname(f) == '.html' }
+      filenames = output_filenames.select { |f| File.extname(f) == '.html' && !excluded_file?(f) }
       hrefs_with_filenames = ::Nanoc::Extra::LinkCollector.new(filenames, :external).filenames_per_href
       results = select_invalid(hrefs_with_filenames.keys)
 
@@ -89,6 +89,9 @@ module ::Nanoc::Extra::Checking::Checks
         return Result.new(href, 'invalid URI')
       end
 
+      # Skip excluded URLs
+      return nil if excluded?(href)
+
       # Skip non-HTTP URLs
       return nil if url.scheme !~ /^https?$/
 
@@ -139,11 +142,12 @@ module ::Nanoc::Extra::Checking::Checks
     end
 
     def path_for_url(url)
-      if url.path.nil? || url.path.empty?
-        path = '/'
-      else
-        path = url.path
-      end
+      path =
+        if url.path.nil? || url.path.empty?
+          '/'
+        else
+          url.path
+        end
 
       if url.query
         path << '?' << url.query
@@ -161,5 +165,15 @@ module ::Nanoc::Extra::Checking::Checks
       end
       http.request(req)
     end
+
+    def excluded?(href)
+      excludes = @config.fetch(:checks, {}).fetch(:external_links, {}).fetch(:exclude, [])
+      excludes.any? { |pattern| Regexp.new(pattern).match(href) }
+    end
+
+    def excluded_file?(file)
+      excludes = @config.fetch(:checks, {}).fetch(:external_links, {}).fetch(:exclude_files, [])
+      excludes.any? { |pattern| Regexp.new(pattern).match(file) }
+    end
   end
 end
