@@ -1,13 +1,12 @@
-# encoding: utf-8
-
 module ::Nanoc::Extra::Checking::Checks
+  # @api private
   class HTML < ::Nanoc::Extra::Checking::Check
     identifier :html
 
     def run
       require 'w3c_validators'
 
-      Dir[site.config[:output_dir] + '/**/*.{htm,html}'].each do |filename|
+      Dir[@config[:output_dir] + '/**/*.{htm,html}'].each do |filename|
         results = ::W3CValidators::MarkupValidator.new.validate_file(filename)
         lines = File.readlines(filename)
         results.errors.each do |e|
