@@ -1,9 +1,9 @@
-# encoding: utf-8
-
 require 'uri'
 
 module Nanoc::Extra::Checking::Checks
   # A check that verifies that all internal links point to a location that exists.
+  #
+  # @api private
   class InternalLinks < ::Nanoc::Extra::Checking::Check
     # Starts the validator. The results will be printed to stdout.
     #
@@ -34,7 +34,7 @@ module Nanoc::Extra::Checking::Checks
       return true if href == '.'
 
       # Skip hrefs that are specified in the exclude configuration
-      return true if self.excluded?(href)
+      return true if excluded?(href)
 
       # Remove target
       path = href.sub(/#.*$/, '')
@@ -48,24 +48,25 @@ module Nanoc::Extra::Checking::Checks
       path = URI.unescape(path)
 
       # Make absolute
-      if path[0, 1] == '/'
-        path = @site.config[:output_dir] + path
-      else
-        path = ::File.expand_path(path, ::File.dirname(origin))
-      end
+      path =
+        if path[0, 1] == '/'
+          @config[:output_dir] + path
+        else
+          ::File.expand_path(path, ::File.dirname(origin))
+        end
 
       # Check whether file exists
       return true if File.file?(path)
 
       # Check whether directory with index file exists
-      return true if File.directory?(path) && @site.config[:index_filenames].any? { |fn| File.file?(File.join(path, fn)) }
+      return true if File.directory?(path) && @config[:index_filenames].any? { |fn| File.file?(File.join(path, fn)) }
 
       # Nope :(
       false
     end
 
     def excluded?(href)
-      excludes =  @site.config.fetch(:checks, {}).fetch(:internal_links, {}).fetch(:exclude, [])
+      excludes = @config.fetch(:checks, {}).fetch(:internal_links, {}).fetch(:exclude, [])
       excludes.any? { |pattern| Regexp.new(pattern).match(href) }
     end
   end
