@@ -1,8 +1,8 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Checking::Checks
   # A check that verifies HTML files do not reference external resources with
   # URLs that would trigger "mixed content" warnings.
+  #
+  # @api private
   class MixedContent < ::Nanoc::Extra::Checking::Check
     PROTOCOL_PATTERN = /^(\w+):\/\//
 
@@ -25,7 +25,7 @@ module Nanoc::Extra::Checking::Checks
     def guaranteed_insecure?(href)
       protocol = PROTOCOL_PATTERN.match(href)
 
-      protocol && protocol[1].downcase == 'http'
+      protocol && protocol[1].casecmp('http').zero?
     end
   end
 end
