@@ -1,12 +1,9 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Checking::Checks
+  # @api private
   class Stale < ::Nanoc::Extra::Checking::Check
     def run
       require 'set'
 
-      item_rep_paths = Set.new(@site.items.map(&:reps).flatten.map(&:raw_path))
-
       output_filenames.each do |f|
         next if pruner.filename_excluded?(f)
         next if item_rep_paths.include?(f)
@@ -19,8 +16,18 @@ module Nanoc::Extra::Checking::Checks
 
     protected
 
+    def item_rep_paths
+      @item_rep_paths ||=
+        Set.new(
+          @items
+            .flat_map(&:reps)
+            .map(&:unwrap)
+            .flat_map(&:raw_paths)
+            .flat_map(&:values))
+    end
+
     def pruner
-      exclude_config = @site.config.fetch(:prune, {}).fetch(:exclude, [])
+      exclude_config = @config.fetch(:prune, {}).fetch(:exclude, [])
       @pruner ||= Nanoc::Extra::Pruner.new(@site, exclude: exclude_config)
     end
   end
