@@ -1,12 +1,11 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Checking
+  # @api private
   class DSL
     attr_reader :deploy_checks
 
     def self.from_file(filename)
       dsl = new
-      dsl.instance_eval File.read(filename)
+      dsl.instance_eval(File.read(filename), filename)
       dsl
     end
 
