@@ -1,13 +1,11 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Checking
   # Runner is reponsible for running issue checks.
   #
   # @api private
   class Runner
-    CHECKS_FILENAMES = ['Checks', 'Checks.rb', 'checks', 'checks.rb']
+    CHECKS_FILENAMES = ['Checks', 'Checks.rb', 'checks', 'checks.rb'].freeze
 
-    # @param [Nanoc::Site] site The nanoc site this runner is for
+    # @param [Nanoc::Int::Site] site The Nanoc site this runner is for
     def initialize(site)
       @site = site
     end
@@ -21,7 +19,7 @@ module Nanoc::Extra::Checking
     def dsl_present?
       checks_filename && File.file?(checks_filename)
     end
-    alias_method :has_dsl?, :dsl_present?
+    alias has_dsl? dsl_present?
 
     # Lists all available checks on stdout.
     #
@@ -64,16 +62,15 @@ module Nanoc::Extra::Checking
       run_check_classes(check_classes_named(check_class_names))
     end
 
-    protected
-
     def load_dsl_if_available
       @dsl_loaded ||= false
       unless @dsl_loaded
-        if self.dsl_present?
-          @dsl = Nanoc::Extra::Checking::DSL.from_file(checks_filename)
-        else
-          @dsl = nil
-        end
+        @dsl =
+          if dsl_present?
+            Nanoc::Extra::Checking::DSL.from_file(checks_filename)
+          else
+            nil
+          end
         @dsl_loaded = true
       end
     end
@@ -81,7 +78,7 @@ module Nanoc::Extra::Checking
     def require_dsl
       load_dsl_if_available
       if dsl.nil?
-        raise Nanoc::Errors::GenericTrivial, "No checks defined (no #{CHECKS_FILENAMES.first} file present)"
+        raise Nanoc::Int::Errors::GenericTrivial, "No checks defined (no #{CHECKS_FILENAMES.first} file present)"
       end
     end
 
@@ -102,7 +99,7 @@ module Nanoc::Extra::Checking
     def check_classes_named(n)
       n.map do |a|
         klass = Nanoc::Extra::Checking::Check.named(a)
-        raise Nanoc::Errors::GenericTrivial, "Unknown check: #{a}" if klass.nil?
+        raise Nanoc::Int::Errors::GenericTrivial, "Unknown check: #{a}" if klass.nil?
         klass
       end
     end
@@ -110,13 +107,16 @@ module Nanoc::Extra::Checking
     def run_checks(classes)
       return [] if classes.empty?
 
+      # TODO: remove me
+      @site.compiler.build_reps
+
       checks = []
       issues = Set.new
       length = classes.map { |c| c.identifier.to_s.length }.max + 18
       classes.each do |klass|
         print format("  %-#{length}s", "Running check #{klass.identifier}… ")
 
-        check = klass.new(@site)
+        check = klass.create(@site)
         check.run
 
         checks << check
@@ -129,17 +129,21 @@ module Nanoc::Extra::Checking
       issues
     end
 
+    def subject_to_s(s)
+      s || '(global)'
+    end
+
     def print_issues(issues)
       require 'colored'
 
       return if issues.empty?
       puts 'Issues found!'
-      issues.group_by(&:subject).to_a.sort_by(&:first).each do |pair|
+      issues.group_by(&:subject).to_a.sort_by { |s| subject_to_s(s.first) }.each do |pair|
         subject = pair.first
         issues  = pair.last
         next if issues.empty?
 
-        puts "  #{subject}:"
+        puts "  #{subject_to_s(subject)}:"
         issues.each do |i|
           puts "    [ #{'ERROR'.red} ] #{i.check_class.identifier} - #{i.description}"
         end
