@@ -1,8 +1,7 @@
-# encoding: utf-8
-
 module Nanoc::Extra
+  # @api private
   module PathnameExtensions
-    def components
+    def __nanoc_components
       components = []
       tmp = self
       loop do
@@ -14,12 +13,13 @@ module Nanoc::Extra
       components.reverse
     end
 
-    def include_component?(component)
-      components.include?(component)
+    def __nanoc_include_component?(component)
+      __nanoc_components.include?(component)
     end
   end
 end
 
+# @api private
 class ::Pathname
   include ::Nanoc::Extra::PathnameExtensions
 end
