@@ -1,12 +1,12 @@
-# encoding: utf-8
-
 module Nanoc::Extra
   # Represents a deployer, an object that allows uploading the compiled site
   # to a specific (remote) location.
   #
   # @abstract Subclass and override {#run} to implement a custom filter.
+  #
+  # @api private
   class Deployer
-    extend Nanoc::PluginRegistry::PluginMethods
+    extend Nanoc::Int::PluginRegistry::PluginMethods
 
     # @return [String] The path to the directory that contains the files to
     #   upload. It should not have a trailing slash.
@@ -18,19 +18,19 @@ module Nanoc::Extra
     # @return [Boolean] true if the deployer should only show what would be
     #   deployed instead of doing the actual deployment
     attr_reader :dry_run
-    alias_method :dry_run?, :dry_run
+    alias dry_run? dry_run
 
     # @param [String] source_path The path to the directory that contains the
     #   files to upload. It should not have a trailing slash.
     #
     # @return [Hash] config The deployer configuration
     #
-    # @option params [Boolean] :dry_run (false) true if the deployer should
+    # @param [Boolean] dry_run true if the deployer should
     #   only show what would be deployed instead actually deploying
-    def initialize(source_path, config, params = {})
+    def initialize(source_path, config, dry_run: false)
       @source_path  = source_path
       @config       = config
-      @dry_run      = params.fetch(:dry_run) { false }
+      @dry_run      = dry_run
     end
 
     # Performs the actual deployment.
