@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Deployers
   # A deployer that deploys a site using [fog](https://github.com/geemus/fog).
   #
@@ -20,6 +18,8 @@ module Nanoc::Extra::Deployers
   #       provider:   local
   #       local_root: ~/myCloud
   #       bucket:     nanoc-site-staging
+  #
+  # @api private
   class Fog < ::Nanoc::Extra::Deployer
     # @see Nanoc::Extra::Deployer#run
     def run
@@ -37,7 +37,7 @@ module Nanoc::Extra::Deployers
       error 'The path requires no trailing slash' if path && path[-1, 1] == '/'
 
       # Mock if necessary
-      if self.dry_run?
+      if dry_run?
         puts 'Dry run - simulation'
         ::Fog.mock!
       end
@@ -69,8 +69,9 @@ module Nanoc::Extra::Deployers
         truncated = set.is_truncated
         files += set
       end
-      keys_to_destroy = files.all.map(&:key)
+      keys_to_destroy = files.map(&:key)
       keys_to_invalidate = []
+      etags = read_etags(files)
 
       # Upload all the files in the output folder to the clouds
       puts 'Uploading local files'
@@ -78,12 +79,7 @@ module Nanoc::Extra::Deployers
         files = Dir['**/*'].select { |f| File.file?(f) }
         files.each do |file_path|
           key = path ? File.join(path, file_path) : file_path
-          directory.files.create(
-            key: key,
-            body: File.open(file_path),
-            public: true)
-          keys_to_destroy.delete(key)
-          keys_to_invalidate.push(key)
+          upload(key, file_path, etags, keys_to_destroy, keys_to_invalidate, directory)
         end
       end
 
@@ -99,7 +95,7 @@ module Nanoc::Extra::Deployers
         keys_to_invalidate.concat(keys_to_destroy)
         cdn = ::Fog::CDN.new(config)
         # fog cannot mock CDN requests
-        unless self.dry_run?
+        unless dry_run?
           distribution = cdn.get_distribution(cdn_id)
           # usual limit per invalidation: 1000 objects
           keys_to_invalidate.each_slice(1000) do |paths|
@@ -113,6 +109,44 @@ module Nanoc::Extra::Deployers
 
     private
 
+    def upload(key, file_path, etags, keys_to_destroy, keys_to_invalidate, dir)
+      keys_to_destroy.delete(key)
+
+      return unless needs_upload?(key, file_path, etags)
+
+      dir.files.create(
+        key: key,
+        body: File.open(file_path),
+        public: true)
+      keys_to_invalidate.push(key)
+    end
+
+    def needs_upload?(key, file_path, etags)
+      remote_etag = etags[key]
+      return true if remote_etag.nil?
+
+      local_etag = calc_local_etag(file_path)
+      remote_etag != local_etag
+    end
+
+    def read_etags(files)
+      case config[:provider]
+      when 'aws'
+        files.each_with_object({}) do |file, etags|
+          etags[file.key] = file.etag
+        end
+      else
+        {}
+      end
+    end
+
+    def calc_local_etag(file_path)
+      case config[:provider]
+      when 'aws'
+        Digest::MD5.file(file_path).hexdigest
+      end
+    end
+
     # Prints the given message on stderr and exits.
     def error(msg)
       raise RuntimeError.new(msg)
