@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Extra::Deployers
   # A deployer that deploys a site using rsync.
   #
@@ -18,6 +16,8 @@ module Nanoc::Extra::Deployers
   #       kind: rsync
   #       dst: "ectype:sites/stoneship-staging/public"
   #       options: [ "-glpPrtvz" ]
+  #
+  # @api private
   class Rsync < ::Nanoc::Extra::Deployer
     # Default rsync options
     DEFAULT_OPTIONS = [
@@ -32,8 +32,8 @@ module Nanoc::Extra::Deployers
       '--compress',
       '--exclude=".hg"',
       '--exclude=".svn"',
-      '--exclude=".git"'
-    ]
+      '--exclude=".git"',
+    ].freeze
 
     # @see Nanoc::Extra::Deployer#run
     def run
