@@ -1,10 +1,9 @@
-# encoding: utf-8
-
 require 'open3'
 
 module Nanoc::Extra
+  # @api private
   class Piper
-    class Error < ::Nanoc::Errors::Generic
+    class Error < ::Nanoc::Int::Errors::Generic
       def initialize(command, exit_code)
         @command   = command
         @exit_code = exit_code
@@ -15,11 +14,11 @@ module Nanoc::Extra
       end
     end
 
-    # @option [IO] :stdout ($stdout)
-    # @option [IO] :stderr ($stderr)
-    def initialize(params = {})
-      @stdout = params.fetch(:stdout, $stdout)
-      @stderr = params.fetch(:stderr, $stderr)
+    # @param [IO] stdout
+    # @param [IO] stderr
+    def initialize(stdout: $stdout, stderr: $stderr)
+      @stdout = stdout
+      @stderr = stderr
     end
 
     # @param [Array<String>] cmd
