@@ -1,33 +1,34 @@
-# encoding: utf-8
-
 module Nanoc::Extra
   # Responsible for finding and deleting files in the site’s output directory
-  # that are not managed by nanoc.
+  # that are not managed by Nanoc.
+  #
+  # @api private
   class Pruner
-    # @return [Nanoc::Site] The site this pruner belongs to
+    # @return [Nanoc::Int::Site] The site this pruner belongs to
     attr_reader :site
 
-    # @param [Nanoc::Site] site The site for which a pruner is created
+    # @param [Nanoc::Int::Site] site The site for which a pruner is created
     #
-    # @option params [Boolean] :dry_run (false) true if the files to be deleted
+    # @param [Boolean] dry_run true if the files to be deleted
     #   should only be printed instead of actually deleted, false if the files
     #   should actually be deleted.
-    def initialize(site, params = {})
+    #
+    # @param [Enumerable<String>] exclude
+    def initialize(site, dry_run: false, exclude: [])
       @site    = site
-      @dry_run = params.fetch(:dry_run) { false }
-      @exclude = params.fetch(:exclude) { [] }
+      @dry_run = dry_run
+      @exclude = exclude
     end
 
-    # Prunes all output files not managed by nanoc.
+    # Prunes all output files not managed by Nanoc.
     #
     # @return [void]
     def run
       require 'find'
 
       # Get compiled files
-      all_raw_paths = site.items.map do |item|
-        item.reps.map(&:raw_path)
-      end
+      # FIXME: requires #build_reps to have been called
+      all_raw_paths = site.compiler.reps.flat_map { |r| r.raw_paths.values }
       compiled_files = all_raw_paths.flatten.compact.select { |f| File.file?(f) }
 
       # Get present files and dirs
@@ -58,7 +59,7 @@ module Nanoc::Extra
     # @return [Boolean] true if the given file is excluded, false otherwise
     def filename_excluded?(filename)
       pathname = Pathname.new(filename)
-      @exclude.any? { |e| pathname.include_component?(e) }
+      @exclude.any? { |e| pathname.__nanoc_include_component?(e) }
     end
 
     protected
