@@ -1,6 +1,5 @@
-# encoding: utf-8
-
 module Nanoc::Filters
+  # @api private
   class ColorizeSyntax < Nanoc::Filter
     requires 'nokogiri', 'stringio', 'open3'
 
@@ -155,8 +154,6 @@ module Nanoc::Filters
     #
     # @param [Boolean] is_fullpage true if the given content is a full page,
     #   false if it is a fragment
-    #
-    # @api private
     def parse(content, klass, is_fullpage)
       if is_fullpage
         klass.parse(content, nil, 'UTF-8')
@@ -173,8 +170,6 @@ module Nanoc::Filters
 
     # Runs the code through [CodeRay](http://coderay.rubychan.de/).
     #
-    # @api private
-    #
     # @param [String] code The code to colorize
     #
     # @param [String] language The language the code is written in
@@ -203,8 +198,6 @@ module Nanoc::Filters
     # Runs the content through [pygmentize](http://pygments.org/docs/cmdline/),
     # the command-line frontend for [Pygments](http://pygments.org/).
     #
-    # @api private
-    #
     # @param [String] code The code to colorize
     #
     # @param [String] language The language the code is written in
@@ -232,8 +225,6 @@ module Nanoc::Filters
     # Runs the content through [Pygments](http://pygments.org/) via
     # [pygments.rb](https://github.com/tmm1/pygments.rb).
     #
-    # @api private
-    #
     # @param [String] code The code to colorize
     #
     # @param [String] language The language the code is written in
@@ -252,15 +243,13 @@ module Nanoc::Filters
     end
 
     SIMON_HIGHLIGHT_OPT_MAP = {
-        wrap: '-W',
-        include_style: '-I',
-        line_numbers: '-l',
-    }
+      wrap: '-W',
+      include_style: '-I',
+      line_numbers: '-l',
+    }.freeze
 
     # Runs the content through [Highlight](http://www.andre-simon.de/doku/highlight/en/highlight.html).
     #
-    # @api private
-    #
     # @since 3.2.0
     #
     # @param [String] code The code to colorize
@@ -315,8 +304,6 @@ module Nanoc::Filters
 
     # Runs the content through [Rouge](https://github.com/jayferd/rouge/.
     #
-    # @api private
-    #
     # @param [String] code The code to colorize
     #
     # @param [String] language The language the code is written in
@@ -360,7 +347,7 @@ module Nanoc::Filters
 
     protected
 
-    KNOWN_COLORIZERS = [:coderay, :dummy, :pygmentize, :pygmentsrb, :simon_highlight, :rouge]
+    KNOWN_COLORIZERS = [:coderay, :dummy, :pygmentize, :pygmentsrb, :simon_highlight, :rouge].freeze
 
     # Removes the first blank lines and any whitespace at the end.
     def strip(s)
@@ -380,7 +367,7 @@ module Nanoc::Filters
       colorizer = @colorizers[language.to_sym]
       if KNOWN_COLORIZERS.include?(colorizer)
         sym = (colorizer.to_s + '_postprocess').to_sym
-        if self.respond_to?(sym)
+        if respond_to?(sym)
           send(sym, language, element)
         end
       else
