@@ -1,11 +1,10 @@
-# encoding: utf-8
-
 module Nanoc::Filters
+  # @api private
   class Erubis < Nanoc::Filter
     requires 'erubis'
 
     # The same as `::Erubis::Eruby` but adds `_erbout` as an alias for the
-    # `_buf` variable, making it compatible with nanoc’s helpers that rely
+    # `_buf` variable, making it compatible with Nanoc’s helpers that rely
     # on `_erbout`, such as {Nanoc::Helpers::Capturing}.
     class ErubisWithErbout < ::Erubis::Eruby
       include ::Erubis::ErboutEnhancer
@@ -19,7 +18,7 @@ module Nanoc::Filters
     # @return [String] The filtered content
     def run(content, _params = {})
       # Create context
-      context = ::Nanoc::Context.new(assigns)
+      context = ::Nanoc::Int::Context.new(assigns)
 
       # Get binding
       proc = assigns[:content] ? -> { assigns[:content] } : nil
