@@ -1,6 +1,5 @@
-# encoding: utf-8
-
 module Nanoc::Filters
+  # @api private
   class Haml < Nanoc::Filter
     requires 'haml'
 
@@ -15,7 +14,7 @@ module Nanoc::Filters
       options = params.merge(filename: filename)
 
       # Create context
-      context = ::Nanoc::Context.new(assigns)
+      context = ::Nanoc::Int::Context.new(assigns)
 
       # Get result
       proc = assigns[:content] ? -> { assigns[:content] } : nil
