@@ -1,6 +1,5 @@
-# encoding: utf-8
-
 module Nanoc::Filters
+  # @api private
   class Less < Nanoc::Filter
     requires 'less'
 
@@ -16,7 +15,7 @@ module Nanoc::Filters
       imports.concat(content.scan(/^@import\s+(["'])([^\1]+?)\1;/))
       imports.concat(content.scan(/^@import\s+url\((["']?)([^)]+?)\1\);/))
       imported_filenames = imports.map do |i|
-        i[1].match(/\.(less|css)$/) ? i[1] : i[1] + '.less'
+        i[1] =~ /\.(less|css)$/ ? i[1] : i[1] + '.less'
       end
 
       # Convert to items
