@@ -1,7 +1,7 @@
-# encoding: utf-8
-
 module Nanoc::Filters
   # @since 3.2.0
+  #
+  # @api private
   class Redcarpet < Nanoc::Filter
     requires 'redcarpet'
 
@@ -38,7 +38,7 @@ module Nanoc::Filters
     #
     #   @option params [Boolean] :with_toc (false) A boolean to request a table
     #     of contents
-
+    #
     #   @return [String] The filtered content
     def run(content, params = {})
       if ::Redcarpet::VERSION > '2'
@@ -62,11 +62,12 @@ module Nanoc::Filters
         end
 
         # Create renderer
-        if renderer_class == ::Redcarpet::Render::HTML_TOC
-          renderer = renderer_class.new
-        else
-          renderer = renderer_class.new(renderer_options)
-        end
+        renderer =
+          if renderer_class == ::Redcarpet::Render::HTML_TOC
+            renderer_class.new
+          else
+            renderer_class.new(renderer_options)
+          end
 
         # Render
         if with_toc
