@@ -1,7 +1,7 @@
-# encoding: utf-8
-
 module Nanoc::Filters
   # @since 3.2.0
+  #
+  # @api private
   class Slim < Nanoc::Filter
     requires 'slim'
 
@@ -13,12 +13,12 @@ module Nanoc::Filters
     # @return [String] The filtered content
     def run(content, params = {})
       params = {
-        disable_capture: true,      # Capture managed by nanoc
-        buffer: '_erbout', # Force slim to output to the buffer used by nanoc
+        disable_capture: true, # Capture managed by Nanoc
+        buffer: '_erbout', # Force slim to output to the buffer used by Nanoc
       }.merge params
 
       # Create context
-      context = ::Nanoc::Context.new(assigns)
+      context = ::Nanoc::Int::Context.new(assigns)
 
       ::Slim::Template.new(params) { content }.render(context) { assigns[:content] }
     end
