@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Provides functionality for building blogs, such as finding articles and
   # constructing feeds.
@@ -52,7 +50,7 @@ module Nanoc::Helpers
     class AtomFeedBuilder
       include Nanoc::Helpers::Blogging
 
-      attr_accessor :site
+      attr_accessor :config
 
       attr_accessor :limit
       attr_accessor :relevant_articles
@@ -65,8 +63,8 @@ module Nanoc::Helpers
       attr_accessor :icon
       attr_accessor :logo
 
-      def initialize(site, item)
-        @site = site
+      def initialize(config, item)
+        @config = config
         @item = item
       end
 
@@ -100,43 +98,43 @@ module Nanoc::Helpers
       end
 
       def validate_config
-        if @site.config[:base_url].nil?
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
+        if @config[:base_url].nil?
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
         end
       end
 
       def validate_feed_item
         if title.nil?
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: no title in params, item or site config')
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: no title in params, item or site config')
         end
         if author_name.nil?
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: no author_name in params, item or site config')
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: no author_name in params, item or site config')
         end
         if author_uri.nil?
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: no author_uri in params, item or site config')
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: no author_uri in params, item or site config')
         end
       end
 
       def validate_articles
         if relevant_articles.empty?
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: no articles')
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: no articles')
         end
         if relevant_articles.any? { |a| a[:created_at].nil? }
-          raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: one or more articles lack created_at')
+          raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: one or more articles lack created_at')
         end
       end
 
       def build_for_feed(xml)
         xml.instruct!
         xml.feed(xmlns: 'http://www.w3.org/2005/Atom') do
-          root_url = @site.config[:base_url] + '/'
+          root_url = @config[:base_url] + '/'
 
           # Add primary attributes
           xml.id root_url
           xml.title title
 
           # Add date
-          xml.updated(attribute_to_time(last_article[:created_at]).to_iso8601_time)
+          xml.updated(attribute_to_time(last_article[:created_at]).__nanoc_to_iso8601_time)
 
           # Add links
           xml.link(rel: 'alternate', href: root_url)
@@ -170,8 +168,8 @@ module Nanoc::Helpers
           xml.title a[:title], type: 'html'
 
           # Add dates
-          xml.published attribute_to_time(a[:created_at]).to_iso8601_time
-          xml.updated attribute_to_time(a[:updated_at] || a[:created_at]).to_iso8601_time
+          xml.published attribute_to_time(a[:created_at]).__nanoc_to_iso8601_time
+          xml.updated attribute_to_time(a[:updated_at] || a[:created_at]).__nanoc_to_iso8601_time
 
           # Add specific author information
           if a[:author_name] || a[:author_uri]
@@ -308,7 +306,7 @@ module Nanoc::Helpers
       require 'builder'
 
       # Create builder
-      builder = AtomFeedBuilder.new(@site, @item)
+      builder = AtomFeedBuilder.new(@config, @item)
 
       # Fill builder
       builder.limit             = params[:limit] || 5
@@ -316,9 +314,9 @@ module Nanoc::Helpers
       builder.preserve_order    = params.fetch(:preserve_order, false)
       builder.content_proc      = params[:content_proc] || ->(a) { a.compiled_content(snapshot: :pre) }
       builder.excerpt_proc      = params[:excerpt_proc] || ->(a) { a[:excerpt] }
-      builder.title             = params[:title] || @item[:title] || @site.config[:title]
-      builder.author_name       = params[:author_name] || @item[:author_name] || @site.config[:author_name]
-      builder.author_uri        = params[:author_uri] || @item[:author_uri] || @site.config[:author_uri]
+      builder.title             = params[:title] || @item[:title] || @config[:title]
+      builder.author_name       = params[:author_name] || @item[:author_name] || @config[:author_name]
+      builder.author_uri        = params[:author_uri] || @item[:author_uri] || @config[:author_uri]
       builder.icon              = params[:icon]
       builder.logo              = params[:logo]
 
@@ -330,22 +328,22 @@ module Nanoc::Helpers
     # Returns the URL for the given item. It will return the URL containing
     # the custom path in the feed if possible, otherwise the normal path.
     #
-    # @param [Nanoc::Item] item The item for which to fetch the URL.
+    # @param [Nanoc::Int::Item] item The item for which to fetch the URL.
     #
     # @return [String] The URL of the given item
     def url_for(item)
       # Check attributes
-      if @site.config[:base_url].nil?
-        raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
+      if @config[:base_url].nil?
+        raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
       end
 
       # Build URL
       if item[:custom_url_in_feed]
         item[:custom_url_in_feed]
       elsif item[:custom_path_in_feed]
-        @site.config[:base_url] + item[:custom_path_in_feed]
+        @config[:base_url] + item[:custom_path_in_feed]
       elsif item.path
-        @site.config[:base_url] + item.path
+        @config[:base_url] + item.path
       end
     end
 
@@ -355,11 +353,11 @@ module Nanoc::Helpers
     # @return [String] The URL of the feed
     def feed_url
       # Check attributes
-      if @site.config[:base_url].nil?
-        raise Nanoc::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
+      if @config[:base_url].nil?
+        raise Nanoc::Int::Errors::GenericTrivial.new('Cannot build Atom feed: site configuration has no base_url')
       end
 
-      @item[:feed_url] || @site.config[:base_url] + @item.path
+      @item[:feed_url] || @config[:base_url] + @item.path
     end
 
     # Returns an URI containing an unique ID for the given item. This will be
@@ -368,28 +366,36 @@ module Nanoc::Helpers
     # ["How to make a good ID in Atom" blog post]
     # (http://web.archive.org/web/20110915110202/http://diveintomark.org/archives/2004/05/28/howto-atom-id).
     #
-    # @param [Nanoc::Item] item The item for which to create an atom tag
+    # @param [Nanoc::Int::Item] item The item for which to create an atom tag
     #
     # @return [String] The atom tag for the given item
     def atom_tag_for(item)
-      hostname, base_dir = %r{^.+?://([^/]+)(.*)$}.match(@site.config[:base_url])[1..2]
+      hostname, base_dir = %r{^.+?://([^/]+)(.*)$}.match(@config[:base_url])[1..2]
 
-      formatted_date = attribute_to_time(item[:created_at]).to_iso8601_date
+      formatted_date = attribute_to_time(item[:created_at]).__nanoc_to_iso8601_date
 
-      'tag:' + hostname + ',' + formatted_date + ':' + base_dir + (item.path || item.identifier)
+      'tag:' + hostname + ',' + formatted_date + ':' + base_dir + (item.path || item.identifier.to_s)
     end
 
-    # Converts the given attribute (which can be a string, a Time or a Date)
-    # into a Time.
+    # Converts the given attribute (which can be a string, a Time, a Date or a
+    # DateTime) into a Time. When given a Date instance or a string, the
+    # argument is assumed to be in the local timezone.
     #
-    # @param [String, Time, Date] time Something that contains time
+    # @param [String, Time, Date, DateTime] arg Something that contains time
     #   information but is not necessarily a Time instance yet
     #
     # @return [Time] The Time instance corresponding to the given input
-    def attribute_to_time(time)
-      time = Time.local(time.year, time.month, time.day) if time.is_a?(Date)
-      time = Time.parse(time) if time.is_a?(String)
-      time
+    def attribute_to_time(arg)
+      case arg
+      when DateTime
+        arg.to_time
+      when Date
+        Time.local(arg.year, arg.month, arg.day)
+      when String
+        Time.parse(arg)
+      else
+        arg
+      end
     end
   end
 end
