@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Provides functionality for filtering parts of an item or a layout.
   module Filtering
@@ -32,13 +30,25 @@ module Nanoc::Helpers
 
       # Find filter
       klass = Nanoc::Filter.named(filter_name)
-      raise Nanoc::Errors::UnknownFilter.new(filter_name) if klass.nil?
-      filter = klass.new(@item_rep.assigns)
+      raise Nanoc::Int::Errors::UnknownFilter.new(filter_name) if klass.nil?
+
+      # Create filter
+      assigns = {
+        item: @item,
+        rep: @rep,
+        item_rep: @item_rep,
+        items: @items,
+        layouts: @layouts,
+        config: @config,
+        site: @site,
+        content: @content,
+      }
+      filter = klass.new(assigns)
 
       # Filter captured data
-      Nanoc::NotificationCenter.post(:filtering_started, @item_rep, filter_name)
+      Nanoc::Int::NotificationCenter.post(:filtering_started, @item_rep.unwrap, filter_name)
       filtered_data = filter.setup_and_run(data, arguments)
-      Nanoc::NotificationCenter.post(:filtering_ended, @item_rep, filter_name)
+      Nanoc::Int::NotificationCenter.post(:filtering_ended, @item_rep.unwrap, filter_name)
 
       # Append filtered data to buffer
       buffer = eval('_erbout', block.binding)
