@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Contains functionality for HTML-escaping strings.
   module HTMLEscape
@@ -36,7 +34,8 @@ module Nanoc::Helpers
         buffer = eval('_erbout', block.binding)
         buffer << escaped_data
       elsif string
-        string.gsub('&', '&amp;')
+        string
+          .gsub('&', '&amp;')
           .gsub('<', '&lt;')
           .gsub('>', '&gt;')
           .gsub('"', '&quot;')
@@ -46,6 +45,6 @@ module Nanoc::Helpers
       end
     end
 
-    alias_method :h, :html_escape
+    alias h html_escape
   end
 end
