@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Contains functions for linking to items and item representations.
   module LinkTo
@@ -14,7 +12,7 @@ module Nanoc::Helpers
     #
     # @param [String] text The visible link text
     #
-    # @param [String, Nanoc::Item, Nanoc::ItemRep] target The path/URL,
+    # @param [String, Nanoc::Int::Item, Nanoc::Int::ItemRep] target The path/URL,
     #   item or item representation that should be linked to
     #
     # @param [Hash] attributes A hash containing HTML attributes (e.g.
@@ -45,12 +43,16 @@ module Nanoc::Helpers
     #   # => '<a title="My super cool blog" href="/blog/">Blog</a>'
     def link_to(text, target, attributes = {})
       # Find path
-      if target.is_a?(String)
-        path = target
-      else
-        path = target.path
-        raise "Cannot create a link to #{target.inspect} because this target is not outputted (its routing rule returns nil)" if path.nil?
-      end
+      path =
+        case target
+        when String
+          target
+        when Nanoc::ItemWithRepsView, Nanoc::ItemWithoutRepsView, Nanoc::ItemRepView
+          raise "Cannot create a link to #{target.inspect} because this target is not outputted (its routing rule returns nil)" if target.path.nil?
+          target.path
+        else
+          raise ArgumentError, "Cannot link to #{target.inspect} (expected a string or an item, not a #{target.class.name})"
+        end
 
       # Join attributes
       attributes = attributes.reduce('') do |memo, (key, value)|
@@ -68,7 +70,7 @@ module Nanoc::Helpers
     #
     # @param [String] text The visible link text
     #
-    # @param [String, Nanoc::Item, Nanoc::ItemRep] target The path/URL,
+    # @param [String, Nanoc::Int::Item, Nanoc::Int::ItemRep] target The path/URL,
     #   item or item representation that should be linked to
     #
     # @param [Hash] attributes A hash containing HTML attributes (e.g.
@@ -84,14 +86,14 @@ module Nanoc::Helpers
     # @example Linking to the same page
     #
     #   link_to_unless_current('This Item', @item)
-    #   # => '<span class="active" title="You\'re here.">This Item</span>'
+    #   # => '<span class="active">This Item</span>'
     def link_to_unless_current(text, target, attributes = {})
       # Find path
       path = target.is_a?(String) ? target : target.path
 
       if @item_rep && @item_rep.path == path
         # Create message
-        "<span class=\"active\" title=\"You're here.\">#{text}</span>"
+        "<span class=\"active\">#{text}</span>"
       else
         link_to(text, target, attributes)
       end
@@ -100,7 +102,7 @@ module Nanoc::Helpers
     # Returns the relative path from the current item to the given path or
     # item representation. The returned path will not be HTML-escaped.
     #
-    # @param [String, Nanoc::Item, Nanoc::ItemRep] target The path/URL,
+    # @param [String, Nanoc::Int::Item, Nanoc::Int::ItemRep] target The path/URL,
     #   item or item representation to which the relative path should be
     #   generated
     #
@@ -125,24 +127,25 @@ module Nanoc::Helpers
       end
 
       # Handle Windows network (UNC) paths
-      if path.start_with?('//') || path.start_with?('\\\\')
+      if path.start_with?('//', '\\\\')
         return path
       end
 
       # Get source and destination paths
-      dst_path   = Pathname.new(path)
+      dst_path = Pathname.new(path)
       if @item_rep.path.nil?
         raise "Cannot get the relative path to #{path} because the current item representation, #{@item_rep.inspect}, is not outputted (its routing rule returns nil)"
       end
-      src_path   = Pathname.new(@item_rep.path)
+      src_path = Pathname.new(@item_rep.path)
 
       # Calculate the relative path (method depends on whether destination is
       # a directory or not).
-      if src_path.to_s[-1, 1] != '/'
-        relative_path = dst_path.relative_path_from(src_path.dirname).to_s
-      else
-        relative_path = dst_path.relative_path_from(src_path).to_s
-      end
+      relative_path =
+        if src_path.to_s[-1, 1] != '/'
+          dst_path.relative_path_from(src_path.dirname).to_s
+        else
+          dst_path.relative_path_from(src_path).to_s
+        end
 
       # Add trailing slash if necessary
       if dst_path.to_s[-1, 1] == '/'
