@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Provides functionality for rendering layouts as partials.
   module Rendering
@@ -64,25 +62,26 @@ module Nanoc::Helpers
     #     I'm boxy! Luvz!
     #   </div>
     #
-    # @raise [Nanoc::Errors::UnknownLayout] if the given layout does not
+    # @raise [Nanoc::Int::Errors::UnknownLayout] if the given layout does not
     #   exist
     #
-    # @raise [Nanoc::Errors::CannotDetermineFilter] if there is no layout
+    # @raise [Nanoc::Int::Errors::CannotDetermineFilter] if there is no layout
     #   rule for the given layout
     #
-    # @raise [Nanoc::Errors::UnknownFilter] if the layout rule for the given
+    # @raise [Nanoc::Int::Errors::UnknownFilter] if the layout rule for the given
     #   layout specifies an unknown filter
     #
     # @return [String, nil] The rendered partial, or nil if this method was
     #   invoked with a block
     def render(identifier, other_assigns = {}, &block)
       # Find layout
-      layout = @site.layouts.find { |l| l.identifier == identifier.cleaned_identifier }
-      raise Nanoc::Errors::UnknownLayout.new(identifier.cleaned_identifier) if layout.nil?
+      layout = @layouts[identifier]
+      layout ||= @layouts[identifier.__nanoc_cleaned_identifier]
+      raise Nanoc::Int::Errors::UnknownLayout.new(identifier) if layout.nil?
 
       # Visit
-      Nanoc::NotificationCenter.post(:visit_started, layout)
-      Nanoc::NotificationCenter.post(:visit_ended,   layout)
+      Nanoc::Int::NotificationCenter.post(:visit_started, layout)
+      Nanoc::Int::NotificationCenter.post(:visit_ended,   layout)
 
       # Capture content, if any
       captured_content = block_given? ? capture(&block) : nil
@@ -96,26 +95,28 @@ module Nanoc::Helpers
         layout: layout,
         layouts: @layouts,
         config: @config,
-        site: @site
+        site: @site,
       }.merge(other_assigns)
 
       # Get filter name
-      filter_name, filter_args = @site.compiler.rules_collection.filter_for_layout(layout)
-      raise Nanoc::Errors::CannotDetermineFilter.new(layout.identifier) if filter_name.nil?
+      filter_name, filter_args = *@site.unwrap.compiler.filter_name_and_args_for_layout(layout)
+      raise Nanoc::Int::Errors::CannotDetermineFilter.new(layout.identifier) if filter_name.nil?
 
       # Get filter class
       filter_class = Nanoc::Filter.named(filter_name)
-      raise Nanoc::Errors::UnknownFilter.new(filter_name) if filter_class.nil?
+      raise Nanoc::Int::Errors::UnknownFilter.new(filter_name) if filter_class.nil?
 
       # Create filter
       filter = filter_class.new(assigns)
 
       begin
         # Notify start
-        Nanoc::NotificationCenter.post(:processing_started, layout)
+        Nanoc::Int::NotificationCenter.post(:processing_started, layout)
 
         # Layout
-        result = filter.setup_and_run(layout.raw_content, filter_args)
+        content = layout.unwrap.content
+        arg = content.binary? ? content.filename : content.string
+        result = filter.setup_and_run(arg, filter_args)
 
         # Append to erbout if we have a block
         if block_given?
@@ -129,7 +130,7 @@ module Nanoc::Helpers
         end
       ensure
         # Notify end
-        Nanoc::NotificationCenter.post(:processing_ended, layout)
+        Nanoc::Int::NotificationCenter.post(:processing_ended, layout)
       end
     end
   end
