@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 module Nanoc::Helpers
   # Provides support for managing tags added to items.
   #
@@ -17,26 +15,22 @@ module Nanoc::Helpers
     # tags will be linked using the {#link_for_tag} function; the
     # HTML-escaping rules for {#link_for_tag} apply here as well.
     #
-    # @option params [String] base_url ("http://technorati.com/tag/") The URL
-    #   to which the tag will be appended to construct the link URL. This URL
-    #   must have a trailing slash.
+    # @param [String] base_url The URL to which the tag will be appended
+    #   to construct the link URL. This URL must have a trailing slash. The
+    #   function will return a tags string without tag page link if the param
+    #   is not provided.
     #
-    # @option params [String] none_text ("(none)") The text to display when
+    # @param [String] none_text The text to display when
     #   the item has no tags
     #
-    # @option params [String] separator (", ") The separator to put between
-    #   tags
+    # @param [String] separator The separator to put between tags
     #
     # @return [String] A hyperlinked list of tags for the given item
-    def tags_for(item, params = {})
-      base_url  = params[:base_url] || 'http://technorati.com/tag/'
-      none_text = params[:none_text] || '(none)'
-      separator = params[:separator] || ', '
-
+    def tags_for(item, base_url: nil, none_text: '(none)', separator: ', ')
       if item[:tags].nil? || item[:tags].empty?
         none_text
       else
-        item[:tags].map { |tag| link_for_tag(tag, base_url) }.join(separator)
+        item[:tags].map { |tag| base_url ? link_for_tag(tag, base_url) : tag }.join(separator)
       end
     end
 
