@@ -1,16 +1,10 @@
-# encoding: utf-8
-
-describe Nanoc::TempFilenameFactory do
+describe Nanoc::Int::TempFilenameFactory do
   subject do
-    Nanoc::TempFilenameFactory.instance
+    Nanoc::Int::TempFilenameFactory.new
   end
 
   let(:prefix) { 'foo' }
 
-  before do
-    subject.cleanup(prefix)
-  end
-
   describe '#create' do
     it 'should create unique paths' do
       path_a = subject.create(prefix)
@@ -60,7 +54,7 @@ describe Nanoc::TempFilenameFactory do
 
   describe 'other instance' do
     let(:other_instance) do
-      Nanoc::TempFilenameFactory.new
+      Nanoc::Int::TempFilenameFactory.new
     end
 
     it 'should create unique paths across instances' do
