@@ -1,183 +1,83 @@
-# encoding: utf-8
+class Nanoc::Int::CompilerTest < Nanoc::TestCase
+  def new_compiler(site = nil)
+    site ||= Nanoc::Int::Site.new(
+      config: nil,
+      code_snippets: [],
+      items: [],
+      layouts: [],
+    )
 
-class Nanoc::CompilerTest < Nanoc::TestCase
-  def test_compilation_rule_for
-    # Mock rules
-    rules = [mock, mock, mock]
-    rules[0].expects(:applicable_to?).returns(false)
-    rules[1].expects(:applicable_to?).returns(true)
-    rules[1].expects(:rep_name).returns('wrong')
-    rules[2].expects(:applicable_to?).returns(true)
-    rules[2].expects(:rep_name).returns('right')
+    reps = Nanoc::Int::ItemRepRepo.new
 
-    # Create compiler
-    compiler = Nanoc::Compiler.new(nil)
-    compiler.rules_collection.instance_eval { @item_compilation_rules = rules }
+    action_provider = Nanoc::Int::ActionProvider.named(:rule_dsl).for(site)
 
-    # Mock rep
-    rep = mock
-    rep.stubs(:name).returns('right')
-    item = mock
-    rep.stubs(:item).returns(item)
-
-    # Test
-    assert_equal rules[2], compiler.rules_collection.compilation_rule_for(rep)
-  end
-
-  def test_routing_rule_for
-    # Mock rules
-    rules = [mock, mock, mock]
-    rules[0].expects(:applicable_to?).returns(false)
-    rules[1].expects(:applicable_to?).returns(true)
-    rules[1].expects(:rep_name).returns('wrong')
-    rules[2].expects(:applicable_to?).returns(true)
-    rules[2].expects(:rep_name).returns('right')
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(nil)
-    compiler.rules_collection.instance_eval { @item_routing_rules = rules }
-
-    # Mock rep
-    rep = mock
-    rep.stubs(:name).returns('right')
-    item = mock
-    rep.stubs(:item).returns(item)
-
-    # Test
-    assert_equal rules[2], compiler.rules_collection.routing_rule_for(rep)
-  end
-
-  def test_filter_for_layout_with_existant_layout
-    # Mock site
-    site = mock
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(site)
-    compiler.rules_collection.layout_filter_mapping[/.*/] = [:erb, { foo: 'bar' }]
-
-    # Mock layout
-    layout = MiniTest::Mock.new
-    layout.expect(:identifier, '/some_layout/')
-
-    # Check
-    assert_equal([:erb, { foo: 'bar' }], compiler.rules_collection.filter_for_layout(layout))
-  end
-
-  def test_filter_for_layout_with_existant_layout_and_unknown_filter
-    # Mock site
-    site = mock
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(site)
-    compiler.rules_collection.layout_filter_mapping[/.*/] = [:some_unknown_filter, { foo: 'bar' }]
-
-    # Mock layout
-    layout = MiniTest::Mock.new
-    layout.expect(:identifier, '/some_layout/')
-
-    # Check
-    assert_equal([:some_unknown_filter, { foo: 'bar' }], compiler.rules_collection.filter_for_layout(layout))
-  end
-
-  def test_filter_for_layout_with_nonexistant_layout
-    # Mock site
-    site = mock
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(site)
-    compiler.rules_collection.layout_filter_mapping[%r{^/foo/$}] = [:erb, { foo: 'bar' }]
-
-    # Mock layout
-    layout = MiniTest::Mock.new
-    layout.expect(:identifier, '/bar/')
-
-    # Check
-    assert_equal(nil, compiler.rules_collection.filter_for_layout(layout))
-  end
-
-  def test_filter_for_layout_with_many_layouts
-    # Mock site
-    site = mock
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(site)
-    compiler.rules_collection.layout_filter_mapping[%r{^/a/b/c/.*/$}] = [:erb, { char: 'd' }]
-    compiler.rules_collection.layout_filter_mapping[%r{^/a/.*/$}]     = [:erb, { char: 'b' }]
-    compiler.rules_collection.layout_filter_mapping[%r{^/a/b/.*/$}]   = [:erb, { char: 'c' }] # never used!
-    compiler.rules_collection.layout_filter_mapping[%r{^/.*/$}]       = [:erb, { char: 'a' }]
-
-    # Mock layout
-    layouts = [mock, mock, mock, mock]
-    layouts[0].stubs(:identifier).returns('/a/b/c/d/')
-    layouts[1].stubs(:identifier).returns('/a/b/c/')
-    layouts[2].stubs(:identifier).returns('/a/b/')
-    layouts[3].stubs(:identifier).returns('/a/')
-
-    # Get expectations
-    expectations = {
-      0 => 'd',
-      1 => 'b', # never used! not c, because b takes priority
-      2 => 'b',
-      3 => 'a'
+    params = {
+      compiled_content_cache: Nanoc::Int::CompiledContentCache.new,
+      checksum_store: Nanoc::Int::ChecksumStore.new(site: site),
+      rule_memory_store: Nanoc::Int::RuleMemoryStore.new,
+      dependency_store: Nanoc::Int::DependencyStore.new(
+        site.items.to_a + site.layouts.to_a),
+      action_provider: action_provider,
+      reps: reps,
     }
 
-    # Check
-    expectations.each_pair do |num, char|
-      filter_and_args = compiler.rules_collection.filter_for_layout(layouts[num])
-      refute_nil(filter_and_args)
-      assert_equal(char, filter_and_args[1][:char])
-    end
+    params[:outdatedness_checker] =
+      Nanoc::Int::OutdatednessChecker.new(
+        site: site,
+        checksum_store: params[:checksum_store],
+        dependency_store: params[:dependency_store],
+        rule_memory_store: params[:rule_memory_store],
+        action_provider: action_provider,
+        reps: reps,
+      )
+
+    Nanoc::Int::Compiler.new(site, params)
   end
 
-  def test_compile_rep_should_write_proper_snapshots
-    # Mock rep
-    item = Nanoc::Item.new('<%= 1 %> <%%= 2 %> <%%%= 3 %>', {}, '/moo/')
-    rep  = Nanoc::ItemRep.new(item, :blah)
+  def test_compile_rep_should_write_proper_snapshots_real
+    with_site do |site|
+      File.write('content/moo.txt', '<%= 1 %> <%%= 2 %> <%%%= 3 %>')
+      File.write('layouts/default.erb', 'head <%= yield %> foot')
 
-    # Set snapshot filenames
-    rep.raw_paths = {
-      raw: 'raw.txt',
-      pre: 'pre.txt',
-      post: 'post.txt',
-      last: 'last.txt'
-    }
+      File.open('Rules', 'w') do |io|
+        io.write "compile '/**/*' do\n"
+        io.write "  filter :erb\n"
+        io.write "  filter :erb\n"
+        io.write "  layout 'default'\n"
+        io.write "  filter :erb\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "route '/**/*', snapshot: :raw do\n"
+        io.write "  '/moo-raw.txt'\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "route '/**/*', snapshot: :pre do\n"
+        io.write "  '/moo-pre.txt'\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "route '/**/*', snapshot: :post do\n"
+        io.write "  '/moo-post.txt'\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "route '/**/*' do\n"
+        io.write "  '/moo-last.txt'\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "layout '/**/*', :erb\n"
+      end
 
-    # Create rule
-    rule_block = proc do
-      filter :erb
-      filter :erb
-      layout '/blah/'
-      filter :erb
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compile
+
+      assert File.file?('output/moo-raw.txt')
+      # assert File.file?('output/moo-pre.txt')
+      assert File.file?('output/moo-post.txt')
+      assert File.file?('output/moo-last.txt')
+      assert_equal '<%= 1 %> <%%= 2 %> <%%%= 3 %>', File.read('output/moo-raw.txt')
+      # assert_equal '1 2 <%= 3 %>',                  File.read('output/moo-pre.txt')
+      assert_equal 'head 1 2 3 foot',               File.read('output/moo-post.txt')
+      assert_equal 'head 1 2 3 foot',               File.read('output/moo-last.txt')
     end
-    rule = Nanoc::Rule.new(/blah/, :meh, rule_block)
-
-    # Create layout
-    layout = Nanoc::Layout.new('head <%= yield %> foot', {}, '/blah/')
-
-    # Create site
-    site = mock
-    site.stubs(:config).returns({})
-    site.stubs(:items).returns([])
-    site.stubs(:layouts).returns([layout])
-
-    # Create compiler
-    compiler = Nanoc::Compiler.new(site)
-    compiler.rules_collection.expects(:compilation_rule_for).times(2).with(rep).returns(rule)
-    compiler.rules_collection.layout_filter_mapping[%r{^/blah/$}] = [:erb, {}]
-    site.stubs(:compiler).returns(compiler)
-
-    # Compile
-    compiler.send(:compile_rep, rep)
-
-    # Test
-    assert File.file?('raw.txt')
-    assert File.file?('pre.txt')
-    assert File.file?('post.txt')
-    assert File.file?('last.txt')
-    assert_equal '<%= 1 %> <%%= 2 %> <%%%= 3 %>', File.read('raw.txt')
-    assert_equal '1 2 <%= 3 %>',                  File.read('pre.txt')
-    assert_equal 'head 1 2 3 foot',               File.read('post.txt')
-    assert_equal 'head 1 2 3 foot',               File.read('last.txt')
   end
 
   def test_compile_with_no_reps
@@ -192,6 +92,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
     with_site do |site|
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       assert Dir['output/*'].size == 1
@@ -205,6 +106,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       File.open('content/foo.html', 'w') { |io| io.write('o hai') }
       File.open('content/bar.html', 'w') { |io| io.write('o bai') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       assert Dir['output/*'].size == 2
@@ -224,6 +126,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
         io.write('manatee')
       end
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       assert Dir['output/*'].size == 2
@@ -243,7 +146,8 @@ class Nanoc::CompilerTest < Nanoc::TestCase
         io.write('<%= @items.find { |i| i.identifier == "/foo/" }.compiled_content %>')
       end
 
-      assert_raises Nanoc::Errors::RecursiveCompilation do
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      assert_raises Nanoc::Int::Errors::RecursiveCompilation do
         site.compile
       end
     end
@@ -256,42 +160,50 @@ class Nanoc::CompilerTest < Nanoc::TestCase
     FileUtils.cd('bar') do
       # Create routes
       File.open('Rules', 'w') do |io|
-        io.write "compile '*' do\n"
+        io.write "compile '/**/*' do\n"
         io.write "  layout 'default'\n"
         io.write "end\n"
         io.write "\n"
-        io.write "route '*' do\n"
+        io.write "route '/**/*' do\n"
         io.write "  'index.html'\n"
         io.write "end\n"
         io.write "\n"
-        io.write "layout '*', :erb\n"
+        io.write "layout '/**/*', :erb\n"
       end
 
       # Create site
-      site = Nanoc::Site.new('.')
-      error = assert_raises(RuntimeError) do
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      error = assert_raises(Nanoc::Error) do
         site.compile
       end
       assert_match(/^The path returned for the.*does not start with a slash. Please ensure that all routing rules return a path that starts with a slash./, error.message)
     end
   end
 
-  def test_load_should_be_idempotent
+  def test_disallow_duplicate_routes
     # Create site
     Nanoc::CLI.run %w( create_site bar)
 
     FileUtils.cd('bar') do
-      site = Nanoc::Site.new('.')
-
-      compiler = Nanoc::Compiler.new(site)
-      def compiler.route_reps
-        raise 'oh my gosh it is borken'
+      # Create routes
+      File.open('Rules', 'w') do |io|
+        io.write "compile '/**/*' do\n"
+        io.write "end\n"
+        io.write "\n"
+        io.write "route '/**/*' do\n"
+        io.write "  '/index.html'\n"
+        io.write "end\n"
       end
 
-      assert site.instance_eval { !@loaded }
-      assert_raises(RuntimeError) { compiler.load }
-      assert site.instance_eval { !@loaded }
-      assert_raises(RuntimeError) { compiler.load }
+      # Create files
+      File.write('content/foo.html', 'asdf')
+      File.write('content/bar.html', 'asdf')
+
+      # Create site
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      assert_raises(Nanoc::Int::ItemRepRouter::IdenticalRoutesError) do
+        site.compile
+      end
     end
   end
 
@@ -301,12 +213,12 @@ class Nanoc::CompilerTest < Nanoc::TestCase
     FileUtils.cd('bar') do
       Nanoc::CLI.run %w( compile )
 
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # At this point, even the already compiled items in the previous pass
       # should have their compiled content assigned, so this should work:
-      site.items[0].reps[0].compiled_content
+      site.compiler.reps[site.items['/index.*']][0].compiled_content
     end
   end
 
@@ -317,21 +229,21 @@ class Nanoc::CompilerTest < Nanoc::TestCase
     FileUtils.cd('bar') do
       # Create routes
       File.open('Rules', 'w') do |io|
-        io.write "compile '*' do\n"
+        io.write "compile '/**/*' do\n"
         io.write "  snapshot :aaa\n"
         io.write "  snapshot :aaa\n"
         io.write "end\n"
         io.write "\n"
-        io.write "route '*' do\n"
-        io.write "  '/index.html'\n"
+        io.write "route '/**/*' do\n"
+        io.write "  item.identifier.to_s\n"
         io.write "end\n"
         io.write "\n"
-        io.write "layout '*', :erb\n"
+        io.write "layout '/**/*', :erb\n"
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
-      assert_raises Nanoc::Errors::CannotCreateMultipleSnapshotsWithSameName do
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      assert_raises Nanoc::Int::Errors::CannotCreateMultipleSnapshotsWithSameName do
         site.compile
       end
     end
@@ -360,7 +272,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -393,7 +305,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -423,7 +335,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -456,7 +368,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -477,7 +389,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -508,7 +420,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -531,7 +443,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
         io.write "layout '*', :erb\n"
       end
 
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       assert_equal Set.new(%w( content/blah.dat )), Set.new(Dir['content/*'])
@@ -547,7 +459,7 @@ class Nanoc::CompilerTest < Nanoc::TestCase
       end
 
       # Compile
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
 
       # Check
@@ -555,37 +467,23 @@ class Nanoc::CompilerTest < Nanoc::TestCase
     end
   end
 
-  def test_compiler_dependency_on_unmet_dependency
-    with_site do
-      File.open('content/a.html', 'w') do |io|
-        io.write('<% @items["/b/"].compiled_content %>')
-      end
-      File.open('content/b.html', 'w') do |io|
-        io.write('I am feeling so dependent!')
-      end
+  def test_find_layouts_by_glob
+    Nanoc::CLI.run %w( create_site bar )
+    FileUtils.cd('bar') do
       File.open('Rules', 'w') do |io|
-        io.write "compile '*' do\n"
-        io.write "  filter :erb\n"
+        io.write "compile '/**/*' do\n"
+        io.write "  layout '/default.*'\n"
         io.write "end\n"
         io.write "\n"
-        io.write "route '*' do\n"
-        io.write "  item.identifier.chop + '.' + item[:extension]\n"
+        io.write "route '/**/*' do\n"
+        io.write "  item.identifier.to_s\n"
         io.write "end\n"
         io.write "\n"
-        io.write "layout '*', :erb\n"
+        io.write "layout '/**/*', :erb\n"
       end
 
-      site = Nanoc::Site.new('.')
-      rep = site.items['/a/'].reps[0]
-      dt = site.compiler.dependency_tracker
-      dt.start
-      assert_raises Nanoc::Errors::UnmetDependency do
-        site.compiler.send :compile_rep, rep
-      end
-      dt.stop
-
-      stack = dt.instance_eval { @stack }
-      assert_empty stack
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compile
     end
   end
 end
