@@ -1,9 +1,7 @@
-# encoding: utf-8
-
-class Nanoc::ContextTest < Nanoc::TestCase
+class Nanoc::Int::ContextTest < Nanoc::TestCase
   def test_context_with_instance_variable
     # Create context
-    context = Nanoc::Context.new({ foo: 'bar', baz: 'quux' })
+    context = Nanoc::Int::Context.new({ foo: 'bar', baz: 'quux' })
 
     # Ensure correct evaluation
     assert_equal('bar', eval('@foo', context.get_binding))
@@ -11,7 +9,7 @@ class Nanoc::ContextTest < Nanoc::TestCase
 
   def test_context_with_instance_method
     # Create context
-    context = Nanoc::Context.new({ foo: 'bar', baz: 'quux' })
+    context = Nanoc::Int::Context.new({ foo: 'bar', baz: 'quux' })
 
     # Ensure correct evaluation
     assert_equal('bar', eval('foo', context.get_binding))
@@ -22,6 +20,6 @@ class Nanoc::ContextTest < Nanoc::TestCase
     YARD.parse(LIB_DIR + '/nanoc/base/context.rb')
 
     # Run
-    assert_examples_correct 'Nanoc::Context#initialize'
+    assert_examples_correct 'Nanoc::Int::Context#initialize'
   end
 end
