@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::DataSourceTest < Nanoc::TestCase
   def test_loading
     # Create data source
@@ -26,17 +24,27 @@ class Nanoc::DataSourceTest < Nanoc::TestCase
     # Test optional methods
     data_source.up
     data_source.down
-    data_source.update
-
-    # Test required methods - general
-    assert_raises(NotImplementedError) { data_source.setup }
 
     # Test methods - loading data
-    assert_equal [],  data_source.items
-    assert_equal [],  data_source.layouts
+    assert_equal [], data_source.items
+    assert_equal [], data_source.layouts
+  end
 
-    # Test required method - creating data
-    assert_raises(NotImplementedError) { data_source.create_item(nil, nil, nil) }
-    assert_raises(NotImplementedError) { data_source.create_layout(nil, nil, nil) }
+  def test_new_item
+    data_source = Nanoc::DataSource.new(nil, nil, nil, nil)
+
+    item = data_source.new_item('stuff', { title: 'Stuff!' }, '/asdf/')
+    assert_equal 'stuff', item.content.string
+    assert_equal 'Stuff!', item.attributes[:title]
+    assert_equal Nanoc::Identifier.new('/asdf/'), item.identifier
+  end
+
+  def test_new_layout
+    data_source = Nanoc::DataSource.new(nil, nil, nil, nil)
+
+    layout = data_source.new_layout('stuff', { title: 'Stuff!' }, '/asdf/')
+    assert_equal 'stuff', layout.content.string
+    assert_equal 'Stuff!', layout.attributes[:title]
+    assert_equal Nanoc::Identifier.new('/asdf/'), layout.identifier
   end
 end
