@@ -1,19 +1,21 @@
-# encoding: utf-8
-
-class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
+class Nanoc::Int::OutdatednessCheckerTest < Nanoc::TestCase
   def test_not_outdated
     # Compile once
     with_site(name: 'foo') do |site|
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
       File.open('lib/stuff.rb', 'w') { |io| io.write('$foo = 123') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items[0].reps[0]
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
       assert_nil outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
@@ -24,6 +26,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
       File.open('lib/stuff.rb', 'w') { |io| io.write('$foo = 123') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -34,10 +37,12 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::NotEnoughData,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::NotEnoughData, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -47,6 +52,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
       File.open('lib/stuff.rb', 'w') { |io| io.write('$foo = 123') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -57,10 +63,12 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::NotWritten,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::NotWritten, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -71,6 +79,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
       File.open('content/new.html', 'w') { |io| io.write('o hello too') }
       File.open('lib/stuff.rb', 'w') { |io| io.write('$foo = 123') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -81,10 +90,12 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/new/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::SourceModified,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/new/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::SourceModified, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -94,6 +105,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
       File.open('layouts/default.html', 'w') { |io| io.write('!!! <%= yield %> !!!') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -105,12 +117,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     # Check
     with_site(name: 'foo') do |site|
       # FIXME: ugly fugly hack
-      site.compiler.load
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
 
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::DependenciesOutdated,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::DependenciesOutdated, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -124,6 +137,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
         io.write('stuff')
       end
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -137,12 +151,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     # Check
     with_site(name: 'foo') do |site|
       # FIXME: ugly fugly hack
-      site.compiler.load
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
 
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/a/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::DependenciesOutdated,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/a/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::DependenciesOutdated, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -159,6 +174,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
         io.write('stuff')
       end
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -172,12 +188,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     # Check
     with_site(name: 'foo') do |site|
       # FIXME: ugly fugly hack
-      site.compiler.load
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
 
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/a/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::DependenciesOutdated,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/a/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::DependenciesOutdated, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -193,6 +210,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
         io.write('stuff')
       end
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -204,12 +222,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     # Check
     with_site(name: 'foo') do |site|
       # FIXME: ugly fugly hack
-      site.compiler.load
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
 
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/a/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::DependenciesOutdated,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/a/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::DependenciesOutdated, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -225,6 +244,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
         io.write('stuff')
       end
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -238,12 +258,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     # Check
     with_site(name: 'foo') do |site|
       # FIXME: ugly fugly hack
-      site.compiler.load
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
 
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/a/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::DependenciesOutdated,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/a/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::DependenciesOutdated, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -254,6 +275,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     with_site(name: 'foo') do |site|
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -264,10 +286,12 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::CodeSnippetsModified,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::CodeSnippetsModified, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -276,20 +300,30 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     with_site(name: 'foo') do |site|
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
     # Change code
     FileUtils.cd('foo') do
-      File.open('nanoc.yaml', 'w') { |io| io.write('awesome: true') }
+      File.open('nanoc.yaml', 'w') do |io|
+        io << 'awesome: true' << "\n"
+        io << 'string_pattern_type: legacy' << "\n"
+        io << 'data_sources:' << "\n"
+        io << '  -' << "\n"
+        io << '    type: filesystem' << "\n"
+        io << '    identifier_type: legacy' << "\n"
+      end
     end
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::ConfigurationModified,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::ConfigurationModified, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -298,6 +332,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
     with_site(name: 'foo') do |site|
       File.open('content/index.html', 'w') { |io| io.write('o hello') }
 
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -308,8 +343,11 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     with_site(name: 'foo') do |site|
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
       assert_nil outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
@@ -331,7 +369,7 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Compile once
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
@@ -349,11 +387,12 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Check
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
+      site.compiler.build_reps
+      site.compiler.load_stores
       outdatedness_checker = site.compiler.send :outdatedness_checker
-      rep = site.items.find { |i| i.identifier == '/' }.reps[0]
-      assert_equal ::Nanoc::OutdatednessReasons::RulesModified,
-        outdatedness_checker.outdatedness_reason_for(rep)
+      rep = site.compiler.reps[site.items.find { |i| i.identifier == '/' }][0]
+      assert_equal ::Nanoc::Int::OutdatednessReasons::RulesModified, outdatedness_checker.outdatedness_reason_for(rep)
     end
   end
 
@@ -374,13 +413,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Compile
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
     # Assert not outdated
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       outdatedness_checker = site.compiler.outdatedness_checker
       site.items.each do |item|
         refute outdatedness_checker.outdated?(item), 'item should not be outdated'
@@ -407,13 +446,13 @@ class Nanoc::OutdatednessCheckerTest < Nanoc::TestCase
 
     # Compile
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       site.compile
     end
 
     # Assert not outdated
     FileUtils.cd('foo') do
-      site = Nanoc::Site.new('.')
+      site = Nanoc::Int::SiteLoader.new.new_from_cwd
       outdatedness_checker = site.compiler.outdatedness_checker
       site.items.each do |item|
         refute outdatedness_checker.outdated?(item), 'item should not be outdated'
