@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::PluginTest < Nanoc::TestCase
   class SampleFilter < Nanoc::Filter
     identifier :_plugin_test_sample_filter
@@ -18,7 +16,7 @@ class Nanoc::PluginTest < Nanoc::TestCase
   def test_register
     SampleFilter.send(:identifier, :_plugin_test_sample_filter)
 
-    registry = Nanoc::PluginRegistry.instance
+    registry = Nanoc::Int::PluginRegistry.instance
     filter = registry.find(Nanoc::Filter, :_plugin_test_sample_filter)
 
     refute_nil filter
