@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::CLI::Commands::CheckTest < Nanoc::TestCase
   def test_check_stale
     with_site do |_site|
@@ -10,7 +8,7 @@ class Nanoc::CLI::Commands::CheckTest < Nanoc::TestCase
 
       # Should raise now
       File.open('output/blah.html', 'w') { |io| io.write 'moo' }
-      assert_raises Nanoc::Errors::GenericTrivial do
+      assert_raises Nanoc::Int::Errors::GenericTrivial do
         Nanoc::CLI.run %w( check stale )
       end
     end
