@@ -1,11 +1,9 @@
-# encoding: utf-8
-
 class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   def test_profiling_information
     with_site do |_site|
-      Nanoc::CLI.run %w( create_item foo )
-      Nanoc::CLI.run %w( create_item bar )
-      Nanoc::CLI.run %w( create_item baz )
+      File.open('content/foo.md', 'w') { |io| io << 'asdf' }
+      File.open('content/bar.md', 'w') { |io| io << 'asdf' }
+      File.open('content/baz.md', 'w') { |io| io << 'asdf' }
 
       File.open('Rules', 'w') do |io|
         io.write "compile '*' do\n"
@@ -29,9 +27,9 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
   def test_auto_prune
     with_site do |_site|
-      Nanoc::CLI.run %w( create_item foo )
-      Nanoc::CLI.run %w( create_item bar )
-      Nanoc::CLI.run %w( create_item baz )
+      File.open('content/foo.md', 'w') { |io| io << 'asdf' }
+      File.open('content/bar.md', 'w') { |io| io << 'asdf' }
+      File.open('content/baz.md', 'w') { |io| io << 'asdf' }
 
       File.open('Rules', 'w') do |io|
         io.write "compile '*' do\n"
@@ -49,6 +47,12 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
         io.write "layout '*', :erb\n"
       end
 
+      File.open('nanoc.yaml', 'w') do |io|
+        io.write "string_pattern_type: legacy\n"
+        io.write "prune:\n"
+        io.write "  auto_prune: false\n"
+      end
+
       File.open('output/stray.html', 'w') do |io|
         io.write 'I am a stray file and I am about to be deleted!'
       end
@@ -58,6 +62,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
       assert File.file?('output/stray.html')
 
       File.open('nanoc.yaml', 'w') do |io|
+        io.write "string_pattern_type: legacy\n"
         io.write "prune:\n"
         io.write "  auto_prune: true\n"
       end
@@ -70,9 +75,9 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
   def test_auto_prune_with_exclude
     with_site do |_site|
-      Nanoc::CLI.run %w( create_item foo )
-      Nanoc::CLI.run %w( create_item bar )
-      Nanoc::CLI.run %w( create_item baz )
+      File.open('content/foo.md', 'w') { |io| io << 'asdf' }
+      File.open('content/bar.md', 'w') { |io| io << 'asdf' }
+      File.open('content/baz.md', 'w') { |io| io << 'asdf' }
 
       File.open('Rules', 'w') do |io|
         io.write "compile '*' do\n"
@@ -92,6 +97,12 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
       Dir.mkdir('output/excluded_dir')
 
+      File.open('nanoc.yaml', 'w') do |io|
+        io.write "string_pattern_type: legacy\n"
+        io.write "prune:\n"
+        io.write "  auto_prune: false\n"
+      end
+
       File.open('output/stray.html', 'w') do |io|
         io.write 'I am a stray file and I am about to be deleted!'
       end
@@ -101,6 +112,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
       assert File.file?('output/stray.html')
 
       File.open('nanoc.yaml', 'w') do |io|
+        io.write "string_pattern_type: legacy\n"
         io.write "prune:\n"
         io.write "  auto_prune: true\n"
         io.write "  exclude: [ 'excluded_dir' ]\n"
@@ -109,8 +121,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
       assert File.file?('output/stray.html')
       Nanoc::CLI.run %w( compile )
       refute File.file?('output/stray.html')
-      assert File.directory?('output/excluded_dir'),
-        'excluded_dir should still be there'
+      assert File.directory?('output/excluded_dir'), 'excluded_dir should still be there'
     end
   end
 
@@ -137,9 +148,8 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
       options = {}
       arguments = []
       cmd = nil
-      listener_classes = [test_listener_class]
-      cmd_runner = Nanoc::CLI::Commands::Compile.new(
-        options, arguments, cmd, listener_classes: listener_classes)
+      cmd_runner = Nanoc::CLI::Commands::Compile.new(options, arguments, cmd)
+      cmd_runner.listener_classes = [test_listener_class]
 
       cmd_runner.run
 
@@ -152,16 +162,16 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
   def test_file_action_printer_normal
     # Create data
-    item = Nanoc::Item.new('content', {}, '/')
-    rep = Nanoc::ItemRep.new(item, :default)
-    rep.raw_path = 'output/foo.txt'
+    item = Nanoc::Int::Item.new('content', {}, '/')
+    rep = Nanoc::Int::ItemRep.new(item, :default)
+    rep.raw_paths[:last] = 'output/foo.txt'
     rep.compiled = true
 
     # Listen
     listener = new_file_action_printer([rep])
     listener.start
-    Nanoc::NotificationCenter.post(:compilation_started, rep)
-    Nanoc::NotificationCenter.post(:rep_written, rep, rep.raw_path, false, true)
+    Nanoc::Int::NotificationCenter.post(:compilation_started, rep)
+    Nanoc::Int::NotificationCenter.post(:rep_written, rep, rep.raw_path, false, true)
     listener.stop
 
     # Check
@@ -174,14 +184,14 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
   def test_file_action_printer_skip
     # Create data
-    item = Nanoc::Item.new('content', {}, '/')
-    rep = Nanoc::ItemRep.new(item, :default)
-    rep.raw_path = 'output/foo.txt'
+    item = Nanoc::Int::Item.new('content', {}, '/')
+    rep = Nanoc::Int::ItemRep.new(item, :default)
+    rep.raw_paths[:last] = 'output/foo.txt'
 
     # Listen
     listener = new_file_action_printer([rep])
     listener.start
-    Nanoc::NotificationCenter.post(:compilation_started, rep)
+    Nanoc::Int::NotificationCenter.post(:compilation_started, rep)
     listener.stop
 
     # Check
@@ -193,6 +203,12 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   end
 
   def new_file_action_printer(reps)
+    # Ensure CLI is loaded
+    begin
+      Nanoc::CLI.run(%w( help %))
+    rescue SystemExit
+    end
+
     listener = Nanoc::CLI::Commands::Compile::FileActionPrinter.new(reps: reps)
 
     def listener.log(level, action, path, duration)
@@ -201,7 +217,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
         level: level,
         action: action,
         path: path,
-        duration: duration
+        duration: duration,
       }
     end
 
