@@ -1,10 +1,8 @@
-# encoding: utf-8
-
 class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
   def test_run_without_yes
     with_site do |_site|
       # Set output dir
-      File.open('nanoc.yaml', 'w') { |io| io.write 'output_dir: output2' }
+      File.open('nanoc.yaml', 'w') { |io| io.write "output_dir: output2\nstring_pattern_type: legacy\n" }
       FileUtils.mkdir_p('output2')
 
       # Create source files
@@ -26,7 +24,14 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
   def test_run_with_yes
     with_site do |_site|
       # Set output dir
-      File.open('nanoc.yaml', 'w') { |io| io.write 'output_dir: output2' }
+      File.open('nanoc.yaml', 'w') do |io|
+        io << 'output_dir: output2' << "\n"
+        io << 'string_pattern_type: legacy' << "\n"
+        io << 'data_sources:' << "\n"
+        io << '  -' << "\n"
+        io << '    type: filesystem' << "\n"
+        io << '    identifier_type: legacy' << "\n"
+      end
       FileUtils.mkdir_p('output2')
 
       # Create source files
@@ -46,7 +51,7 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
   def test_run_with_dry_run
     with_site do |_site|
       # Set output dir
-      File.open('nanoc.yaml', 'w') { |io| io.write 'output_dir: output2' }
+      File.open('nanoc.yaml', 'w') { |io| io.write "string_pattern_type: legacy\noutput_dir: output2" }
       FileUtils.mkdir_p('output2')
 
       # Create source files
@@ -66,7 +71,15 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
   def test_run_with_exclude
     with_site do |_site|
       # Set output dir
-      File.open('nanoc.yaml', 'w') { |io| io.write "prune:\n  exclude: [ 'good-dir', 'good-file.html' ]" }
+      File.open('nanoc.yaml', 'w') do |io|
+        io << 'prune:' << "\n"
+        io << '  exclude: [ "good-dir", "good-file.html" ]' << "\n"
+        io << 'string_pattern_type: legacy' << "\n"
+        io << 'data_sources:' << "\n"
+        io << '  -' << "\n"
+        io << '    type: filesystem' << "\n"
+        io << '    identifier_type: legacy' << "\n"
+      end
       FileUtils.mkdir_p('output')
 
       # Create source files
@@ -93,8 +106,8 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
 
   def test_run_with_symlink_to_output_dir
     skip_unless_symlinks_supported
-    if defined?(JRUBY_VERSION) && JRUBY_VERSION == '1.7.11'
-      skip 'JRuby 1.7.11 has buggy File.find behavior (see https://github.com/jruby/jruby/issues/1647)'
+    if defined?(JRUBY_VERSION)
+      skip 'JRuby has buggy File.find behavior (see https://github.com/jruby/jruby/issues/1647)'
     end
 
     with_site do |_site|
