@@ -1,9 +1,5 @@
-# encoding: utf-8
-
 class Nanoc::CLITest < Nanoc::TestCase
-  COMMAND_CODE = <<EOS
-# encoding: utf-8
-
+  COMMAND_CODE = <<EOS.freeze
 usage       '_test [options]'
 summary     'meh'
 description 'longer meh'
@@ -13,9 +9,7 @@ run do |opts, args, cmd|
 end
 EOS
 
-  SUBCOMMAND_CODE = <<EOS
-# encoding: utf-8
-
+  SUBCOMMAND_CODE = <<EOS.freeze
 usage       '_sub [options]'
 summary     'meh sub'
 description 'longer meh sub'
@@ -131,6 +125,13 @@ EOS
     end
   end
 
+  def test_load_command_at_with_non_utf8_encoding
+    Encoding.default_external = Encoding::US_ASCII
+    Nanoc::CLI.load_command_at(root_dir + '/lib/nanoc/cli/commands/create-site.rb')
+  ensure
+    Encoding.default_external = Encoding::UTF_8
+  end
+
   def test_after_setup
     $after_setup_success = false
     Nanoc::CLI.after_setup do
