@@ -1,49 +1,15 @@
-# encoding: utf-8
-
 class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
   def new_data_source(params = nil)
     # Mock site
-    site = Nanoc::Site.new({})
+    site = Nanoc::Int::SiteLoader.new.new_empty
 
     # Create data source
-    data_source = Nanoc::DataSources::FilesystemUnified.new(site, nil, nil, params)
+    data_source = Nanoc::DataSources::FilesystemUnified.new(site.config, nil, nil, params)
 
     # Done
     data_source
   end
 
-  def test_create_object_not_at_root
-    # Create item
-    data_source = new_data_source
-    data_source.send(:create_object, 'foobar', 'content here', { foo: 'bar' }, '/asdf/')
-
-    # Check file existance
-    assert File.directory?('foobar')
-    assert !File.directory?('foobar/content')
-    assert !File.directory?('foobar/asdf')
-    assert File.file?('foobar/asdf.html')
-
-    # Check file content
-    expected = /^--- ?\nfoo: bar\n---\ncontent here$/
-    assert_match expected, File.read('foobar/asdf.html')
-  end
-
-  def test_create_object_at_root
-    # Create item
-    data_source = new_data_source
-    data_source.send(:create_object, 'foobar', 'content here', { foo: 'bar' }, '/')
-
-    # Check file existance
-    assert File.directory?('foobar')
-    assert !File.directory?('foobar/index')
-    assert !File.directory?('foobar/foobar')
-    assert File.file?('foobar/index.html')
-
-    # Check file content
-    expected = /^--- ?\nfoo: bar\n---\ncontent here$/
-    assert_match expected, File.read('foobar/index.html')
-  end
-
   def test_load_objects
     # Create data source
     data_source = new_data_source
@@ -75,39 +41,58 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     expected_out = [
       klass.new(
         'test 1',
-        { 'num' => 1, :filename => 'foo/bar.html',   :extension => 'html', :file => File.open('foo/bar.html') },
+        { 'num' => 1, :filename => 'foo/bar.html', :extension => 'html', mtime: File.mtime('foo/bar.html') },
         '/bar/',
-        binary: false, mtime: File.mtime('foo/bar.html')
       ),
       klass.new(
         'test 2',
-        { 'num' => 2, :filename => 'foo/b.c.html',   :extension => 'c.html', :file => File.open('foo/b.c.html') },
+        { 'num' => 2, :filename => 'foo/b.c.html', :extension => 'c.html', mtime: File.mtime('foo/b.c.html') },
         '/b/',
-        binary: false, mtime: File.mtime('foo/b.c.html')
       ),
       klass.new(
         'test 3',
-        { 'num' => 3, :filename => 'foo/a/b/c.html', :extension => 'html', :file => File.open('foo/a/b/c.html') },
+        { 'num' => 3, :filename => 'foo/a/b/c.html', :extension => 'html', mtime: File.mtime('foo/a/b/c.html') },
         '/a/b/c/',
-        binary: false, mtime: File.mtime('foo/a/b/c.html')
-      )
+      ),
     ]
-    actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass).sort_by { |i| i.stuff[0] }
+    actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass).sort_by { |i| i.stuff[0].string }
 
     # Check
     (0..expected_out.size - 1).each do |i|
-      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
+      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
-      assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
-      assert_equal expected_out[i].stuff[1][:file].path, actual_out[i].stuff[1][:file].path, 'file paths must match'
-      expected_out[i].stuff[1][:file].close
-      actual_out[i].stuff[1][:file].close
-      ['num', :filename, :extension].each do |key|
+      ['num', :filename, :extension, :mtime].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
   end
 
+  def test_load_objects_with_same_extensions
+    # Create data source
+    data_source = new_data_source({ identifier_type: 'full' })
+
+    # Create a fake class
+    klass = Class.new do
+      attr_reader :stuff
+      def initialize(*stuff)
+        @stuff = stuff
+      end
+
+      def ==(other)
+        @stuff == other.stuff
+      end
+    end
+
+    # Create sample files
+    FileUtils.mkdir_p('foo')
+    File.open('foo/bar.html', 'w') { |io| io.write("---\nnum: 1\n---\ntest 1") }
+    File.open('foo/bar.md',   'w') { |io| io.write("---\nnum: 1\n---\ntest 1") }
+
+    # Check
+    actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass)
+    assert_equal 2, actual_out.size
+  end
+
   def test_load_binary_objects
     # Create data source
     data_source = new_data_source
@@ -117,13 +102,28 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     File.open('foo/stuff.dat', 'w') { |io| io.write('random binary data') }
 
     # Load
-    items = data_source.send(:load_objects, 'foo', 'item', Nanoc::Item)
+    items = data_source.send(:load_objects, 'foo', 'item', Nanoc::Int::Item)
 
     # Check
     assert_equal 1, items.size
-    assert items[0].binary?
-    assert_equal 'foo/stuff.dat', items[0].raw_filename
-    assert_nil items[0].raw_content
+    assert items[0].content.binary?
+    assert_equal "#{Dir.getwd}/foo/stuff.dat", items[0].content.filename
+    assert_equal Nanoc::Int::BinaryContent, items[0].content.class
+  end
+
+  def test_load_layouts_with_nil_dir_name
+    # Create data source
+    data_source = new_data_source(layouts_dir: nil)
+
+    # Create sample files
+    FileUtils.mkdir_p('layouts')
+    File.write('layouts/stuff.txt', 'blah blah')
+
+    # Load
+    layouts = data_source.layouts
+
+    # Check
+    assert_empty(layouts)
   end
 
   def test_load_binary_layouts
@@ -136,7 +136,29 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Load
     assert_raises(RuntimeError) do
-      data_source.send(:load_objects, 'foo', 'item', Nanoc::Layout)
+      data_source.send(:load_objects, 'foo', 'item', Nanoc::Int::Layout)
+    end
+  end
+
+  def test_identifier_for_filename_with_full_style_identifier
+    # Create data source
+    data_source = new_data_source({ identifier_type: 'full' })
+
+    # Get input and expected output
+    expected = {
+      '/foo'            => Nanoc::Identifier.new('/foo',            type: :full),
+      '/foo.html'       => Nanoc::Identifier.new('/foo.html',       type: :full),
+      '/foo/index.html' => Nanoc::Identifier.new('/foo/index.html', type: :full),
+      '/foo.html.erb'   => Nanoc::Identifier.new('/foo.html.erb',   type: :full),
+    }
+
+    # Check
+    expected.each_pair do |input, expected_output|
+      actual_output = data_source.send(:identifier_for_filename, input)
+      assert_equal(
+        expected_output, actual_output,
+        "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
+      )
     end
   end
 
@@ -149,7 +171,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       '/foo'            => '/foo/',
       '/foo.html'       => '/foo/',
       '/foo/index.html' => '/foo/',
-      '/foo.entry.html' => '/foo.entry/'
+      '/foo.entry.html' => '/foo.entry/',
     }
 
     # Check
@@ -171,7 +193,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       '/foo'            => '/foo/',
       '/foo.html'       => '/foo/',
       '/foo/index.html' => '/foo/',
-      '/foo.html.erb'   => '/foo/'
+      '/foo.html.erb'   => '/foo/',
     }
 
     # Check
@@ -195,7 +217,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       'foo/qux.bar.qux.yaml' => '/foo/qux.bar.qux/',
       'foo/index.yaml'       => '/foo/',
       'index.yaml'           => '/',
-      'foo/blah_index.yaml'  => '/foo/blah_index/'
+      'foo/blah_index.yaml'  => '/foo/blah_index/',
     }
 
     data_source = new_data_source(allow_periods_in_identifiers: true)
@@ -204,7 +226,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
-          data_source.instance_eval { identifier_for_filename(filename) }
+          data_source.instance_eval { identifier_for_filename(filename) },
         )
       end
     end
@@ -221,7 +243,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       'foo/qux.bar.qux.yaml' => '/foo/qux/',
       'foo/index.yaml'       => '/foo/',
       'index.yaml'           => '/',
-      'foo/blah_index.yaml'  => '/foo/blah_index/'
+      'foo/blah_index.yaml'  => '/foo/blah_index/',
     }
 
     data_source = new_data_source
@@ -230,7 +252,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
-          data_source.instance_eval { identifier_for_filename(filename) }
+          data_source.instance_eval { identifier_for_filename(filename) },
         )
       end
     end
@@ -314,10 +336,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :content_filename => nil,
           :meta_filename    => 'foo/a/b/c.yaml',
           :extension        => nil,
-          :file             => nil
+          :file             => nil,
+          mtime: File.mtime('foo/a/b/c.yaml'),
         },
         '/a/b/c/',
-        binary: false, mtime: File.mtime('foo/a/b/c.yaml')
       ),
       klass.new(
         'test 2',
@@ -326,10 +348,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :content_filename => 'foo/b.c.html',
           :meta_filename    => 'foo/b.c.yaml',
           :extension        => 'html',
-          :file             => File.open('foo/b.c.html')
+          :file             => File.open('foo/b.c.html'),
+          mtime: File.mtime('foo/b.c.html') > File.mtime('foo/b.c.yaml') ? File.mtime('foo/b.c.html') : File.mtime('foo/b.c.yaml'),
         },
         '/b.c/',
-        binary: false, mtime: File.mtime('foo/b.c.html') > File.mtime('foo/b.c.yaml') ? File.mtime('foo/b.c.html') : File.mtime('foo/b.c.yaml')
       ),
       klass.new(
         'test 3',
@@ -337,11 +359,11 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           content_filename: 'foo/car.html',
           meta_filename: nil,
           extension: 'html',
-          file: File.open('foo/car.html')
+          file: File.open('foo/car.html'),
+          mtime: File.mtime('foo/car.html'),
         },
         '/car/',
-        binary: false, mtime: File.mtime('foo/car.html')
-      )
+      ),
     ]
 
     # Get actual output ordered by identifier
@@ -349,17 +371,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Check
     (0..expected_out.size - 1).each do |i|
-      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
+      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
-      assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
 
-      actual_file   = actual_out[i].stuff[1][:file]
-      expected_file = expected_out[i].stuff[1][:file]
-      assert(actual_file == expected_file || actual_file.path == expected_file.path, 'file paths must match')
-      actual_file.close unless actual_file.nil?
-      expected_file.close unless expected_file.nil?
-
-      ['num', :content_filename, :meta_filename, :extension].each do |key|
+      ['num', :content_filename, :meta_filename, :extension, :mtime].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
@@ -403,10 +418,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :content_filename => nil,
           :meta_filename    => 'foo/a/b/c.yaml',
           :extension        => nil,
-          :file             => nil
+          :file             => nil,
+          mtime: File.mtime('foo/a/b/c.yaml'),
         },
         '/a/b/c/',
-        binary: false, mtime: File.mtime('foo/a/b/c.yaml')
       ),
       klass.new(
         'test 2',
@@ -415,10 +430,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :content_filename => 'foo/b.html.erb',
           :meta_filename    => 'foo/b.yaml',
           :extension        => 'html.erb',
-          :file             => File.open('foo/b.html.erb')
+          :file             => File.open('foo/b.html.erb'),
+          mtime: File.mtime('foo/b.html.erb') > File.mtime('foo/b.yaml') ? File.mtime('foo/b.html.erb') : File.mtime('foo/b.yaml'),
         },
         '/b/',
-        binary: false, mtime: File.mtime('foo/b.html.erb') > File.mtime('foo/b.yaml') ? File.mtime('foo/b.html.erb') : File.mtime('foo/b.yaml')
       ),
       klass.new(
         'test 3',
@@ -426,11 +441,11 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           content_filename: 'foo/car.html',
           meta_filename: nil,
           extension: 'html',
-          file: File.open('foo/car.html')
+          file: File.open('foo/car.html'),
+          mtime: File.mtime('foo/car.html'),
         },
         '/car/',
-        binary: false, mtime: File.mtime('foo/car.html')
-      )
+      ),
     ]
 
     # Get actual output ordered by identifier
@@ -438,56 +453,25 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Check
     (0..expected_out.size - 1).each do |i|
-      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
+      assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
-      assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
 
-      actual_file   = actual_out[i].stuff[1][:file]
-      expected_file = expected_out[i].stuff[1][:file]
-      assert(actual_file == expected_file || actual_file.path == expected_file.path, 'file paths must match')
-      actual_file.close unless actual_file.nil?
-      expected_file.close unless expected_file.nil?
-
-      ['num', :content_filename, :meta_filename, :extension].each do |key|
+      ['num', :content_filename, :meta_filename, :extension, :mtime].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
   end
 
-  def test_create_object_allowing_periods_in_identifiers
-    # Create data source
-    data_source = new_data_source(allow_periods_in_identifiers: true)
+  def test_load_objects_correct_identifier_with_separate_yaml_file
+    data_source = new_data_source({ identifier_type: 'full' })
 
-    # Create object without period
-    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/asdf/')
-    assert File.file?('foo/asdf.html')
-    data = data_source.send(:parse, 'foo/asdf.html', nil, 'moo')
-    assert_equal({ 'some' => 'attributes' }, data[0])
-    assert_equal('some content',             data[1])
+    FileUtils.mkdir_p('foo')
+    File.write('foo/donkey.jpeg', 'data')
+    File.write('foo/donkey.yaml', "---\nalt: Donkey\n")
 
-    # Create object with period
-    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/as.df/')
-    assert File.file?('foo/as.df.html')
-    data = data_source.send(:parse, 'foo/as.df.html', nil, 'moo')
-    assert_equal({ 'some' => 'attributes' }, data[0])
-    assert_equal('some content',             data[1])
-  end
-
-  def test_create_object_disallowing_periods_in_identifiers
-    # Create data source
-    data_source = new_data_source
-
-    # Create object without period
-    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/asdf/')
-    assert File.file?('foo/asdf.html')
-    data = data_source.send(:parse, 'foo/asdf.html', nil, 'moo')
-    assert_equal({ 'some' => 'attributes' }, data[0])
-    assert_equal('some content',             data[1])
-
-    # Create object with period
-    assert_raises(RuntimeError) do
-      data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/as.df/')
-    end
+    objects = data_source.send(:load_objects, 'foo', 'The Foo', Nanoc::Int::Item)
+    assert_equal 1, objects.size
+    assert_equal '/donkey.jpeg', objects.first.identifier.to_s
   end
 
   def test_filename_for
@@ -528,7 +512,8 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     data_source = new_data_source
 
     # Create item
-    data_source.create_item('Hëllö', {}, '/foo/')
+    FileUtils.mkdir_p('content')
+    File.open('content/foo.md', 'w') { |io| io << 'Hëllö' }
 
     # Parse
     begin
@@ -538,7 +523,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       items = data_source.items
 
       assert_equal 1, items.size
-      assert_equal Encoding.find('UTF-8'), items[0].raw_content.encoding
+      assert_equal Encoding.find('UTF-8'), items[0].content.string.encoding
     ensure
       Encoding.default_external = original_default_external_encoding
     end
@@ -560,7 +545,8 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       original_default_external_encoding = Encoding.default_external
       Encoding.default_external = 'ISO-8859-1'
 
-      data_source.create_item('Hëllö', {}, '/foo/')
+      FileUtils.mkdir_p('content')
+      File.open('content/foo.md', 'w') { |io| io << 'Hëllö' }
     ensure
       Encoding.default_external = original_default_external_encoding
     end
@@ -568,6 +554,6 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     # Parse
     items = data_source.items
     assert_equal 1, items.size
-    assert_equal Encoding.find('UTF-8'), items[0].raw_content.encoding
+    assert_equal Encoding.find('UTF-8'), items[0].content.string.encoding
   end
 end
