@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
   def test_run
     with_site do |site|
@@ -9,7 +7,7 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
       File.open('output/bar.html', 'w') { |io| io.write('<a href="http://example.com/">not broken</a>') }
 
       # Create check
-      check = Nanoc::Extra::Checking::Checks::ExternalLinks.new(site)
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
       def check.request_url_once(url)
         Net::HTTPResponse.new('1.1', url.path == '/' ? '200' : '404', 'okay')
       end
@@ -23,7 +21,7 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
   def test_valid_by_path
     with_site do |site|
       # Create check
-      check = Nanoc::Extra::Checking::Checks::ExternalLinks.new(site)
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
       def check.request_url_once(url)
         Net::HTTPResponse.new('1.1', url.path == '/200' ? '200' : '404', 'okay')
       end
@@ -38,7 +36,7 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
   def test_valid_by_query
     with_site do |site|
       # Create check
-      check = Nanoc::Extra::Checking::Checks::ExternalLinks.new(site)
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
       def check.request_url_once(url)
         Net::HTTPResponse.new('1.1', url.query == 'status=200' ? '200' : '404', 'okay')
       end
@@ -52,7 +50,7 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
   def test_fallback_to_get_when_head_is_not_allowed
     with_site do |site|
       # Create check
-      check = Nanoc::Extra::Checking::Checks::ExternalLinks.new(site)
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
       def check.request_url_once(url, req_method = Net::HTTP::Head)
         Net::HTTPResponse.new('1.1', (req_method == Net::HTTP::Head || url.path == '/405') ? '405' : '200', 'okay')
       end
@@ -65,7 +63,7 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
 
   def test_path_for_url
     with_site do |site|
-      check = Nanoc::Extra::Checking::Checks::ExternalLinks.new(site)
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
 
       assert_equal '/',             check.send(:path_for_url, URI.parse('http://example.com'))
       assert_equal '/',             check.send(:path_for_url, URI.parse('http://example.com/'))
@@ -74,4 +72,29 @@ class Nanoc::Extra::Checking::Checks::ExternalLinksTest < Nanoc::TestCase
       assert_equal '/meow?foo=bar', check.send(:path_for_url, URI.parse('http://example.com/meow?foo=bar'))
     end
   end
+
+  def test_excluded
+    with_site do |site|
+      # Create check
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
+      site.config.update({ checks: { external_links: { exclude: ['^http://excluded.com$'] } } })
+
+      # Test
+      assert check.send(:excluded?, 'http://excluded.com')
+      refute check.send(:excluded?, 'http://excluded.com/notexcluded')
+      refute check.send(:excluded?, 'http://notexcluded.com')
+    end
+  end
+
+  def test_excluded_file
+    with_site do |site|
+      # Create check
+      check = Nanoc::Extra::Checking::Checks::ExternalLinks.create(site)
+      site.config.update({ checks: { external_links: { exclude_files: ['blog/page'] } } })
+
+      # Test
+      assert check.send(:excluded_file?, 'output/blog/page1/index.html')
+      refute check.send(:excluded_file?, 'output/blog/pag1/index.html')
+    end
+  end
 end
