@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
   def test_run_ok
     VCR.use_cassette('html_run_ok') do
@@ -10,7 +8,7 @@ class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
         File.open('output/style.css', 'w') { |io| io.write('h1 { coxlor: rxed; }') }
 
         # Run check
-        check = Nanoc::Extra::Checking::Checks::HTML.new(site)
+        check = Nanoc::Extra::Checking::Checks::HTML.create(site)
         check.run
 
         # Check
@@ -28,7 +26,7 @@ class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
         File.open('output/style.css', 'w') { |io| io.write('h1 { coxlor: rxed; }') }
 
         # Run check
-        check = Nanoc::Extra::Checking::Checks::HTML.new(site)
+        check = Nanoc::Extra::Checking::Checks::HTML.create(site)
         check.run
 
         # Check
@@ -36,7 +34,6 @@ class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
         assert_equal 2, check.issues.size
         assert_equal 'line 1: no document type declaration; will parse without validation: <h2>Hi!</h1>', check.issues.to_a[0].description
         assert_equal 'line 1: end tag for element "H1" which is not open: <h2>Hi!</h1>', check.issues.to_a[1].description
-          check.issues.to_a[0].description
       end
     end
   end
