@@ -1,15 +1,12 @@
-# encoding: utf-8
-
 class Nanoc::Extra::Checking::Checks::StaleTest < Nanoc::TestCase
   def check_class
     Nanoc::Extra::Checking::Checks::Stale
   end
 
   def calc_issues
-    site = Nanoc::Site.new('.')
-    check = check_class.new(site)
-    check.run
-    check.issues
+    site = Nanoc::Int::SiteLoader.new.new_from_cwd
+    runner = Nanoc::Extra::Checking::Runner.new(site)
+    runner.run_checks([check_class])
   end
 
   def test_run_ok
@@ -47,7 +44,7 @@ class Nanoc::Extra::Checking::Checks::StaleTest < Nanoc::TestCase
       assert Dir['content/*'].empty?
       assert Dir['output/*'].empty?
 
-      File.open('nanoc.yaml', 'w') { |io| io.write "prune:\n  exclude: [ 'excluded.html' ]" }
+      File.open('nanoc.yaml', 'w') { |io| io.write "string_pattern_type: legacy\nprune:\n  exclude: [ 'excluded.html' ]" }
       File.open('content/index.html', 'w') { |io| io.write('stuff') }
       File.open('output/excluded.html', 'w') { |io| io.write('stuff') }
       assert calc_issues.empty?
@@ -59,7 +56,7 @@ class Nanoc::Extra::Checking::Checks::StaleTest < Nanoc::TestCase
       assert Dir['content/*'].empty?
       assert Dir['output/*'].empty?
 
-      File.open('nanoc.yaml', 'w') { |io| io.write "prune:\n  blah: meh" }
+      File.open('nanoc.yaml', 'w') { |io| io.write "string_pattern_type: legacy\nprune:\n  blah: meh" }
       File.open('content/index.html', 'w') { |io| io.write('stuff') }
       File.open('output/excluded.html', 'w') { |io| io.write('stuff') }
       refute calc_issues.empty?
