@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Extra::Deployers::RsyncTest < Nanoc::TestCase
   def test_run_without_dst
     # Create deployer
@@ -59,7 +57,7 @@ class Nanoc::Extra::Deployers::RsyncTest < Nanoc::TestCase
     opts = Nanoc::Extra::Deployers::Rsync::DEFAULT_OPTIONS
     assert_equal(
       ['rsync', opts, 'output/', 'asdf'].flatten,
-      rsync.instance_eval { @shell_cms_args }
+      rsync.instance_eval { @shell_cms_args },
     )
   end
 
@@ -82,7 +80,7 @@ class Nanoc::Extra::Deployers::RsyncTest < Nanoc::TestCase
     opts = Nanoc::Extra::Deployers::Rsync::DEFAULT_OPTIONS
     assert_equal(
       ['echo', 'rsync', opts, 'output/', 'asdf'].flatten,
-      rsync.instance_eval { @shell_cms_args }
+      rsync.instance_eval { @shell_cms_args },
     )
   end
 end
