@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Extra::FilesystemToolsTest < Nanoc::TestCase
   def setup
     super
@@ -30,7 +28,7 @@ class Nanoc::Extra::FilesystemToolsTest < Nanoc::TestCase
       'dir0/sub/sub/sub/sub/sub/sub/sub/foo.md',
       'dir0/sub/sub/sub/sub/sub/sub/sub/sub/foo.md',
       'dir0/sub/sub/sub/sub/sub/sub/sub/sub/sub/foo.md',
-      'dir0/sub/sub/sub/sub/sub/sub/sub/sub/sub/sub/foo.md'
+      'dir0/sub/sub/sub/sub/sub/sub/sub/sub/sub/sub/foo.md',
     ]
     actual_files = Nanoc::Extra::FilesystemTools.all_files_in('dir0', nil).sort
     assert_equal expected_files, actual_files
@@ -137,7 +135,7 @@ class Nanoc::Extra::FilesystemToolsTest < Nanoc::TestCase
 
     pattern = { dotfiles: '**/.other' }
 
-    assert_raises Nanoc::Errors::GenericTrivial, "Do not know how to handle extra_files: #{pattern.inspect}" do
+    assert_raises Nanoc::Int::Errors::GenericTrivial, "Do not know how to handle extra_files: #{pattern.inspect}" do
       Nanoc::Extra::FilesystemTools.all_files_in('dir0', pattern)
     end
   end
