@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Filters::ERBTest < Nanoc::TestCase
   def test_filter_with_instance_variable
     # Create filter
@@ -27,11 +25,11 @@ class Nanoc::Filters::ERBTest < Nanoc::TestCase
     item_rep.expect(:name, :quux)
 
     # Create filter
-    filter = ::Nanoc::Filters::ERB.new({
+    filter = ::Nanoc::Filters::ERB.new(
       item: item,
       item_rep: item_rep,
-      location: 'a cheap motel'
-    })
+      location: 'a cheap motel',
+    )
 
     # Run filter
     raised = false
@@ -39,7 +37,7 @@ class Nanoc::Filters::ERBTest < Nanoc::TestCase
       filter.setup_and_run('<%= this isn\'t really ruby so it\'ll break, muahaha %>')
     rescue SyntaxError => e
       e.message =~ /(.+?):\d+: /
-      assert_match 'item /foo/bar/baz/ (rep quux)', $1
+      assert_match 'item /foo/bar/baz/ (rep quux)', Regexp.last_match[1]
       raised = true
     end
     assert raised
@@ -79,7 +77,7 @@ class Nanoc::Filters::ERBTest < Nanoc::TestCase
 
     # With
     assert_raises(SecurityError) do
-      res = filter.setup_and_run('<%= File.read("moo") %>', safe_level: 3)
+      res = filter.setup_and_run('<%= eval File.read("moo") %>', safe_level: 1)
     end
   end
 
