@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Filters::ErubisTest < Nanoc::TestCase
   def test_filter_with_instance_variable
     if_have 'erubis' do
@@ -34,7 +32,7 @@ class Nanoc::Filters::ErubisTest < Nanoc::TestCase
         filter.setup_and_run('<%= this isn\'t really ruby so it\'ll break, muahaha %>')
       rescue SyntaxError => e
         e.message =~ /(.+?):\d+: /
-        assert_match '?', $1
+        assert_match '?', Regexp.last_match[1]
         raised = true
       end
       assert raised
