@@ -1,14 +1,12 @@
-# encoding: utf-8
-
 class Nanoc::Filters::HandlebarsTest < Nanoc::TestCase
   def test_filter
     if_have 'handlebars' do
       # Create data
-      item = Nanoc::Item.new(
+      item = Nanoc::Int::Item.new(
         'content',
         { title: 'Max Payne', protagonist: 'Max Payne', location: 'here' },
         '/games/max-payne/')
-      layout = Nanoc::Layout.new(
+      layout = Nanoc::Int::Layout.new(
         'layout content',
         { name: 'Max Payne' },
         '/default/')
@@ -19,7 +17,7 @@ class Nanoc::Filters::HandlebarsTest < Nanoc::TestCase
         item: item,
         layout: layout,
         config: config,
-        content: 'No Payne No Gayne'
+        content: 'No Payne No Gayne',
       }
       filter = ::Nanoc::Filters::Handlebars.new(assigns)
 
@@ -36,7 +34,7 @@ class Nanoc::Filters::HandlebarsTest < Nanoc::TestCase
   def test_filter_without_layout
     if_have 'handlebars' do
       # Create data
-      item = Nanoc::Item.new(
+      item = Nanoc::Int::Item.new(
         'content',
         { title: 'Max Payne', protagonist: 'Max Payne', location: 'here' },
         '/games/max-payne/')
@@ -44,7 +42,7 @@ class Nanoc::Filters::HandlebarsTest < Nanoc::TestCase
       # Create filter
       assigns = {
         item: item,
-        content: 'No Payne No Gayne'
+        content: 'No Payne No Gayne',
       }
       filter = ::Nanoc::Filters::Handlebars.new(assigns)
 
