@@ -1,13 +1,11 @@
-# encoding: utf-8
-
 class Nanoc::Filters::MustacheTest < Nanoc::TestCase
   def test_filter
     if_have 'mustache' do
       # Create item
-      item = Nanoc::Item.new(
+      item = Nanoc::Int::Item.new(
         'content',
         { title: 'Max Payne', protagonist: 'Max Payne' },
-        '/games/max-payne/'
+        '/games/max-payne/',
       )
 
       # Create filter
@@ -22,10 +20,10 @@ class Nanoc::Filters::MustacheTest < Nanoc::TestCase
   def test_filter_with_yield
     if_have 'mustache' do
       # Create item
-      item = Nanoc::Item.new(
+      item = Nanoc::Int::Item.new(
         'content',
         { title: 'Max Payne', protagonist: 'Max Payne' },
-        '/games/max-payne/'
+        '/games/max-payne/',
       )
 
       # Create filter
