@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Filters::RedClothTest < Nanoc::TestCase
   def test_filter
     if_have 'redcloth' do
@@ -19,7 +17,7 @@ class Nanoc::Filters::RedClothTest < Nanoc::TestCase
 
       # Run filter without options
       result = filter.setup_and_run('I am a member of SPECTRE.')
-      assert_equal("<p>I am a member of <span class=\"caps\">SPECTRE</span>.</p>", result)
+      assert_equal('<p>I am a member of <span class="caps">SPECTRE</span>.</p>', result)
 
       # Run filter with options
       result = filter.setup_and_run('I am a member of SPECTRE.', no_span_caps: true)
