@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
   def test_filter_html_with_double_quotes
     # Create filter with mock item
@@ -7,13 +5,13 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -31,13 +29,13 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -55,13 +53,13 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -79,13 +77,13 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -115,13 +113,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -139,13 +137,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -163,13 +161,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -187,13 +185,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -211,13 +209,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -235,13 +233,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -259,13 +257,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -283,13 +281,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -307,13 +305,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     raw_content    = %(<object data="/example"><param name="movie" content="/example"></object>)
@@ -339,13 +337,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -363,13 +361,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -387,13 +385,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -411,13 +409,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
@@ -438,13 +436,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -462,13 +460,13 @@ EOS
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/woof/meow/'
+      @item_rep.paths[:last] = '/woof/meow/'
     end
 
     # Set content
@@ -487,13 +485,13 @@ EOS
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/bar/baz/'),
           :blah)
-        @item_rep.path = '/foo/bar/baz/'
+        @item_rep.paths[:last] = '/foo/bar/baz/'
       end
 
       # Set content
@@ -518,13 +516,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/bar/baz/'),
           :blah)
-        @item_rep.path = '/foo/bar/baz/'
+        @item_rep.paths[:last] = '/foo/bar/baz/'
       end
 
       # Set content
@@ -548,13 +546,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/bar/baz/'),
           :blah)
-        @item_rep.path = '/foo/bar/baz/'
+        @item_rep.paths[:last] = '/foo/bar/baz/'
       end
 
       # Set content
@@ -564,11 +562,12 @@ XML
 </foo>
 XML
 
-      actual_content = filter.setup_and_run(raw_content, {
+      options = {
         type: :xml,
         namespaces: { ex: 'http://example.org' },
-        select: ['ex:a/@href']
-      })
+        select: ['ex:a/@href'],
+      }
+      actual_content = filter.setup_and_run(raw_content, options)
 
       assert_match(/<foo xmlns="http:\/\/example.org">/,    actual_content)
       assert_match(/<bar><a href="..\/..">baz<\/a><\/bar>/, actual_content)
@@ -582,13 +581,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/bar/baz/'),
           :blah)
-        @item_rep.path = '/foo/bar/baz/'
+        @item_rep.paths[:last] = '/foo/bar/baz/'
       end
 
       # Set content
@@ -622,13 +621,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/bar/baz/'),
           :blah)
-        @item_rep.path = '/foo/bar/baz/'
+        @item_rep.paths[:last] = '/foo/bar/baz/'
       end
 
       # Set content
@@ -655,13 +654,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/baz/'),
           :blah)
-        @item_rep.path = '/foo/baz/'
+        @item_rep.paths[:last] = '/foo/baz/'
       end
 
       # Set content
@@ -687,13 +686,13 @@ XML
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::ItemRep.new(
-          Nanoc::Item.new(
+        @item_rep = Nanoc::Int::ItemRep.new(
+          Nanoc::Int::Item.new(
             'content',
             {},
             '/foo/baz/'),
           :blah)
-        @item_rep.path = '/foo/baz/'
+        @item_rep.paths[:last] = '/foo/baz/'
       end
 
       # Set content
@@ -716,13 +715,13 @@ XML
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::ItemRep.new(
-        Nanoc::Item.new(
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
           'content',
           {},
           '/foo/bar/baz/'),
         :blah)
-      @item_rep.path = '/foo/bar/baz/'
+      @item_rep.paths[:last] = '/foo/bar/baz/'
     end
 
     # Set content
