@@ -1,6 +1,14 @@
-# encoding: utf-8
-
 class Nanoc::Filters::SassTest < Nanoc::TestCase
+  def setup
+    super
+
+    if_have 'sass' do
+      unless ::Sass.load_paths.include?('.')
+        ::Sass.load_paths << '.'
+      end
+    end
+  end
+
   def test_filter
     if_have 'sass' do
       # Get filter
@@ -123,7 +131,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Compile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Check
@@ -138,7 +146,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Recompile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Recheck
@@ -178,7 +186,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Compile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Check
@@ -193,7 +201,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Recompile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Recheck
@@ -245,7 +253,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Compile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Check
@@ -259,7 +267,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         end
 
         # Recompile
-        site = Nanoc::Site.new('.')
+        site = Nanoc::Int::SiteLoader.new.new_from_cwd
         site.compile
 
         # Recheck
@@ -276,7 +284,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
         io.write("p\n  color: blue")
       end
 
-      options = { :filename => File.join(Dir.getwd, 'test.sass') }
+      options = { filename: File.join(Dir.getwd, 'test.sass') }
       ::Sass::Engine.new('@import "morestuff"', options).render
     end
   end
@@ -287,10 +295,16 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
     FileUtils.mkdir_p('content')
     File.open('content/xyzzy.sass', 'w') { |io| io.write('p\n  color: green') }
 
-    items = [Nanoc::Item.new(
-      'blah',
-      { content_filename: 'content/xyzzy.sass' },
-      '/blah/')]
+    items = [
+      Nanoc::ItemWithRepsView.new(
+        Nanoc::Int::Item.new(
+          'blah',
+          { content_filename: 'content/xyzzy.sass' },
+          '/blah/',
+        ),
+        nil,
+      ),
+    ]
     params = { item: items[0], items: items }.merge(params)
     ::Nanoc::Filters::Sass.new(params)
   end
