@@ -1,9 +1,7 @@
-# encoding: utf-8
-
 require 'tempfile'
 
 class Nanoc::Filters::XSLTest < Nanoc::TestCase
-  SAMPLE_XSL = <<-EOS
+  SAMPLE_XSL = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
@@ -20,7 +18,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
 </xsl:stylesheet>
 EOS
 
-  SAMPLE_XML_IN = <<-EOS
+  SAMPLE_XML_IN = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <report>
   <title>My Report</title>
@@ -29,7 +27,7 @@ EOS
 
   SAMPLE_XML_OUT = %r{\A<\?xml version="1.0" encoding="utf-8"\?>\s*<html>\s*<head>\s*<title>My Report</title>\s*</head>\s*<body>\s*<h1>My Report</h1>\s*</body>\s*</html>\s*\Z}m
 
-  SAMPLE_XSL_WITH_PARAMS = <<-EOS
+  SAMPLE_XSL_WITH_PARAMS = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
@@ -47,7 +45,7 @@ EOS
 </xsl:stylesheet>
 EOS
 
-  SAMPLE_XML_IN_WITH_PARAMS = <<-EOS
+  SAMPLE_XML_IN_WITH_PARAMS = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <report>
   <title>My Report</title>
@@ -56,7 +54,7 @@ EOS
 
   SAMPLE_XML_OUT_WITH_PARAMS = %r{\A<\?xml version="1.0" encoding="utf-8"\?>\s*<html>\s*<head>\s*<title>My Report</title>\s*</head>\s*<body>\s*<h1>bar</h1>\s*</body>\s*</html>\s*\Z}m
 
-  SAMPLE_XSL_WITH_OMIT_XML_DECL = <<-EOS
+  SAMPLE_XSL_WITH_OMIT_XML_DECL = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"
@@ -74,7 +72,7 @@ EOS
 </xsl:stylesheet>
 EOS
 
-  SAMPLE_XML_IN_WITH_OMIT_XML_DECL = <<-EOS
+  SAMPLE_XML_IN_WITH_OMIT_XML_DECL = <<-EOS.freeze
 <?xml version="1.0" encoding="utf-8"?>
 <report>
   <title>My Report</title>
@@ -86,18 +84,16 @@ EOS
   def test_filter_as_layout
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Item.new(SAMPLE_XML_IN,
-                             {},
-                             '/content/')
-      layout = Nanoc::Layout.new(SAMPLE_XSL,
-                                 {},
-                                 '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN, {}, '/content/')
+      item = Nanoc::ItemWithRepsView.new(item, nil)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL, {}, '/layout/')
+      layout = Nanoc::LayoutView.new(layout, nil)
 
       # Create an instance of the filter
       assigns = {
         item: item,
         layout: layout,
-        content: item.raw_content
+        content: item.raw_content,
       }
       filter = ::Nanoc::Filters::XSL.new(assigns)
 
@@ -110,24 +106,21 @@ EOS
   def test_filter_with_params
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Item.new(SAMPLE_XML_IN_WITH_PARAMS,
-                             {},
-                             '/content/')
-      layout = Nanoc::Layout.new(SAMPLE_XSL_WITH_PARAMS,
-                                 {},
-                                 '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_PARAMS, {}, '/content/')
+      item = Nanoc::ItemWithRepsView.new(item, nil)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_PARAMS, {}, '/layout/')
+      layout = Nanoc::LayoutView.new(layout, nil)
 
       # Create an instance of the filter
       assigns = {
         item: item,
         layout: layout,
-        content: item.raw_content
+        content: item.raw_content,
       }
       filter = ::Nanoc::Filters::XSL.new(assigns)
 
       # Run the filter and validate the results
-      result = filter.setup_and_run(layout.raw_content,
-                                    foo: 'bar')
+      result = filter.setup_and_run(layout.raw_content, foo: 'bar')
       assert_match SAMPLE_XML_OUT_WITH_PARAMS, result
     end
   end
@@ -135,18 +128,16 @@ EOS
   def test_filter_with_omit_xml_decl
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Item.new(SAMPLE_XML_IN_WITH_OMIT_XML_DECL,
-                             {},
-                             '/content/')
-      layout = Nanoc::Layout.new(SAMPLE_XSL_WITH_OMIT_XML_DECL,
-                                 {},
-                                 '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_OMIT_XML_DECL, {}, '/content/')
+      item = Nanoc::ItemWithRepsView.new(item, nil)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_OMIT_XML_DECL, {}, '/layout/')
+      layout = Nanoc::LayoutView.new(layout, nil)
 
       # Create an instance of the filter
       assigns = {
         item: item,
         layout: layout,
-        content: item.raw_content
+        content: item.raw_content,
       }
       filter = ::Nanoc::Filters::XSL.new(assigns)
 
