@@ -1,34 +1,27 @@
-# encoding: utf-8
+require 'simplecov'
+SimpleCov.start
 
-# Set up gem loading (necessary for cri dependency)
-require File.dirname(__FILE__) + '/gem_loader.rb'
-
-# Load unit testing stuff
 require 'minitest/test'
 require 'minitest/spec'
 require 'minitest/mock'
+require 'minitest/autorun'
 require 'mocha/setup'
 require 'vcr'
 
-# Setup coverage
-require 'coveralls'
-Coveralls.wear!
-
-# Load nanoc
-$LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__) + '/../lib'))
-require 'nanoc'
-require 'nanoc/cli'
-require 'nanoc/tasks'
-
-# Load miscellaneous requirements
 require 'tmpdir'
 require 'stringio'
+require 'yard'
 
 VCR.configure do |c|
   c.cassette_library_dir = 'test/fixtures/vcr_cassettes'
   c.hook_into :webmock
 end
 
+require 'nanoc'
+require 'nanoc/cli'
+
+Nanoc::CLI.setup
+
 module Nanoc::TestHelpers
   LIB_DIR = File.expand_path(File.dirname(__FILE__) + '/../lib')
 
@@ -40,14 +33,12 @@ module Nanoc::TestHelpers
     libs.each do |lib|
       if defined?(RUBY_ENGINE) && RUBY_ENGINE == 'jruby' && lib == 'nokogiri' && disable_nokogiri?
         skip 'Pure Java Nokogiri has issues that cause problems with nanoc (see https://github.com/nanoc/nanoc/pull/422) -- run without DISABLE_NOKOGIRI to enable Nokogiri tests'
-        return
       end
 
       begin
         require lib
       rescue LoadError
         skip "requiring #{lib} failed"
-        return
       end
     end
 
@@ -103,14 +94,21 @@ EOS
           end
         end
 
-        File.open('nanoc.yaml', 'w') { |io| io.write('stuff: 12345') }
+        File.open('nanoc.yaml', 'w') do |io|
+          io << 'string_pattern_type: legacy' << "\n" if params.fetch(:legacy, true)
+          io << 'data_sources:' << "\n"
+          io << '  -' << "\n"
+          io << '    type: filesystem' << "\n"
+          io << '    identifier_type: legacy' << "\n" if params.fetch(:legacy, true)
+        end
+
         File.open('Rules', 'w') { |io| io.write(rules_content) }
       end
     end
 
     # Yield site
     FileUtils.cd(site_name) do
-      yield Nanoc::Site.new('.')
+      yield Nanoc::Int::SiteLoader.new.new_from_cwd
     end
   end
 
@@ -199,22 +197,30 @@ EOS
         actual_out   = eval(pair.first, b)
         expected_out = eval(pair.last.match(/# ?=>(.*)/)[1], b)
 
-        assert_equal expected_out, actual_out,
-          "Incorrect example:\n#{pair.first}"
+        assert_equal(
+          expected_out,
+          actual_out,
+          "Incorrect example:\n#{pair.first}",
+        )
       end
     end
   end
 
   def assert_contains_exactly(expected, actual)
-    assert_equal expected.size, actual.size,
-      format('Expected %s to be of same size as %s', actual.inspect, expected.inspect)
+    assert_equal(
+      expected.size,
+      actual.size,
+      format('Expected %s to be of same size as %s', actual.inspect, expected.inspect),
+    )
     remaining = actual.dup.to_a
     expected.each do |e|
       index = remaining.index(e)
       remaining.delete_at(index) if index
     end
-    assert remaining.empty?,
-      format('Expected %s to contain all the elements of %s', actual.inspect, expected.inspect)
+    assert(
+      remaining.empty?,
+      format('Expected %s to contain all the elements of %s', actual.inspect, expected.inspect),
+    )
   end
 
   def assert_raises_frozen_error
@@ -254,6 +260,10 @@ EOS
   def skip_unless_symlinks_supported
     skip 'Symlinks are not supported by Ruby on Windows' unless symlinks_supported?
   end
+
+  def root_dir
+    File.absolute_path(File.dirname(__FILE__) + '/..')
+  end
 end
 
 class Nanoc::TestCase < Minitest::Test
