@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   include Nanoc::Helpers::Blogging
   include Nanoc::Helpers::Text
@@ -26,64 +24,6 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     item
   end
 
-  def test_articles
-    # Create items
-    @items = [
-      Nanoc::Item.new(
-        'blah',
-        { kind: 'item' },
-        '/0/'
-      ),
-      Nanoc::Item.new(
-        'blah blah',
-        { kind: 'article' },
-        '/1/'
-      ),
-      Nanoc::Item.new(
-        'blah blah blah',
-        { kind: 'article' },
-        '/2/'
-      )
-    ]
-
-    # Check
-    assert_equal(2, articles.size)
-    assert articles.include?(@items[1])
-    assert articles.include?(@items[2])
-  ensure
-    # Cleanup
-    @items = nil
-  end
-
-  def test_sorted_articles
-    # Create items
-    @items = [
-      Nanoc::Item.new(
-        'blah',
-        { kind: 'item' },
-        '/0/'
-      ),
-      Nanoc::Item.new(
-        'blah',
-        { kind: 'article', created_at: (Date.today - 1).to_s },
-        '/1/'
-      ),
-      Nanoc::Item.new(
-        'blah',
-        { kind: 'article', created_at: (Time.now - 500).to_s },
-        '/2/'
-      )
-    ]
-
-    # Check
-    assert_equal(2,         sorted_articles.size)
-    assert_equal(@items[2], sorted_articles[0])
-    assert_equal(@items[1], sorted_articles[1])
-  ensure
-    # Cleanup
-    @items = nil
-  end
-
   def test_atom_feed
     if_have 'builder' do
       # Create items
@@ -107,8 +47,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).with(snapshot: :pre).returns('item 2 content')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -139,8 +78,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].expects(:compiled_content).returns('item 2 content')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -161,8 +99,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_item]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -171,12 +108,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: no articles',
-        error.message
+        error.message,
       )
     end
   end
@@ -187,8 +124,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: nil })
+      @config = Nanoc::ConfigView.new({ base_url: nil }, nil)
 
       # Create feed item
       @item = mock
@@ -197,12 +133,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: site configuration has no base_url',
-        error.message
+        error.message,
       )
     end
   end
@@ -213,8 +149,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -223,12 +158,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: no title in params, item or site config',
-        error.message
+        error.message,
       )
     end
   end
@@ -239,8 +174,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -249,12 +183,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: no author_name in params, item or site config',
-        error.message
+        error.message,
       )
     end
   end
@@ -270,8 +204,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].expects(:compiled_content).returns('item 1 content')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com/' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com/' }, nil)
 
       # Create feed item
       @item = mock
@@ -288,21 +221,21 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       # Still should keep feed level author
       assert_match(
         /#{Regexp.escape('<name>Denis Defreyne</name>')}/, #'
-        result
+        result,
       )
       assert_match(
         /#{Regexp.escape('<uri>http://stoneship.org/</uri>')}/, #'
-        result
+        result,
       )
 
       # Overrides on specific items
       assert_match(
         /#{Regexp.escape('<name>Don Alias</name>')}/, #'
-        result
+        result,
       )
       assert_match(
         /#{Regexp.escape('<uri>http://don.example.com/</uri>')}/, #'
-        result
+        result,
       )
     end
   end
@@ -313,8 +246,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_item, mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -323,12 +255,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns(nil)
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: no author_uri in params, item or site config',
-        error.message
+        error.message,
       )
     end
   end
@@ -341,8 +273,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[2].stubs(:[]).with(:created_at).returns(nil)
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -351,12 +282,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
       # Check
-      error = assert_raises(Nanoc::Errors::GenericTrivial) do
+      error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
         atom_feed
       end
       assert_equal(
         'Cannot build Atom feed: one or more articles lack created_at',
-        error.message
+        error.message,
       )
     end
   end
@@ -368,8 +299,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -382,7 +312,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       atom_feed(
         author_name: 'Bob',
         author_uri: 'http://example.com/~bob/',
-        title: 'My Blog Or Something'
+        title: 'My Blog Or Something',
       )
     end
   end
@@ -394,14 +324,15 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @config = {
-        author_name: 'Bob',
-        author_uri: 'http://example.com/~bob/',
-        title: 'My Blog Or Something',
-        base_url: 'http://example.com'
-      }
-      @site = mock
-      @site.stubs(:config).returns(@config)
+      @config = Nanoc::ConfigView.new(
+        {
+          author_name: 'Bob',
+          author_uri: 'http://example.com/~bob/',
+          title: 'My Blog Or Something',
+          base_url: 'http://example.com',
+        },
+        nil,
+      )
 
       # Create feed item
       @item = mock
@@ -425,8 +356,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -450,8 +380,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       end
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -464,11 +393,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       result = atom_feed limit: 1, articles: @items
       assert_match(
         Regexp.new('Article 0', Regexp::MULTILINE),
-        result
+        result,
       )
       refute_match(
         Regexp.new('Article 1', Regexp::MULTILINE),
-        result
+        result,
       )
     end
   end
@@ -484,8 +413,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].stubs(:[]).with(:created_at).returns('22-03-2009')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -498,7 +426,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       result = atom_feed
       assert_match(
         Regexp.new('Article 1.*Article 0', Regexp::MULTILINE),
-        result
+        result,
       )
     end
   end
@@ -514,8 +442,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].stubs(:[]).with(:created_at).returns('01-01-2014')
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -528,7 +455,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       result = atom_feed(preserve_order: true)
       assert_match(
         Regexp.new('Article 1.*Article 0', Regexp::MULTILINE),
-        result
+        result,
       )
     end
   end
@@ -539,8 +466,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -561,8 +487,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -583,8 +508,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -605,8 +529,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items = [mock_article]
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -628,8 +551,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      @site = mock
-      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Create feed item
       @item = mock
@@ -644,181 +566,4 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       atom_feed
     end
   end
-
-  def test_url_for_without_custom_path_in_feed
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', {}, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('http://example.com/foo/bar/', url_for(item))
-  ensure
-    # Cleanup
-    @item = nil
-  end
-
-  def test_url_for_with_custom_path_in_feed
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new(
-      'content', { custom_path_in_feed: '/meow/woof/' }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-
-    # Check
-    assert_equal('http://example.com/meow/woof/', url_for(item))
-  ensure
-    # Cleanup
-    @item = nil
-  end
-
-  def test_url_for_with_custom_url_in_feed
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new(
-      'content', { custom_url_in_feed: 'http://example.org/x' }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-
-    # Check
-    assert_equal('http://example.org/x', url_for(item))
-  ensure
-    # Cleanup
-    @item = nil
-  end
-
-  def test_url_for_without_base_url
-    # Create site
-    @site = Nanoc::Site.new({})
-
-    # Check
-    assert_raises(Nanoc::Errors::GenericTrivial) do
-      url_for(nil)
-    end
-  end
-
-  def test_url_for_without_path
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', {}, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = nil
-
-    # Check
-    assert_equal(nil, url_for(item))
-  end
-
-  def test_feed_url_without_custom_feed_url
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    @item = Nanoc::Item.new('content', {}, '/foo/')
-    @item.reps << Nanoc::ItemRep.new(@item, :default)
-    @item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('http://example.com/foo/bar/', feed_url)
-  ensure
-    # Cleanup
-    @item = nil
-  end
-
-  def test_feed_url_with_custom_feed_url
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create feed item
-    @item = Nanoc::Item.new('content', { feed_url: 'http://example.com/feed/' }, '/foo/')
-    @item.reps << Nanoc::ItemRep.new(@item, :default)
-    @item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('http://example.com/feed/', feed_url)
-  ensure
-    # Cleanup
-    @item = nil
-  end
-
-  def test_feed_url_without_base_url
-    # Create site
-    @site = Nanoc::Site.new({})
-
-    # Check
-    assert_raises(Nanoc::Errors::GenericTrivial) do
-      feed_url
-    end
-  end
-
-  def test_atom_tag_for_with_path
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('tag:example.com,2008-05-19:/foo/bar/', atom_tag_for(item))
-  end
-
-  def test_atom_tag_for_without_path
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/baz/qux/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-
-    # Check
-    assert_equal('tag:example.com,2008-05-19:/baz/qux/', atom_tag_for(item))
-  end
-
-  def test_atom_tag_for_with_base_url_in_dir
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com/somedir' })
-
-    # Create article
-    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('tag:example.com,2008-05-19:/somedir/foo/bar/', atom_tag_for(item))
-  end
-
-  def test_atom_tag_for_with_time
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', { created_at: Time.parse('2008-05-19') }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('tag:example.com,2008-05-19:/foo/bar/', atom_tag_for(item))
-  end
-
-  def test_atom_tag_for_with_date
-    # Create site
-    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
-
-    # Create article
-    item = Nanoc::Item.new('content', { created_at: Date.parse('2008-05-19') }, '/foo/')
-    item.reps << Nanoc::ItemRep.new(item, :default)
-    item.reps[0].path = '/foo/bar/'
-
-    # Check
-    assert_equal('tag:example.com,2008-05-19:/foo/bar/', atom_tag_for(item))
-  end
 end
