@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
   include Nanoc::Helpers::Capturing
 
@@ -17,16 +15,16 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
               '<% end %> foot'
 
     # Build site
-    @site = Nanoc3::Site.new({})
-    @item = Nanoc::Item.new('moo', {}, '/blah/')
-    @item.site = @site
+    site = Nanoc::Int::SiteLoader.new.new_empty
+    item = Nanoc::Int::Item.new('moo', {}, '/blah/')
+    @site = Nanoc::SiteView.new(Nanoc::Int::SiteLoader.new.new_empty, nil)
+    @item = Nanoc::ItemWithRepsView.new(item, nil)
 
     # Evaluate content
     result = ::ERB.new(content).result(binding)
 
     # Check
     assert_equal '3', content_for(@item, :sidebar).strip
-    assert_equal '3', @item[:content_for_sidebar].strip
     assert_match(/^head\s+foot$/, result)
   end
 
@@ -34,8 +32,8 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
     require 'erb'
 
     # Build site
-    @site = Nanoc3::Site.new({})
-    @item = Nanoc::Item.new('moo', {}, '/blah/')
+    @site = Nanoc::SiteView.new(Nanoc::Int::SiteLoader.new.new_empty, nil)
+    @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('moo', {}, '/blah/'), nil)
 
     # Capture
     _erbout = 'foo'
@@ -61,15 +59,15 @@ head
 <% content_for :box do %>
   basic
 <% end %>
-<% content_for :box do %>
+<% content_for :outerbox do %>
   before <%= content_for @item, :box %> after
 <% end %>
-<%= content_for @item, :box %>
+<%= content_for @item, :outerbox %>
 foot
 EOS
 
-    @site = Nanoc3::Site.new({})
-    @item = Nanoc::Item.new('content', {}, '/')
+    @site = Nanoc::SiteView.new(Nanoc::Int::SiteLoader.new.new_empty, nil)
+    @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('content', {}, '/'), nil)
 
     result = ::ERB.new(content).result(binding)
 
@@ -86,16 +84,16 @@ EOS
       io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
     end
 
-    @site = Nanoc3::Site.new({})
-    @item = Nanoc::Item.new('content', {}, '/')
+    @site = Nanoc::SiteView.new(Nanoc::Int::SiteLoader.new.new_empty, nil)
+    @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('content', {}, '/'), nil)
     content = '<% content_for :a do %>Content One<% end %>'
     ::ERB.new(content).result(binding)
 
     assert_equal 'Content One', content_for(@item, :a)
     assert_equal nil,           content_for(@item, :b)
 
-    @site = Nanoc3::Site.new({})
-    @item = Nanoc::Item.new('content', {}, '/')
+    @site = Nanoc::SiteView.new(Nanoc::Int::SiteLoader.new.new_empty, nil)
+    @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('content', {}, '/'), nil)
     content = '<% content_for :b do %>Content Two<% end %>'
     ::ERB.new(content).result(binding)
 
@@ -103,6 +101,125 @@ EOS
     assert_equal 'Content Two', content_for(@item, :b)
   end
 
+  def test_content_for_with_existing_symbol
+    with_site do |_site|
+      # Prepare
+      File.open('lib/helpers.rb', 'w') do |io|
+        io.write 'include Nanoc::Helpers::Capturing'
+      end
+      File.open('content/includer.erb', 'w') do |io|
+        io.write '[<%= content_for(@items["/includee/"], :blah) %>]'
+      end
+      File.open('Rules', 'w') do |io|
+        io.write "compile '*' do ; filter :erb ; end\n"
+        io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
+      end
+
+      File.open('content/includee.erb', 'w') do |io|
+        io.write '{<% content_for :blah do %>First content<% end %><% content_for :blah do %>Second content<% end %>}'
+      end
+
+      # Using the same symbols twice now raises an error, to be changed to concatenating in a future version
+      assert_raises do
+        Nanoc::CLI.run(%w(compile))
+      end
+    end
+  end
+
+  def test_content_for_with_existing_symbol_with_error_option
+    with_site do |_site|
+      # Prepare
+      File.open('lib/helpers.rb', 'w') do |io|
+        io.write 'include Nanoc::Helpers::Capturing'
+      end
+      File.open('content/includer.erb', 'w') do |io|
+        io.write '[<%= content_for(@items["/includee/"], :blah) %>]'
+      end
+      File.open('Rules', 'w') do |io|
+        io.write "compile '*' do ; filter :erb ; end\n"
+        io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
+      end
+
+      File.open('content/includee.erb', 'w') do |io|
+        io.write '{<% content_for :blah do %>First content<% end %><% content_for :blah, existing: :error do %>Second content<% end %>}'
+      end
+
+      assert_raises do
+        Nanoc::CLI.run(%w(compile))
+      end
+    end
+  end
+
+  def test_content_for_with_existing_symbol_with_overwrite_option
+    with_site do |_site|
+      # Prepare
+      File.open('lib/helpers.rb', 'w') do |io|
+        io.write 'include Nanoc::Helpers::Capturing'
+      end
+      File.open('content/includer.erb', 'w') do |io|
+        io.write '[<%= content_for(@items["/includee/"], :blah) %>]'
+      end
+      File.open('Rules', 'w') do |io|
+        io.write "compile '*' do ; filter :erb ; end\n"
+        io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
+      end
+
+      File.open('content/includee.erb', 'w') do |io|
+        io.write '{<% content_for :blah do %>First content<% end %><% content_for :blah, existing: :overwrite do %>Second content<% end %>}'
+      end
+
+      Nanoc::CLI.run(%w(compile))
+      assert_equal '[Second content]', File.read('output/includer/index.html')
+    end
+  end
+
+  def test_content_for_with_existing_symbol_with_append_option
+    with_site do |_site|
+      # Prepare
+      File.open('lib/helpers.rb', 'w') do |io|
+        io.write 'include Nanoc::Helpers::Capturing'
+      end
+      File.open('content/includer.erb', 'w') do |io|
+        io.write '[<%= content_for(@items["/includee/"], :blah) %>]'
+      end
+      File.open('Rules', 'w') do |io|
+        io.write "compile '*' do ; filter :erb ; end\n"
+        io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
+      end
+
+      File.open('content/includee.erb', 'w') do |io|
+        io.write '{<% content_for :blah do %>First content<% end %><% content_for :blah, existing: :append do %>Second content<% end %>}'
+      end
+
+      Nanoc::CLI.run(%w(compile))
+      assert_equal '[First contentSecond content]', File.read('output/includer/index.html')
+    end
+  end
+
+  def test_content_for_with_existing_symbol_with_unrecognised_option
+    with_site do |_site|
+      # Prepare
+      File.open('lib/helpers.rb', 'w') do |io|
+        io.write 'include Nanoc::Helpers::Capturing'
+      end
+      File.open('content/includer.erb', 'w') do |io|
+        io.write '[<%= content_for(@items["/includee/"], :blah) %>]'
+      end
+      File.open('Rules', 'w') do |io|
+        io.write "compile '*' do ; filter :erb ; end\n"
+        io.write "route '*' do ; item.identifier + 'index.html' ; end\n"
+      end
+
+      File.open('content/includee.erb', 'w') do |io|
+        io.write '{<% content_for :blah, existing: :donkey do %>First content<% end %>}'
+      end
+
+      assert_raises(ArgumentError) do
+        Nanoc::CLI.run(%w(compile))
+      end
+    end
+  end
+
   def test_dependencies
     with_site do |_site|
       # Prepare
