@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
   include Nanoc::Helpers::Filtering
 
@@ -13,7 +11,7 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
 
       # Mock item and rep
       @item_rep = mock
-      @item_rep.expects(:assigns).returns({})
+      @item_rep = Nanoc::ItemRepView.new(@item_rep, nil)
 
       # Evaluate content
       result = ::ERB.new(content).result(binding)
@@ -26,27 +24,19 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
 
   def test_filter_with_assigns
     if_have 'rubypants' do
-      # Build content to be evaluated
       content = "<p>Foo...</p>\n" \
                 "<% filter :erb do %>\n" \
                 " <p><%%= @item[:title] %></p>\n" \
                 "<% end %>\n"
 
-      # Mock item and rep
-      @item = mock
-      @item.expects(:[]).with(:title).returns('Bar...')
-      @item.expects(:identifier).returns('/blah/')
-      @item_rep = mock
-      @item_rep.expects(:name).returns('default')
-      @item_rep.expects(:assigns).returns({
-        item: @item,
-        item_rep: @item_rep
-      })
+      item = Nanoc::Int::Item.new('stuff', { title: 'Bar...' }, '/foo.md')
+      item_rep = Nanoc::Int::ItemRep.new(item, :default)
+
+      @item = Nanoc::ItemWithRepsView.new(item, nil)
+      @item_rep = Nanoc::ItemRepView.new(item_rep, nil)
 
-      # Evaluate content
       result = ::ERB.new(content).result(binding)
 
-      # Check
       assert_match('<p>Foo...</p>', result)
       assert_match('<p>Bar...</p>', result)
     end
@@ -60,7 +50,7 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
               "<% end %>\n"
 
     # Evaluate content
-    assert_raises(Nanoc::Errors::UnknownFilter) do
+    assert_raises(Nanoc::Int::Errors::UnknownFilter) do
       ::ERB.new(content).result(binding)
     end
   end
@@ -68,17 +58,17 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
   def test_filter_with_arguments
     if_have 'coderay' do
       # Build content to be evaluated
-      content = "<% filter :coderay, :language => 'ruby' do %>\n" \
-                "   def some_function ; x = blah.foo ; x.bar 'xyzzy' ; end\n" \
+      content = "<% filter :erb, locals: { sheep: 'baah' } do %>\n" \
+                "   Sheep says <%%= @sheep %>!\n" \
                 "<% end %>\n"
 
       # Mock item and rep
       @item_rep = mock
-      @item_rep.expects(:assigns).returns({})
+      @item_rep = Nanoc::ItemRepView.new(@item_rep, nil)
 
       # Evaluate content
       result = ::ERB.new(content).result(binding)
-      assert_match(%r{<span class="keyword">def</span> <span class="function">some_function</span>}, result)
+      assert_match(%r{Sheep says baah!}, result)
     end
   end
 
@@ -92,7 +82,7 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
 
       # Mock item and rep
       @item_rep = mock
-      @item_rep.expects(:assigns).returns({})
+      @item_rep = Nanoc::ItemRepView.new(@item_rep, nil)
 
       # Evaluate content
       result = ::Haml::Engine.new(content).render(binding)
@@ -102,8 +92,8 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
 
   def test_notifications
     notifications = Set.new
-    Nanoc::NotificationCenter.on(:filtering_started) { notifications << :filtering_started }
-    Nanoc::NotificationCenter.on(:filtering_ended)   { notifications << :filtering_ended   }
+    Nanoc::Int::NotificationCenter.on(:filtering_started) { notifications << :filtering_started }
+    Nanoc::Int::NotificationCenter.on(:filtering_ended)   { notifications << :filtering_ended   }
 
     # Build content to be evaluated
     content = "<% filter :erb do %>\n" \
@@ -112,7 +102,7 @@ class Nanoc::Helpers::FilteringTest < Nanoc::TestCase
 
     # Mock item and rep
     @item_rep = mock
-    @item_rep.expects(:assigns).returns({})
+    @item_rep = Nanoc::ItemRepView.new(@item_rep, nil)
 
     ::ERB.new(content).result(binding)
 
