@@ -1,37 +1,40 @@
-# encoding: utf-8
-
 class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
   include Nanoc::Helpers::LinkTo
 
   def test_link_to_with_path
-    # Check
     assert_equal(
       '<a href="/foo/">Foo</a>',
-      link_to('Foo', '/foo/')
+      link_to('Foo', '/foo/'),
     )
   end
 
-  def test_link_to_with_rep
-    # Create rep
-    rep = mock
-    rep.stubs(:path).returns('/bar/')
+  def test_link_to_with_item_without_reps_view
+    target = Nanoc::ItemWithoutRepsView.new(mock, {})
+    target.stubs(:path).returns('/bar/')
 
-    # Check
     assert_equal(
       '<a href="/bar/">Bar</a>',
-      link_to('Bar', rep)
+      link_to('Bar', target),
     )
   end
 
-  def test_link_to_with_item
-    # Create rep
-    item = mock
-    item.stubs(:path).returns('/bar/')
+  def test_link_to_with_item_with_reps_view
+    target = Nanoc::ItemWithRepsView.new(mock, {})
+    target.stubs(:path).returns('/bar/')
 
-    # Check
     assert_equal(
       '<a href="/bar/">Bar</a>',
-      link_to('Bar', item)
+      link_to('Bar', target),
+    )
+  end
+
+  def test_link_to_with_item_rep_view
+    target = Nanoc::ItemRepView.new(mock, {})
+    target.stubs(:path).returns('/bar/')
+
+    assert_equal(
+      '<a href="/bar/">Bar</a>',
+      link_to('Bar', target),
     )
   end
 
@@ -39,7 +42,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Check
     assert_equal(
       '<a title="Dis mai foo!" href="/foo/">Foo</a>',
-      link_to('Foo', '/foo/', title: 'Dis mai foo!')
+      link_to('Foo', '/foo/', title: 'Dis mai foo!'),
     )
   end
 
@@ -47,18 +50,16 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Check
     assert_equal(
       '<a title="Foo &amp; Bar" href="/foo&amp;bar/">Foo &amp; Bar</a>',
-      link_to('Foo &amp; Bar', '/foo&bar/', title: 'Foo & Bar')
+      link_to('Foo &amp; Bar', '/foo&bar/', title: 'Foo & Bar'),
     )
   end
 
   def test_link_to_to_nil_item_or_item_rep
-    obj = Object.new
-    def obj.path
-      nil
-    end
+    target = Nanoc::ItemRepView.new(mock, {})
+    target.stubs(:path).returns(nil)
 
     assert_raises RuntimeError do
-      link_to('Some Text', obj)
+      link_to('Some Text', target)
     end
   end
 
@@ -69,8 +70,8 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
 
     # Check
     assert_equal(
-      '<span class="active" title="You\'re here.">Bar</span>',
-      link_to_unless_current('Bar', @item_rep)
+      '<span class="active">Bar</span>',
+      link_to_unless_current('Bar', @item_rep),
     )
   ensure
     @item = nil
@@ -84,7 +85,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Check
     assert_equal(
       '<a href="/abc/xyz/">Bar</a>',
-      link_to_unless_current('Bar', '/abc/xyz/')
+      link_to_unless_current('Bar', '/abc/xyz/'),
     )
   end
 
@@ -96,7 +97,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       './',
-      relative_path_to('/foo/bar/baz/')
+      relative_path_to('/foo/bar/baz/'),
     )
   end
 
@@ -108,7 +109,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       '../../../',
-      relative_path_to('/')
+      relative_path_to('/'),
     )
   end
 
@@ -120,7 +121,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       '../../quux',
-      relative_path_to('/foo/quux')
+      relative_path_to('/foo/quux'),
     )
   end
 
@@ -132,7 +133,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       '../../quux/',
-      relative_path_to('/foo/quux/')
+      relative_path_to('/foo/quux/'),
     )
   end
 
@@ -148,7 +149,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       '../../quux/',
-      relative_path_to(other_item_rep)
+      relative_path_to(other_item_rep),
     )
   end
 
@@ -164,7 +165,7 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     # Test
     assert_equal(
       '../../quux/',
-      relative_path_to(other_item)
+      relative_path_to(other_item),
     )
   end
 
@@ -210,14 +211,18 @@ class Nanoc::Helpers::LinkToTest < Nanoc::TestCase
     YARD.parse(LIB_DIR + '/nanoc/helpers/link_to.rb')
 
     # Mock
-    @items = [mock, mock, mock]
+    @items = [
+      Nanoc::ItemRepView.new(mock, {}),
+      Nanoc::ItemRepView.new(mock, {}),
+      Nanoc::ItemRepView.new(mock, {}),
+    ]
     @items[0].stubs(:identifier).returns('/about/')
     @items[0].stubs(:path).returns('/about.html')
     @items[1].stubs(:identifier).returns('/software/')
     @items[1].stubs(:path).returns('/software.html')
     @items[2].stubs(:identifier).returns('/software/nanoc/')
     @items[2].stubs(:path).returns('/software/nanoc.html')
-    about_rep_vcard = mock
+    about_rep_vcard = Nanoc::ItemRepView.new(mock, {})
     about_rep_vcard.stubs(:path).returns('/about.vcf')
     @items[0].stubs(:rep).with(:vcard).returns(about_rep_vcard)
 
