@@ -1,44 +1,50 @@
-# encoding: utf-8
-
 class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   include Nanoc::Helpers::XMLSitemap
 
-  def teardown
+  def setup
     super
+
+    @reps = Nanoc::Int::ItemRepRepo.new
+    @view_context = Nanoc::ViewContext.new(reps: @reps, items: nil)
+
     @items = nil
-    @item  = nil
-    @site  = nil
-    super
+    @item = nil
+    @site = nil
+    @config = nil
   end
 
   def test_xml_sitemap
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = []
+      @items = Nanoc::Int::IdentifiableCollection.new({})
 
       # Create item 1
-      @items << Nanoc::Item.new('some content 1', {}, '/item-one/')
-      create_item_rep(@items.last, :one_a, '/item-one/a/')
-      create_item_rep(@items.last, :one_b, '/item-one/b/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :one_a, '/item-one/a/')
+      create_item_rep(item.unwrap, :one_b, '/item-one/b/')
 
       # Create item 2
-      @items << Nanoc::Item.new('some content 2', { is_hidden: true }, '/item-two/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 2', { is_hidden: true }, '/item-two/'), @view_context)
+      @items << item
 
       # Create item 3
       attrs = { mtime: Time.parse('2004-07-12'), changefreq: 'daily', priority: 0.5 }
-      @items << Nanoc::Item.new('some content 3', attrs, '/item-three/')
-      create_item_rep(@items.last, :three_a, '/item-three/a/')
-      create_item_rep(@items.last, :three_b, '/item-three/b/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 3', attrs, '/item-three/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :three_a, '/item-three/a/')
+      create_item_rep(item.unwrap, :three_b, '/item-three/b/')
 
       # Create item 4
-      @items << Nanoc::Item.new('some content 4', {}, '/item-four/')
-      create_item_rep(@items.last, :four_a, nil)
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 4', {}, '/item-four/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :four_a, nil)
 
       # Create sitemap item
-      @item = Nanoc::Item.new('sitemap content', {}, '/sitemap/')
+      @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @site = Nanoc::Site.new({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Build sitemap
       res = xml_sitemap
@@ -71,21 +77,22 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_sitemap_with_items_as_param
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = []
+      @items = Nanoc::Int::IdentifiableCollection.new({})
       @items << nil
-      @items << Nanoc::Item.new('some content 1', {}, '/item-one/')
-      create_item_rep(@items.last, :one_a, '/item-one/a/')
-      create_item_rep(@items.last, :one_b, '/item-one/b/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :one_a, '/item-one/a/')
+      create_item_rep(item.unwrap, :one_b, '/item-one/b/')
       @items << nil
 
       # Create sitemap item
-      @item = Nanoc::Item.new('sitemap content', {}, '/sitemap/')
+      @item = Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/')
 
       # Create site
-      @site = Nanoc::Site.new({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Build sitemap
-      res = xml_sitemap(items: [@items[1]])
+      res = xml_sitemap(items: [item])
 
       # Check
       doc = Nokogiri::XML(res)
@@ -107,15 +114,17 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_filter
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = [Nanoc::Item.new('some content 1', {}, '/item-one/')]
-      create_item_rep(@items.last, :one_a, '/item-one/a/')
-      create_item_rep(@items.last, :one_b, '/item-one/b/')
+      @items = Nanoc::Int::IdentifiableCollection.new({})
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/item-one/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :one_a, '/item-one/a/')
+      create_item_rep(item.unwrap, :one_b, '/item-one/b/')
 
       # Create sitemap item
-      @item = Nanoc::Item.new('sitemap content', {}, '/sitemap/')
+      @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @site = Nanoc::Site.new({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Build sitemap
       res = xml_sitemap(rep_select: ->(rep) { rep.name == :one_a })
@@ -136,22 +145,25 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def test_sorted
     if_have 'builder', 'nokogiri' do
       # Create items
-      @items = []
-      @items << Nanoc::Item.new('some content 1', {}, '/george/')
-      create_item_rep(@items.last, :a_alice,   '/george/alice/')
-      create_item_rep(@items.last, :b_zoey,    '/george/zoey/')
-      @items << Nanoc::Item.new('some content 1', {}, '/walton/')
-      create_item_rep(@items.last, :a_eve,     '/walton/eve/')
-      create_item_rep(@items.last, :b_bob,     '/walton/bob/')
-      @items << Nanoc::Item.new('some content 1', {}, '/lucas/')
-      create_item_rep(@items.last, :a_trudy,   '/lucas/trudy/')
-      create_item_rep(@items.last, :b_mallory, '/lucas/mallory/')
+      @items = Nanoc::Int::IdentifiableCollection.new({})
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/george/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :a_alice,   '/george/alice/')
+      create_item_rep(item.unwrap, :b_zoey,    '/george/zoey/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/walton/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :a_eve,     '/walton/eve/')
+      create_item_rep(item.unwrap, :b_bob,     '/walton/bob/')
+      item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('some content 1', {}, '/lucas/'), @view_context)
+      @items << item
+      create_item_rep(item.unwrap, :a_trudy,   '/lucas/trudy/')
+      create_item_rep(item.unwrap, :b_mallory, '/lucas/mallory/')
 
       # Create sitemap item
-      @item = Nanoc::Item.new('sitemap content', {}, '/sitemap/')
+      @item = Nanoc::ItemWithRepsView.new(Nanoc::Int::Item.new('sitemap content', {}, '/sitemap/'), @view_context)
 
       # Create site
-      @site = Nanoc::Site.new({ base_url: 'http://example.com' })
+      @config = Nanoc::ConfigView.new({ base_url: 'http://example.com' }, nil)
 
       # Build sitemap
       res = xml_sitemap(items: @items)
@@ -174,10 +186,10 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   protected
 
   def create_item_rep(item, name, path)
-    rep = Nanoc::ItemRep.new(item, name)
+    rep = Nanoc::Int::ItemRep.new(item, name)
     rep.paths     = { last: path }
     rep.raw_paths = { last: path }
-    item.reps << rep
+    @reps << rep
     rep
   end
 end
